package com.asterinet.react.tcpsocket;

import android.content.Context;
import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.security.GeneralSecurityException;
import java.security.KeyStore;
import java.security.SecureRandom;
import java.security.cert.Certificate;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509TrustManager;

final class SSLCertificateHelper {
    SSLCertificateHelper() {
    }

    static SSLSocketFactory createBlindSocketFactory() throws GeneralSecurityException {
        SSLContext instance = SSLContext.getInstance("TLS");
        instance.init(null, new TrustManager[]{new BlindTrustManager()}, null);
        return instance.getSocketFactory();
    }

    static SSLSocketFactory createCustomTrustedSocketFactory(Context context, String str) throws IOException, GeneralSecurityException {
        InputStream rawResourceStream = getRawResourceStream(context, str);
        Certificate generateCertificate = CertificateFactory.getInstance("X.509").generateCertificate(rawResourceStream);
        rawResourceStream.close();
        KeyStore instance = KeyStore.getInstance(KeyStore.getDefaultType());
        instance.load(null, null);
        instance.setCertificateEntry("ca", generateCertificate);
        TrustManagerFactory instance2 = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
        instance2.init(instance);
        SSLContext instance3 = SSLContext.getInstance("TLS");
        instance3.init(null, instance2.getTrustManagers(), new SecureRandom());
        return instance3.getSocketFactory();
    }

    private static InputStream getRawResourceStream(Context context, String str) throws IOException {
        int resourceId = getResourceId(context, str);
        if (resourceId == 0) {
            return URI.create(str).toURL().openStream();
        }
        return context.getResources().openRawResource(resourceId);
    }

    private static int getResourceId(Context context, String str) {
        String replace = str.toLowerCase().replace("-", "_");
        try {
            return Integer.parseInt(replace);
        } catch (NumberFormatException unused) {
            return context.getResources().getIdentifier(replace, "raw", context.getPackageName());
        }
    }

    private static class BlindTrustManager implements X509TrustManager {
        @Override // javax.net.ssl.X509TrustManager
        public void checkClientTrusted(X509Certificate[] x509CertificateArr, String str) {
        }

        @Override // javax.net.ssl.X509TrustManager
        public void checkServerTrusted(X509Certificate[] x509CertificateArr, String str) {
        }

        public X509Certificate[] getAcceptedIssuers() {
            return null;
        }

        private BlindTrustManager() {
        }
    }
}
