package com.asterinet.react.tcpsocket;

import android.content.Context;
import android.net.Network;
import com.facebook.react.bridge.ReadableMap;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.security.GeneralSecurityException;
import java.util.Arrays;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import javax.net.SocketFactory;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;

/* access modifiers changed from: package-private */
public class TcpSocketClient extends TcpSocket {
    private final ExecutorService listenExecutor = Executors.newSingleThreadExecutor();
    private final TcpEventListener receiverListener;
    private TcpReceiverTask receiverTask;
    private Socket socket;
    private final ExecutorService writeExecutor = Executors.newSingleThreadExecutor();

    TcpSocketClient(TcpEventListener tcpEventListener, Integer num, Socket socket2) {
        super(num.intValue());
        this.socket = socket2;
        this.receiverListener = tcpEventListener;
    }

    public Socket getSocket() {
        return this.socket;
    }

    public void connect(Context context, String str, Integer num, ReadableMap readableMap, Network network) throws IOException, GeneralSecurityException {
        SocketFactory socketFactory;
        if (this.socket == null) {
            int i = 0;
            boolean z = readableMap.hasKey("tls") && readableMap.getBoolean("tls");
            if (z) {
                if (!readableMap.hasKey("tlsCheckValidity") || readableMap.getBoolean("tlsCheckValidity")) {
                    String string = readableMap.hasKey("tlsCert") ? readableMap.getString("tlsCert") : null;
                    socketFactory = string != null ? SSLCertificateHelper.createCustomTrustedSocketFactory(context, string) : SSLSocketFactory.getDefault();
                } else {
                    socketFactory = SSLCertificateHelper.createBlindSocketFactory();
                }
                SSLSocket sSLSocket = (SSLSocket) socketFactory.createSocket();
                sSLSocket.setUseClientMode(true);
                this.socket = sSLSocket;
            } else {
                this.socket = new Socket();
            }
            InetAddress byName = InetAddress.getByName(readableMap.hasKey("localAddress") ? readableMap.getString("localAddress") : "0.0.0.0");
            InetAddress byName2 = InetAddress.getByName(str);
            if (network != null) {
                network.bindSocket(this.socket);
            }
            if (readableMap.hasKey("reuseAddress")) {
                this.socket.setReuseAddress(readableMap.getBoolean("reuseAddress"));
            } else {
                this.socket.setReuseAddress(true);
            }
            if (readableMap.hasKey("localPort")) {
                i = readableMap.getInt("localPort");
            }
            this.socket.bind(new InetSocketAddress(byName, i));
            this.socket.connect(new InetSocketAddress(byName2, num.intValue()));
            if (z) {
                ((SSLSocket) this.socket).startHandshake();
            }
            startListening();
            return;
        }
        throw new IOException("Already connected");
    }

    public void startListening() {
        TcpReceiverTask tcpReceiverTask = new TcpReceiverTask(this, this.receiverListener);
        this.receiverTask = tcpReceiverTask;
        this.listenExecutor.execute(tcpReceiverTask);
    }

    public void write(final int i, final byte[] bArr) {
        this.writeExecutor.execute(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketClient.AnonymousClass1 */

            public void run() {
                try {
                    TcpSocketClient.this.socket.getOutputStream().write(bArr);
                    TcpSocketClient.this.receiverListener.onWritten(TcpSocketClient.this.getId(), i, null);
                } catch (IOException e) {
                    TcpSocketClient.this.receiverListener.onWritten(TcpSocketClient.this.getId(), i, e.toString());
                    TcpSocketClient.this.receiverListener.onError(TcpSocketClient.this.getId(), e.toString());
                }
            }
        });
    }

    public void destroy() {
        try {
            Socket socket2 = this.socket;
            if (socket2 != null && !socket2.isClosed()) {
                this.socket.close();
                this.receiverListener.onClose(getId(), null);
                this.socket = null;
            }
        } catch (IOException e) {
            this.receiverListener.onClose(getId(), e.getMessage());
        }
    }

    public void setNoDelay(boolean z) throws IOException {
        Socket socket2 = this.socket;
        if (socket2 != null) {
            socket2.setTcpNoDelay(z);
            return;
        }
        throw new IOException("Socket is not connected.");
    }

    public void setKeepAlive(boolean z, int i) throws IOException {
        Socket socket2 = this.socket;
        if (socket2 != null) {
            socket2.setKeepAlive(z);
            return;
        }
        throw new IOException("Socket is not connected.");
    }

    public void pause() {
        this.receiverTask.pause();
    }

    public void resume() {
        this.receiverTask.resume();
    }

    /* access modifiers changed from: private */
    public static class TcpReceiverTask implements Runnable {
        private final TcpSocketClient clientSocket;
        private boolean paused = false;
        private final TcpEventListener receiverListener;

        public TcpReceiverTask(TcpSocketClient tcpSocketClient, TcpEventListener tcpEventListener) {
            this.clientSocket = tcpSocketClient;
            this.receiverListener = tcpEventListener;
        }

        public void run() {
            int id = this.clientSocket.getId();
            Socket socket = this.clientSocket.getSocket();
            byte[] bArr = new byte[16384];
            try {
                BufferedInputStream bufferedInputStream = new BufferedInputStream(socket.getInputStream());
                while (!socket.isClosed()) {
                    int read = bufferedInputStream.read(bArr);
                    waitIfPaused();
                    if (read > 0) {
                        this.receiverListener.onData(id, Arrays.copyOfRange(bArr, 0, read));
                    } else if (read == -1) {
                        this.clientSocket.destroy();
                    }
                }
            } catch (IOException | InterruptedException e) {
                if (this.receiverListener != null && !socket.isClosed()) {
                    this.receiverListener.onError(id, e.getMessage());
                }
            }
        }

        public synchronized void pause() {
            this.paused = true;
        }

        public synchronized void resume() {
            this.paused = false;
            notify();
        }

        private synchronized void waitIfPaused() throws InterruptedException {
            while (this.paused) {
                wait();
            }
        }
    }
}
