package com.asterinet.react.tcpsocket;

import android.net.ConnectivityManager;
import android.net.Network;
import android.net.NetworkRequest;
import android.util.Base64;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import java.io.IOException;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

public class TcpSocketModule extends ReactContextBaseJavaModule {
    private static final int N_THREADS = 2;
    private static final String TAG = "TcpSockets";
    private final CurrentNetwork currentNetwork = new CurrentNetwork();
    private final ExecutorService executorService = Executors.newFixedThreadPool(2);
    private final ConcurrentHashMap<String, Network> mNetworkMap = new ConcurrentHashMap<>();
    private final ReactApplicationContext mReactContext;
    private final ConcurrentHashMap<Integer, TcpSocket> socketMap = new ConcurrentHashMap<>();
    private TcpEventListener tcpEvtListener;

    @ReactMethod
    public void addListener(String str) {
    }

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return TAG;
    }

    @ReactMethod
    public void removeListeners(Integer num) {
    }

    public TcpSocketModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.mReactContext = reactApplicationContext;
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void initialize() {
        super.initialize();
        this.tcpEvtListener = new TcpEventListener(this.mReactContext);
    }

    @ReactMethod
    public void connect(final Integer num, final String str, final Integer num2, final ReadableMap readableMap) {
        this.executorService.execute(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass1 */

            public void run() {
                if (TcpSocketModule.this.socketMap.get(num) != null) {
                    TcpSocketModule.this.tcpEvtListener.onError(num.intValue(), "TcpSocketscreateSocket called twice with the same id.");
                    return;
                }
                try {
                    TcpSocketModule.this.selectNetwork(readableMap.hasKey("interface") ? readableMap.getString("interface") : null, readableMap.hasKey("localAddress") ? readableMap.getString("localAddress") : null);
                    TcpSocketClient tcpSocketClient = new TcpSocketClient(TcpSocketModule.this.tcpEvtListener, num, null);
                    TcpSocketModule.this.socketMap.put(num, tcpSocketClient);
                    tcpSocketClient.connect(TcpSocketModule.this.mReactContext, str, num2, readableMap, TcpSocketModule.this.currentNetwork.getNetwork());
                    TcpSocketModule.this.tcpEvtListener.onConnect(num.intValue(), tcpSocketClient);
                } catch (Exception e) {
                    TcpSocketModule.this.tcpEvtListener.onError(num.intValue(), e.getMessage());
                }
            }
        });
    }

    @ReactMethod
    public void write(int i, String str, int i2) {
        getTcpClient(i).write(i2, Base64.decode(str, 2));
    }

    @ReactMethod
    public void end(final Integer num) {
        this.executorService.execute(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass2 */

            public void run() {
                TcpSocketModule.this.getTcpClient(num.intValue()).destroy();
                TcpSocketModule.this.socketMap.remove(num);
            }
        });
    }

    @ReactMethod
    public void destroy(Integer num) {
        end(num);
    }

    @ReactMethod
    public void close(final Integer num) {
        this.executorService.execute(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass3 */

            public void run() {
                TcpSocketModule.this.getTcpServer(num.intValue()).close();
                TcpSocketModule.this.socketMap.remove(num);
            }
        });
    }

    @ReactMethod
    public void listen(final Integer num, final ReadableMap readableMap) {
        this.executorService.execute(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass4 */

            public void run() {
                try {
                    TcpSocketServer tcpSocketServer = new TcpSocketServer(TcpSocketModule.this.socketMap, TcpSocketModule.this.tcpEvtListener, num, readableMap);
                    TcpSocketModule.this.socketMap.put(num, tcpSocketServer);
                    TcpSocketModule.this.tcpEvtListener.onListen(num.intValue(), tcpSocketServer);
                } catch (Exception e) {
                    TcpSocketModule.this.tcpEvtListener.onError(num.intValue(), e.getMessage());
                }
            }
        });
    }

    @ReactMethod
    public void setNoDelay(Integer num, boolean z) {
        try {
            getTcpClient(num.intValue()).setNoDelay(z);
        } catch (IOException e) {
            this.tcpEvtListener.onError(num.intValue(), e.getMessage());
        }
    }

    @ReactMethod
    public void setKeepAlive(Integer num, boolean z, int i) {
        try {
            getTcpClient(num.intValue()).setKeepAlive(z, i);
        } catch (IOException e) {
            this.tcpEvtListener.onError(num.intValue(), e.getMessage());
        }
    }

    @ReactMethod
    public void pause(int i) {
        getTcpClient(i).pause();
    }

    @ReactMethod
    public void resume(int i) {
        getTcpClient(i).resume();
    }

    private void requestNetwork(int i) throws InterruptedException {
        NetworkRequest.Builder builder = new NetworkRequest.Builder();
        builder.addTransportType(i);
        final CountDownLatch countDownLatch = new CountDownLatch(1);
        ((ConnectivityManager) this.mReactContext.getSystemService("connectivity")).requestNetwork(builder.build(), new ConnectivityManager.NetworkCallback() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass5 */

            public void onAvailable(Network network) {
                TcpSocketModule.this.currentNetwork.setNetwork(network);
                countDownLatch.countDown();
            }

            public void onUnavailable() {
                countDownLatch.countDown();
            }
        });
        new ScheduledThreadPoolExecutor(1).schedule(new Runnable() {
            /* class com.asterinet.react.tcpsocket.TcpSocketModule.AnonymousClass6 */

            public void run() {
                countDownLatch.countDown();
            }
        }, 5, TimeUnit.SECONDS);
        countDownLatch.await();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void selectNetwork(String str, String str2) throws InterruptedException, IOException {
        this.currentNetwork.setNetwork(null);
        if (str != null) {
            if (str2 != null) {
                ConcurrentHashMap<String, Network> concurrentHashMap = this.mNetworkMap;
                Network network = concurrentHashMap.get(str + str2);
                if (network != null) {
                    this.currentNetwork.setNetwork(network);
                    return;
                }
            }
            str.hashCode();
            char c = 65535;
            switch (str.hashCode()) {
                case -1419358249:
                    if (str.equals("ethernet")) {
                        c = 0;
                        break;
                    }
                    break;
                case -916596374:
                    if (str.equals("cellular")) {
                        c = 1;
                        break;
                    }
                    break;
                case 3649301:
                    if (str.equals("wifi")) {
                        c = 2;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    requestNetwork(3);
                    break;
                case 1:
                    requestNetwork(0);
                    break;
                case 2:
                    requestNetwork(1);
                    break;
            }
            if (this.currentNetwork.getNetwork() == null) {
                throw new IOException("Interface " + str + " unreachable");
            } else if (str2 != null && !str2.equals("0.0.0.0")) {
                ConcurrentHashMap<String, Network> concurrentHashMap2 = this.mNetworkMap;
                concurrentHashMap2.put(str + str2, this.currentNetwork.getNetwork());
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private TcpSocketClient getTcpClient(int i) {
        TcpSocket tcpSocket = this.socketMap.get(Integer.valueOf(i));
        if (tcpSocket == null) {
            throw new IllegalArgumentException("TcpSocketsNo socket with id " + i);
        } else if (tcpSocket instanceof TcpSocketClient) {
            return (TcpSocketClient) tcpSocket;
        } else {
            throw new IllegalArgumentException("TcpSocketsSocket with id " + i + " is not a client");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private TcpSocketServer getTcpServer(int i) {
        TcpSocket tcpSocket = this.socketMap.get(Integer.valueOf(i));
        if (tcpSocket == null) {
            throw new IllegalArgumentException("TcpSocketsNo socket with id " + i);
        } else if (tcpSocket instanceof TcpSocketServer) {
            return (TcpSocketServer) tcpSocket;
        } else {
            throw new IllegalArgumentException("TcpSocketsSocket with id " + i + " is not a server");
        }
    }

    /* access modifiers changed from: private */
    public static class CurrentNetwork {
        Network network;

        private CurrentNetwork() {
            this.network = null;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private Network getNetwork() {
            return this.network;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setNetwork(Network network2) {
            this.network = network2;
        }
    }
}
