package com.asterinet.react.tcpsocket;

import com.facebook.react.bridge.ReadableMap;
import java.io.IOException;
import java.net.InetAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public final class TcpSocketServer extends TcpSocket {
    private int clientSocketIds;
    private final ExecutorService listenExecutor = Executors.newSingleThreadExecutor();
    private final TcpEventListener mReceiverListener;
    private ServerSocket serverSocket;
    private final ConcurrentHashMap<Integer, TcpSocket> socketClients;

    public TcpSocketServer(ConcurrentHashMap<Integer, TcpSocket> concurrentHashMap, TcpEventListener tcpEventListener, Integer num, ReadableMap readableMap) throws IOException {
        super(num.intValue());
        int i = readableMap.getInt("port");
        String string = readableMap.getString("host");
        this.socketClients = concurrentHashMap;
        this.clientSocketIds = (getId() + 1) * 1000;
        this.serverSocket = new ServerSocket(i, 50, InetAddress.getByName(string));
        try {
            this.serverSocket.setReuseAddress(readableMap.getBoolean("reuseAddress"));
        } catch (Exception unused) {
            this.serverSocket.setReuseAddress(true);
        }
        this.mReceiverListener = tcpEventListener;
        listen();
    }

    public ServerSocket getServerSocket() {
        return this.serverSocket;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addClient(Socket socket) {
        int clientId = getClientId();
        TcpSocketClient tcpSocketClient = new TcpSocketClient(this.mReceiverListener, Integer.valueOf(clientId), socket);
        this.socketClients.put(Integer.valueOf(clientId), tcpSocketClient);
        this.mReceiverListener.onConnection(getId(), clientId, socket);
        tcpSocketClient.startListening();
    }

    private int getClientId() {
        int i = this.clientSocketIds;
        this.clientSocketIds = i + 1;
        return i;
    }

    private void listen() {
        this.listenExecutor.execute(new TcpListenTask(this.mReceiverListener));
    }

    public void close() {
        try {
            ServerSocket serverSocket2 = this.serverSocket;
            if (serverSocket2 != null && !serverSocket2.isClosed()) {
                this.serverSocket.close();
                this.mReceiverListener.onClose(getId(), null);
                this.serverSocket = null;
            }
        } catch (IOException e) {
            this.mReceiverListener.onClose(getId(), e.getMessage());
        }
    }

    /* access modifiers changed from: private */
    public static class TcpListenTask implements Runnable {
        private final TcpEventListener receiverListener;
        private final TcpSocketServer server;

        private TcpListenTask(TcpSocketServer tcpSocketServer, TcpEventListener tcpEventListener) {
            this.server = tcpSocketServer;
            this.receiverListener = tcpEventListener;
        }

        public void run() {
            ServerSocket serverSocket = this.server.getServerSocket();
            while (!serverSocket.isClosed()) {
                try {
                    this.server.addClient(serverSocket.accept());
                } catch (IOException e) {
                    if (!serverSocket.isClosed()) {
                        this.receiverListener.onError(this.server.getId(), e.getMessage());
                        return;
                    }
                    return;
                }
            }
        }
    }
}
