package com.facebook.react.views.scroll;

import android.content.Context;
import android.widget.HorizontalScrollView;
import com.facebook.react.modules.i18nmanager.I18nUtil;
import com.facebook.react.views.view.ReactViewGroup;

public class ReactHorizontalScrollContainerView extends ReactViewGroup {
    private int mLastWidth = 0;
    private int mLayoutDirection;
    private Listener rtlListener = null;

    public interface Listener {
        void onLayout();
    }

    public ReactHorizontalScrollContainerView(Context context) {
        super(context);
        this.mLayoutDirection = I18nUtil.getInstance().isRTL(context) ? 1 : 0;
    }

    @Override // com.facebook.react.uimanager.ReactClippingViewGroup, com.facebook.react.views.view.ReactViewGroup
    public void setRemoveClippedSubviews(boolean z) {
        if (this.mLayoutDirection == 1) {
            super.setRemoveClippedSubviews(false);
        } else {
            super.setRemoveClippedSubviews(z);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.views.view.ReactViewGroup
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        HorizontalScrollView horizontalScrollView = (HorizontalScrollView) getParent();
        horizontalScrollView.setClipChildren(false);
        setClipChildren(false);
        if (this.mLayoutDirection == 1) {
            setLeft(0);
            setRight((i3 - i) + 0);
            horizontalScrollView.scrollTo((getMeasuredWidth() - this.mLastWidth) + horizontalScrollView.getScrollX(), horizontalScrollView.getScrollY());
            this.mLastWidth = getMeasuredWidth();
            Listener listener = this.rtlListener;
            if (listener != null) {
                listener.onLayout();
            }
        }
    }

    public int getLastWidth() {
        return this.mLastWidth;
    }

    public void setListener(Listener listener) {
        this.rtlListener = listener;
    }
}
