package com.flurry.android.marketing;

import android.text.TextUtils;
import com.flurry.sdk.cx;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.messaging.FirebaseMessaging;

public class FlurryMarketingUtils {
    private static final String TAG = "FlurryMarketingUtils";

    public static class FirebaseTokenAgent implements OnCompleteListener<String> {
        private TokenListener listener;
        private String token;

        public interface TokenListener {
            void onComplete(String str);
        }

        public void start(TokenListener tokenListener) {
            this.listener = tokenListener;
            try {
                FirebaseMessaging.getInstance().getToken().addOnCompleteListener(this);
            } catch (Throwable th) {
                cx.e(FlurryMarketingUtils.TAG, "Failed to get Firebase token: ".concat(String.valueOf(th)));
            }
        }

        public String getToken() {
            return this.token;
        }

        @Override // com.google.android.gms.tasks.OnCompleteListener
        public void onComplete(Task<String> task) {
            this.token = task.isSuccessful() ? task.getResult() : null;
            cx.c(FlurryMarketingUtils.TAG, "Firebase token received: " + this.token);
            if (this.listener != null && !TextUtils.isEmpty(this.token)) {
                this.listener.onComplete(this.token);
            }
        }
    }
}
