package com.flurry.android.reactnative;

import android.content.Context;
import android.text.TextUtils;
import android.util.Log;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableMapKeySetIterator;
import com.facebook.react.bridge.ReadableType;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.facebook.react.uimanager.IllegalViewOperationException;
import com.flurry.android.FlurryAgent;
import com.flurry.android.FlurryAgentListener;
import com.flurry.android.FlurryConfig;
import com.flurry.android.FlurryConfigListener;
import com.flurry.android.FlurryEvent;
import com.flurry.android.FlurryPerformance;
import com.flurry.android.FlurryPrivacySession;
import com.flurry.android.FlurryPublisherSegmentation;
import com.flurry.android.marketing.FlurryMarketingModule;
import com.flurry.android.marketing.FlurryMarketingOptions;
import com.flurry.android.marketing.messaging.FlurryMessagingListener;
import com.flurry.android.marketing.messaging.notification.FlurryMessage;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class FlurryModule extends ReactContextBaseJavaModule {
    private static final String FLURRY_CONFIG_EVENT = "FlurryConfigEvent";
    private static final String FLURRY_MESSAGING_EVENT = "FlurryMessagingEvent";
    private static final String ORIGIN_NAME = "react-native-flurry-sdk";
    private static final String ORIGIN_VERSION = "7.1.1";
    private static final String REACT_CLASS = "ReactNativeFlurry";
    private static final String TAG = "FlurryModule";
    private static boolean sEnableMessagingListener = false;
    private static FlurryMessage sFlurryMessage;
    private static FlurryPerformance.ResourceLogger sFlurryPerformanceResourceLogger;
    private static FlurryPublisherSegmentation.FetchListener sPublisherSegmentationListener;
    private static RNFlurryConfigListener sRNFlurryConfigListener;
    private static ReactApplicationContext sReactApplicationContext;
    private static int sRequestConfigListener;
    private FlurryAgent.Builder mFlurryAgentBuilder;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return REACT_CLASS;
    }

    @ReactMethod
    public void onPageView() {
    }

    public FlurryModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        sReactApplicationContext = reactApplicationContext;
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void initialize() {
        super.initialize();
        if (sFlurryMessage != null && sReactApplicationContext != null) {
            RNFlurryMessagingListener.sendEvent(RNFlurryMessagingListener.EventType.NotificationClicked, sFlurryMessage, false);
            sFlurryMessage = null;
        }
    }

    @ReactMethod
    public void initBuilder() {
        this.mFlurryAgentBuilder = new FlurryAgent.Builder();
    }

    @ReactMethod
    public void build(String str) {
        FlurryAgent.addOrigin(ORIGIN_NAME, ORIGIN_VERSION);
        Context currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            currentActivity = getReactApplicationContext();
        }
        this.mFlurryAgentBuilder.withListener(new FlurryAgentListener() {
            /* class com.flurry.android.reactnative.FlurryModule.AnonymousClass1 */

            @Override // com.flurry.android.FlurryAgentListener
            public void onSessionStarted() {
            }
        }).withSessionForceStart(true).build(currentActivity, str);
    }

    @ReactMethod
    public void withCrashReporting(boolean z) {
        this.mFlurryAgentBuilder.withCaptureUncaughtExceptions(z);
    }

    @ReactMethod
    public void withContinueSessionMillis(double d) {
        this.mFlurryAgentBuilder.withContinueSessionMillis((long) d);
    }

    @ReactMethod
    public void withDataSaleOptOut(boolean z) {
        this.mFlurryAgentBuilder.withDataSaleOptOut(z);
    }

    @ReactMethod
    public void withIncludeBackgroundSessionsInMetrics(boolean z) {
        this.mFlurryAgentBuilder.withIncludeBackgroundSessionsInMetrics(z);
    }

    @ReactMethod
    public void withLogEnabled(boolean z) {
        this.mFlurryAgentBuilder.withLogEnabled(z);
    }

    @ReactMethod
    public void withLogLevel(double d) {
        this.mFlurryAgentBuilder.withLogLevel((int) d);
    }

    @ReactMethod
    public void withPerformanceMetrics(double d) {
        this.mFlurryAgentBuilder.withPerformanceMetrics((int) d);
    }

    @ReactMethod
    public void withSslPinningEnabled(boolean z) {
        this.mFlurryAgentBuilder.withSslPinningEnabled(z);
    }

    @ReactMethod
    public void withMessaging(boolean z) {
        Log.i(TAG, "To enable Flurry Push for Android, please duplicate Builder setup in your MainApplication.java.");
    }

    @ReactMethod
    public void setContinueSessionMillis(double d) {
        FlurryAgent.setContinueSessionMillis((long) d);
    }

    @ReactMethod
    public void setCrashReporting(boolean z) {
        FlurryAgent.setCaptureUncaughtExceptions(z);
    }

    @ReactMethod
    public void setIncludeBackgroundSessionsInMetrics(boolean z) {
        FlurryAgent.setIncludeBackgroundSessionsInMetrics(z);
    }

    @ReactMethod
    public void setLogEnabled(boolean z) {
        FlurryAgent.setLogEnabled(z);
    }

    @ReactMethod
    public void setLogLevel(int i) {
        FlurryAgent.setLogLevel(i);
    }

    @ReactMethod
    public void setSslPinningEnabled(boolean z) {
        FlurryAgent.setSslPinningEnabled(z);
    }

    @ReactMethod
    public void setAge(double d) {
        FlurryAgent.setAge((int) d);
    }

    @ReactMethod
    public void setGender(String str) {
        byte b;
        if (str.equalsIgnoreCase("m")) {
            b = 1;
        } else {
            b = str.equalsIgnoreCase("f") ? (byte) 0 : -1;
        }
        FlurryAgent.setGender(b);
    }

    @ReactMethod
    public void setReportLocation(boolean z) {
        FlurryAgent.setReportLocation(z);
    }

    @ReactMethod
    public void setSessionOrigin(String str, String str2) {
        FlurryAgent.setSessionOrigin(str, str2);
    }

    @ReactMethod
    public void setUserId(String str) {
        FlurryAgent.setUserId(str);
    }

    @ReactMethod
    public void setVersionName(String str) {
        FlurryAgent.setVersionName(str);
    }

    @ReactMethod
    public void setIAPReportingEnabled(boolean z) {
        Log.i(TAG, "setIAPReportingEnabled is not supported on Android. Please use logPayment instead.");
    }

    @ReactMethod
    public void setDataSaleOptOut(boolean z) {
        FlurryAgent.setDataSaleOptOut(z);
    }

    @ReactMethod
    public void deleteData() {
        FlurryAgent.deleteData();
    }

    @ReactMethod
    public void openPrivacyDashboard() {
        if (sReactApplicationContext == null) {
            Log.w(TAG, "Application Context is not available to open Privacy Dashboard.");
            return;
        }
        FlurryAgent.openPrivacyDashboard(new FlurryPrivacySession.Request(sReactApplicationContext, new FlurryPrivacySession.Callback() {
            /* class com.flurry.android.reactnative.FlurryModule.AnonymousClass2 */

            @Override // com.flurry.android.FlurryPrivacySession.Callback
            public void success() {
                Log.d(FlurryModule.TAG, "Privacy Dashboard opened successfully.");
            }

            @Override // com.flurry.android.FlurryPrivacySession.Callback
            public void failure() {
                Log.d(FlurryModule.TAG, "Opening Privacy Dashboard failed.");
            }
        }));
    }

    @ReactMethod
    public void addOrigin(String str, String str2) {
        FlurryAgent.addOrigin(str, str2);
    }

    @ReactMethod
    public void addOriginParams(String str, String str2, ReadableMap readableMap) {
        FlurryAgent.addOrigin(str, str2, toMap(readableMap));
    }

    @ReactMethod
    public void addSessionProperty(String str, String str2) {
        FlurryAgent.addSessionProperty(str, str2);
    }

    @ReactMethod
    public void getVersions(Callback callback, Callback callback2) {
        try {
            callback2.invoke(Integer.valueOf(FlurryAgent.getAgentVersion()), FlurryAgent.getReleaseVersion(), FlurryAgent.getSessionId());
        } catch (IllegalViewOperationException e) {
            callback.invoke(e.getMessage());
        }
    }

    @ReactMethod
    public void getVersionsPromise(Promise promise) {
        try {
            WritableMap createMap = Arguments.createMap();
            createMap.putInt("agentVersion", FlurryAgent.getAgentVersion());
            createMap.putString("releaseVersion", FlurryAgent.getReleaseVersion());
            createMap.putString("sessionId", FlurryAgent.getSessionId());
            promise.resolve(createMap);
        } catch (IllegalViewOperationException e) {
            promise.reject("Flurry.getVersionsPromise", e);
        }
    }

    @ReactMethod
    public void getPublisherSegmentation(boolean z, final Promise promise) {
        if (!z) {
            try {
                Map<String, String> publisherData = FlurryPublisherSegmentation.getPublisherData();
                if (publisherData != null) {
                    resolvePublisherSegmentation(publisherData, promise);
                    return;
                }
            } catch (IllegalViewOperationException e) {
                promise.reject("Flurry.getPublisherSegmentation", e);
                return;
            }
        }
        if (FlurryPublisherSegmentation.isFetchFinished()) {
            resolvePublisherSegmentation(FlurryPublisherSegmentation.getPublisherData(), promise);
            return;
        }
        AnonymousClass3 r2 = new FlurryPublisherSegmentation.FetchListener() {
            /* class com.flurry.android.reactnative.FlurryModule.AnonymousClass3 */

            @Override // com.flurry.android.FlurryPublisherSegmentation.FetchListener
            public void onFetched(Map<String, String> map) {
                FlurryPublisherSegmentation.unregisterFetchListener(FlurryModule.sPublisherSegmentationListener);
                FlurryModule.this.resolvePublisherSegmentation(map, promise);
            }
        };
        sPublisherSegmentationListener = r2;
        FlurryPublisherSegmentation.registerFetchListener(r2);
        FlurryPublisherSegmentation.fetch();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void resolvePublisherSegmentation(Map<String, String> map, Promise promise) {
        WritableMap createMap = Arguments.createMap();
        if (map != null) {
            for (Map.Entry<String, String> entry : map.entrySet()) {
                createMap.putString(entry.getKey(), entry.getValue());
            }
        }
        promise.resolve(createMap);
    }

    @ReactMethod
    public void fetchPublisherSegmentation() {
        FlurryPublisherSegmentation.fetch();
    }

    @ReactMethod
    public void logBreadcrumb(String str) {
        FlurryAgent.logBreadcrumb(str);
    }

    @ReactMethod
    public void logEvent(String str) {
        FlurryAgent.logEvent(str);
    }

    @ReactMethod
    public void logEventTimed(String str, boolean z) {
        FlurryAgent.logEvent(str, z);
    }

    @ReactMethod
    public void logEventParams(String str, ReadableMap readableMap) {
        FlurryAgent.logEvent(str, toMap(readableMap));
    }

    @ReactMethod
    public void logEventParamsTimed(String str, ReadableMap readableMap, boolean z) {
        FlurryAgent.logEvent(str, toMap(readableMap), z);
    }

    @ReactMethod
    public void logStandardEvent(double d, ReadableMap readableMap) {
        int i = (int) d;
        if (i < 0 || i >= ReactNativeFlurryEvent.EVENTS.length) {
            Log.e(TAG, "Standard event ID is out of range: " + i);
            return;
        }
        FlurryAgent.logEvent(ReactNativeFlurryEvent.EVENTS[i], getStandardEventParams(readableMap));
    }

    private static FlurryEvent.Params getStandardEventParams(ReadableMap readableMap) {
        FlurryEvent.Params params = new FlurryEvent.Params();
        if (readableMap == null) {
            return params;
        }
        Iterator<Map.Entry<String, Object>> entryIterator = readableMap.getEntryIterator();
        if (!entryIterator.hasNext()) {
            return params;
        }
        while (entryIterator.hasNext()) {
            Map.Entry<String, Object> next = entryIterator.next();
            String key = next.getKey();
            if (!TextUtils.isEmpty(key)) {
                addStandardEventParams(params, key, next.getValue());
            }
        }
        return params;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:33:0x0017 */
    /* JADX DEBUG: Multi-variable search result rejected for r3v6, resolved type: com.flurry.android.FlurryEvent$BooleanParam */
    /* JADX WARN: Multi-variable type inference failed */
    private static void addStandardEventParams(FlurryEvent.Params params, String str, Object obj) {
        FlurryEvent.ParamBase paramBase;
        FlurryEvent.ParamBase[] paramBaseArr = ReactNativeFlurryEvent.PARAMS;
        int length = paramBaseArr.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                paramBase = null;
                break;
            }
            paramBase = paramBaseArr[i];
            if (str.equals(paramBase.toString())) {
                break;
            }
            i++;
        }
        if (paramBase == null) {
            params.putString(str, obj.toString());
            return;
        }
        if (obj instanceof String) {
            if (paramBase instanceof FlurryEvent.StringParam) {
                params.putString((FlurryEvent.StringParam) paramBase, (String) obj);
                return;
            }
        } else if (obj instanceof Double) {
            double doubleValue = ((Double) obj).doubleValue();
            if (paramBase instanceof FlurryEvent.IntegerParam) {
                params.putLong((FlurryEvent.IntegerParam) paramBase, (long) doubleValue);
                return;
            } else if (paramBase instanceof FlurryEvent.DoubleParam) {
                params.putDouble((FlurryEvent.DoubleParam) paramBase, doubleValue);
                return;
            }
        } else if ((obj instanceof Boolean) && (paramBase instanceof FlurryEvent.BooleanParam)) {
            params.putBoolean((FlurryEvent.BooleanParam) paramBase, ((Boolean) obj).booleanValue());
            return;
        }
        Log.e(TAG, "Wrong Standard parameter type: {" + str + ", " + obj + "}.");
    }

    @ReactMethod
    public void logPayment(String str, String str2, double d, double d2, String str3, String str4, ReadableMap readableMap) {
        FlurryAgent.logPayment(str, str2, (int) d, d2, str3, str4, toMap(readableMap));
    }

    @ReactMethod
    public void endTimedEvent(String str) {
        FlurryAgent.endTimedEvent(str);
    }

    @ReactMethod
    public void endTimedEventParams(String str, ReadableMap readableMap) {
        FlurryAgent.endTimedEvent(str, toMap(readableMap));
    }

    @ReactMethod
    public void onError(String str, String str2, String str3) {
        FlurryAgent.onError(str, str2, str3);
    }

    @ReactMethod
    public void onErrorParams(String str, String str2, String str3, ReadableMap readableMap) {
        FlurryAgent.onError(str, str2, str3, toMap(readableMap));
    }

    @ReactMethod
    public void UserPropertiesSet(String str, String str2) {
        FlurryAgent.UserProperties.set(str, str2);
    }

    @ReactMethod
    public void UserPropertiesSetList(String str, ReadableArray readableArray) {
        FlurryAgent.UserProperties.set(str, toList(readableArray));
    }

    @ReactMethod
    public void UserPropertiesAdd(String str, String str2) {
        FlurryAgent.UserProperties.add(str, str2);
    }

    @ReactMethod
    public void UserPropertiesAddList(String str, ReadableArray readableArray) {
        FlurryAgent.UserProperties.add(str, toList(readableArray));
    }

    @ReactMethod
    public void UserPropertiesRemove(String str, String str2) {
        FlurryAgent.UserProperties.remove(str, str2);
    }

    @ReactMethod
    public void UserPropertiesRemoveList(String str, ReadableArray readableArray) {
        FlurryAgent.UserProperties.remove(str, toList(readableArray));
    }

    @ReactMethod
    public void UserPropertiesRemoveAll(String str) {
        FlurryAgent.UserProperties.remove(str);
    }

    @ReactMethod
    public void UserPropertiesFlag(String str) {
        FlurryAgent.UserProperties.flag(str);
    }

    @ReactMethod
    public void reportFullyDrawn() {
        FlurryPerformance.reportFullyDrawn();
    }

    @ReactMethod
    public void startPerformanceResourceLogger() {
        sFlurryPerformanceResourceLogger = new FlurryPerformance.ResourceLogger();
    }

    @ReactMethod
    public void logPerformanceResourceLogger(String str) {
        FlurryPerformance.ResourceLogger resourceLogger = sFlurryPerformanceResourceLogger;
        if (resourceLogger != null) {
            resourceLogger.logEvent(str);
        }
    }

    @ReactMethod
    public void updateConversionValue(double d) {
        Log.i(TAG, "UpdateConversionValue is for iOS only.");
    }

    @ReactMethod
    public void updateConversionValueWithEvent(double d) {
        Log.i(TAG, "UpdateConversionValueWithEvent is for iOS only.");
    }

    @ReactMethod
    public void enableMessagingListener(boolean z) {
        sEnableMessagingListener = z;
        if (RNFlurryMessagingListener.sToken != null && sReactApplicationContext != null) {
            RNFlurryMessagingListener.sendEvent(RNFlurryMessagingListener.EventType.TokenRefresh, RNFlurryMessagingListener.sToken);
        }
    }

    @ReactMethod
    public void willHandleMessage(boolean z) {
        RNFlurryMessagingListener.notifyCallbackReturn(z);
    }

    @ReactMethod
    public void registerConfigListener() {
        sRequestConfigListener++;
        if (sRNFlurryConfigListener == null) {
            sRNFlurryConfigListener = new RNFlurryConfigListener();
            FlurryConfig.getInstance().registerListener(sRNFlurryConfigListener);
        }
    }

    @ReactMethod
    public void unregisterConfigListener() {
        sRequestConfigListener--;
    }

    @ReactMethod
    public void fetchConfig() {
        FlurryConfig.getInstance().fetchConfig();
    }

    @ReactMethod
    public void activateConfig() {
        FlurryConfig.getInstance().activateConfig();
    }

    @ReactMethod
    public void getConfigString(String str, String str2, Promise promise) {
        try {
            WritableMap createMap = Arguments.createMap();
            createMap.putString(str, FlurryConfig.getInstance().getString(str, str2));
            promise.resolve(createMap);
        } catch (IllegalViewOperationException e) {
            promise.reject("Flurry.getConfigString", e);
        }
    }

    @ReactMethod
    public void getConfigStringMap(ReadableMap readableMap, Promise promise) {
        try {
            WritableMap createMap = Arguments.createMap();
            if (readableMap != null) {
                ReadableMapKeySetIterator keySetIterator = readableMap.keySetIterator();
                while (keySetIterator.hasNextKey()) {
                    String nextKey = keySetIterator.nextKey();
                    createMap.putString(nextKey, FlurryConfig.getInstance().getString(nextKey, readableMap.getString(nextKey)));
                }
            }
            promise.resolve(createMap);
        } catch (IllegalViewOperationException e) {
            promise.reject("Flurry.getConfigString", e);
        }
    }

    private static Map<String, String> toMap(ReadableMap readableMap) {
        if (readableMap == null) {
            return null;
        }
        ReadableMapKeySetIterator keySetIterator = readableMap.keySetIterator();
        if (!keySetIterator.hasNextKey()) {
            return null;
        }
        HashMap hashMap = new HashMap();
        while (keySetIterator.hasNextKey()) {
            String nextKey = keySetIterator.nextKey();
            hashMap.put(nextKey, readableMap.getString(nextKey));
        }
        return hashMap;
    }

    private static List<String> toList(ReadableArray readableArray) {
        if (readableArray == null || readableArray.size() == 0) {
            return null;
        }
        ArrayList arrayList = new ArrayList();
        for (int i = 0; i < readableArray.size(); i++) {
            if (readableArray.getType(i) == ReadableType.String) {
                arrayList.add(readableArray.getString(i));
            }
        }
        return arrayList;
    }

    public static class Builder {
        private FlurryAgent.Builder mFlurryAgentBuilder = new FlurryAgent.Builder();

        public Builder withCrashReporting(boolean z) {
            this.mFlurryAgentBuilder.withCaptureUncaughtExceptions(z);
            return this;
        }

        public Builder withContinueSessionMillis(long j) {
            this.mFlurryAgentBuilder.withContinueSessionMillis(j);
            return this;
        }

        public Builder withIncludeBackgroundSessionsInMetrics(boolean z) {
            this.mFlurryAgentBuilder.withIncludeBackgroundSessionsInMetrics(z);
            return this;
        }

        public Builder withLogEnabled(boolean z) {
            this.mFlurryAgentBuilder.withLogEnabled(z);
            return this;
        }

        public Builder withLogLevel(int i) {
            this.mFlurryAgentBuilder.withLogLevel(i);
            return this;
        }

        public Builder withPerformanceMetrics(int i) {
            this.mFlurryAgentBuilder.withPerformanceMetrics(i);
            return this;
        }

        public Builder withSslPinningEnabled(boolean z) {
            this.mFlurryAgentBuilder.withSslPinningEnabled(z);
            return this;
        }

        public Builder withMessaging(boolean z) {
            withMessaging(z, (FlurryMessagingListener) null);
            return this;
        }

        public Builder withMessaging(boolean z, FlurryMessagingListener flurryMessagingListener) {
            if (!z) {
                return this;
            }
            if (flurryMessagingListener == null) {
                flurryMessagingListener = new RNFlurryMessagingListener();
            }
            this.mFlurryAgentBuilder.withModule(new FlurryMarketingModule(new FlurryMarketingOptions.Builder().setupMessagingWithAutoIntegration().withFlurryMessagingListener(flurryMessagingListener).build()));
            return this;
        }

        public Builder withMessaging(boolean z, FlurryMarketingOptions flurryMarketingOptions) {
            if (!z) {
                return this;
            }
            if (flurryMarketingOptions.getFlurryMessagingListener() == null) {
                FlurryMarketingOptions.Builder builder = new FlurryMarketingOptions.Builder();
                if (flurryMarketingOptions.isAutoIntegration()) {
                    builder.setupMessagingWithAutoIntegration();
                } else {
                    builder.setupMessagingWithManualIntegration(flurryMarketingOptions.getToken());
                }
                flurryMarketingOptions = builder.withFlurryMessagingListener(new RNFlurryMessagingListener()).withDefaultNotificationChannelId(flurryMarketingOptions.getNotificationChannelId()).withDefaultNotificationIconResourceId(flurryMarketingOptions.getDefaultNotificationIconResourceId()).withDefaultNotificationIconAccentColor(flurryMarketingOptions.getDefaultNotificationIconAccentColor()).build();
            }
            this.mFlurryAgentBuilder.withModule(new FlurryMarketingModule(flurryMarketingOptions));
            return this;
        }

        public void build(Context context, String str) {
            this.mFlurryAgentBuilder.withSessionForceStart(true).build(context, str);
        }
    }

    static class RNFlurryConfigListener implements FlurryConfigListener {
        RNFlurryConfigListener() {
        }

        /* access modifiers changed from: package-private */
        public enum EventType {
            FetchSuccess("FetchSuccess"),
            FetchNoChange("FetchNoChange"),
            FetchError("FetchError"),
            ActivateComplete("ActivateComplete");
            
            private final String name;

            private EventType(String str) {
                this.name = str;
            }

            public String getName() {
                return this.name;
            }
        }

        @Override // com.flurry.android.FlurryConfigListener
        public void onFetchSuccess() {
            if (FlurryModule.sRequestConfigListener > 0 && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.FetchSuccess);
            }
        }

        @Override // com.flurry.android.FlurryConfigListener
        public void onFetchNoChange() {
            if (FlurryModule.sRequestConfigListener > 0 && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.FetchNoChange);
            }
        }

        @Override // com.flurry.android.FlurryConfigListener
        public void onFetchError(boolean z) {
            if (FlurryModule.sRequestConfigListener > 0 && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.FetchError, "isRetrying", z);
            }
        }

        @Override // com.flurry.android.FlurryConfigListener
        public void onActivateComplete(boolean z) {
            if (FlurryModule.sRequestConfigListener > 0 && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.ActivateComplete, "isCache", z);
            }
        }

        private void sendEvent(EventType eventType) {
            sendEvent(eventType, null, false);
        }

        private void sendEvent(EventType eventType, String str, boolean z) {
            WritableMap createMap = Arguments.createMap();
            createMap.putString("Type", eventType.getName());
            if (str != null) {
                createMap.putBoolean(str, z);
            }
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) FlurryModule.sReactApplicationContext.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(FlurryModule.FLURRY_CONFIG_EVENT, createMap);
        }
    }

    public static FlurryMessagingListener getFlurryMessagingListener() {
        return new RNFlurryMessagingListener();
    }

    /* access modifiers changed from: package-private */
    public static class RNFlurryMessagingListener implements FlurryMessagingListener {
        private static volatile boolean sCallbackReturnValue = false;
        private static volatile boolean sIsCallbackReturn = false;
        private static volatile String sToken;

        @Override // com.flurry.android.marketing.messaging.FlurryMessagingListener
        public void onNonFlurryNotificationReceived(Object obj) {
        }

        RNFlurryMessagingListener() {
        }

        /* access modifiers changed from: package-private */
        public enum EventType {
            NotificationReceived("NotificationReceived"),
            NotificationClicked("NotificationClicked"),
            NotificationCancelled("NotificationCancelled"),
            TokenRefresh("TokenRefresh"),
            NonFlurryNotificationReceived("NonFlurryNotificationReceived");
            
            private final String name;

            private EventType(String str) {
                this.name = str;
            }

            public String getName() {
                return this.name;
            }
        }

        @Override // com.flurry.android.marketing.messaging.FlurryMessagingListener
        public boolean onNotificationReceived(FlurryMessage flurryMessage) {
            if (!FlurryModule.sEnableMessagingListener || FlurryModule.sReactApplicationContext == null) {
                return false;
            }
            return sendEvent(EventType.NotificationReceived, flurryMessage, true);
        }

        @Override // com.flurry.android.marketing.messaging.FlurryMessagingListener
        public boolean onNotificationClicked(FlurryMessage flurryMessage) {
            if (FlurryModule.sReactApplicationContext == null) {
                FlurryMessage unused = FlurryModule.sFlurryMessage = flurryMessage;
                return false;
            } else if (FlurryModule.sEnableMessagingListener) {
                return sendEvent(EventType.NotificationClicked, flurryMessage, true);
            } else {
                return false;
            }
        }

        @Override // com.flurry.android.marketing.messaging.FlurryMessagingListener
        public void onNotificationCancelled(FlurryMessage flurryMessage) {
            if (FlurryModule.sEnableMessagingListener && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.NotificationCancelled, flurryMessage, false);
            }
        }

        @Override // com.flurry.android.marketing.messaging.FlurryMessagingListener
        public void onTokenRefresh(String str) {
            sToken = str;
            if (FlurryModule.sEnableMessagingListener && FlurryModule.sReactApplicationContext != null) {
                sendEvent(EventType.TokenRefresh, str);
            }
        }

        /* access modifiers changed from: private */
        public static boolean sendEvent(EventType eventType, FlurryMessage flurryMessage, boolean z) {
            WritableMap createMap = Arguments.createMap();
            createMap.putString("Type", eventType.getName());
            createMap.putString("Title", flurryMessage.getTitle());
            createMap.putString("Body", flurryMessage.getBody());
            createMap.putString("ClickAction", flurryMessage.getClickAction());
            HashMap<String, String> appData = flurryMessage.getAppData();
            WritableMap createMap2 = Arguments.createMap();
            for (String str : appData.keySet()) {
                createMap2.putString(str, appData.get(str));
            }
            createMap.putMap("Data", createMap2);
            sCallbackReturnValue = false;
            sIsCallbackReturn = !z;
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) FlurryModule.sReactApplicationContext.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(FlurryModule.FLURRY_MESSAGING_EVENT, createMap);
            waitCallbackReturn();
            return sCallbackReturnValue;
        }

        /* access modifiers changed from: private */
        public static void sendEvent(EventType eventType, String str) {
            WritableMap createMap = Arguments.createMap();
            createMap.putString("Type", eventType.getName());
            createMap.putString("Token", str);
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) FlurryModule.sReactApplicationContext.getJSModule(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(FlurryModule.FLURRY_MESSAGING_EVENT, createMap);
        }

        private static void waitCallbackReturn() {
            synchronized (FlurryModule.sReactApplicationContext) {
                if (!sIsCallbackReturn) {
                    try {
                        FlurryModule.sReactApplicationContext.wait(300);
                    } catch (InterruptedException e) {
                        Log.e(FlurryModule.TAG, "Interrupted Exception!", e);
                    }
                }
            }
        }

        /* access modifiers changed from: private */
        public static void notifyCallbackReturn(boolean z) {
            synchronized (FlurryModule.sReactApplicationContext) {
                sCallbackReturnValue = z;
                sIsCallbackReturn = true;
                FlurryModule.sReactApplicationContext.notifyAll();
            }
        }
    }
}
