package com.horcrux.svg;

import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.LinearGradient;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.RadialGradient;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.common.ReactConstants;

/* access modifiers changed from: package-private */
public class Brush {
    private ReadableArray mColors;
    private Matrix mMatrix;
    private PatternView mPattern;
    private final SVGLength[] mPoints;
    private final BrushType mType;
    private boolean mUseContentObjectBoundingBox;
    private final boolean mUseObjectBoundingBox;
    private Rect mUserSpaceBoundingBox;

    /* access modifiers changed from: package-private */
    public enum BrushType {
        LINEAR_GRADIENT,
        RADIAL_GRADIENT,
        PATTERN
    }

    /* access modifiers changed from: package-private */
    public enum BrushUnits {
        OBJECT_BOUNDING_BOX,
        USER_SPACE_ON_USE
    }

    Brush(BrushType brushType, SVGLength[] sVGLengthArr, BrushUnits brushUnits) {
        this.mType = brushType;
        this.mPoints = sVGLengthArr;
        this.mUseObjectBoundingBox = brushUnits == BrushUnits.OBJECT_BOUNDING_BOX;
    }

    /* access modifiers changed from: package-private */
    public void setContentUnits(BrushUnits brushUnits) {
        this.mUseContentObjectBoundingBox = brushUnits == BrushUnits.OBJECT_BOUNDING_BOX;
    }

    /* access modifiers changed from: package-private */
    public void setPattern(PatternView patternView) {
        this.mPattern = patternView;
    }

    private static void parseGradientStops(ReadableArray readableArray, int i, float[] fArr, int[] iArr, float f) {
        int size = readableArray.size() - i;
        for (int i2 = 0; i2 < i; i2++) {
            fArr[i2] = (float) readableArray.getDouble(size + i2);
            int i3 = i2 * 4;
            iArr[i2] = Color.argb((int) (readableArray.getDouble(i3 + 3) * 255.0d * ((double) f)), (int) (readableArray.getDouble(i3) * 255.0d), (int) (readableArray.getDouble(i3 + 1) * 255.0d), (int) (readableArray.getDouble(i3 + 2) * 255.0d));
        }
    }

    /* access modifiers changed from: package-private */
    public void setUserSpaceBoundingBox(Rect rect) {
        this.mUserSpaceBoundingBox = rect;
    }

    /* access modifiers changed from: package-private */
    public void setGradientColors(ReadableArray readableArray) {
        this.mColors = readableArray;
    }

    /* access modifiers changed from: package-private */
    public void setGradientTransform(Matrix matrix) {
        this.mMatrix = matrix;
    }

    private RectF getPaintRect(RectF rectF) {
        float f;
        if (!this.mUseObjectBoundingBox) {
            rectF = new RectF(this.mUserSpaceBoundingBox);
        }
        float width = rectF.width();
        float height = rectF.height();
        float f2 = 0.0f;
        if (this.mUseObjectBoundingBox) {
            f2 = rectF.left;
            f = rectF.top;
        } else {
            f = 0.0f;
        }
        return new RectF(f2, f, width + f2, height + f);
    }

    /* access modifiers changed from: package-private */
    public void setupPaint(Paint paint, RectF rectF, float f, float f2) {
        RectF paintRect = getPaintRect(rectF);
        float width = paintRect.width();
        float height = paintRect.height();
        float f3 = paintRect.left;
        float f4 = paintRect.top;
        float textSize = paint.getTextSize();
        if (this.mType == BrushType.PATTERN) {
            double d = (double) width;
            double d2 = (double) f3;
            double d3 = (double) f;
            double d4 = (double) textSize;
            double fromRelative = PropHelper.fromRelative(this.mPoints[0], d, d2, d3, d4);
            double d5 = (double) height;
            double d6 = (double) f4;
            double fromRelative2 = PropHelper.fromRelative(this.mPoints[1], d5, d6, d3, d4);
            double fromRelative3 = PropHelper.fromRelative(this.mPoints[2], d, d2, d3, d4);
            double fromRelative4 = PropHelper.fromRelative(this.mPoints[3], d5, d6, d3, d4);
            Matrix transform = ViewBox.getTransform(this.mPattern.getViewBox(), new RectF((float) fromRelative, (float) fromRelative2, (float) fromRelative3, (float) fromRelative4), this.mPattern.mAlign, this.mPattern.mMeetOrSlice);
            Bitmap createBitmap = Bitmap.createBitmap((int) fromRelative3, (int) fromRelative4, Bitmap.Config.ARGB_8888);
            Canvas canvas = new Canvas(createBitmap);
            canvas.concat(transform);
            this.mPattern.draw(canvas, new Paint(), f2);
            Matrix matrix = new Matrix();
            Matrix matrix2 = this.mMatrix;
            if (matrix2 != null) {
                matrix.preConcat(matrix2);
            }
            BitmapShader bitmapShader = new BitmapShader(createBitmap, Shader.TileMode.REPEAT, Shader.TileMode.REPEAT);
            bitmapShader.setLocalMatrix(matrix);
            paint.setShader(bitmapShader);
            return;
        }
        int size = this.mColors.size() / 5;
        int[] iArr = new int[size];
        float[] fArr = new float[size];
        parseGradientStops(this.mColors, size, fArr, iArr, f2);
        if (size == 1) {
            int[] iArr2 = {iArr[0], iArr[0]};
            float[] fArr2 = {fArr[0], fArr[0]};
            FLog.w(ReactConstants.TAG, "Gradient contains only on stop");
            fArr = fArr2;
            iArr = iArr2;
        }
        if (this.mType == BrushType.LINEAR_GRADIENT) {
            double d7 = (double) width;
            double d8 = (double) f3;
            double d9 = (double) f;
            double d10 = (double) textSize;
            double d11 = (double) height;
            double d12 = (double) f4;
            Shader linearGradient = new LinearGradient((float) PropHelper.fromRelative(this.mPoints[0], d7, d8, d9, d10), (float) PropHelper.fromRelative(this.mPoints[1], d11, d12, d9, d10), (float) PropHelper.fromRelative(this.mPoints[2], d7, d8, d9, d10), (float) PropHelper.fromRelative(this.mPoints[3], d11, d12, d9, d10), iArr, fArr, Shader.TileMode.CLAMP);
            if (this.mMatrix != null) {
                Matrix matrix3 = new Matrix();
                matrix3.preConcat(this.mMatrix);
                linearGradient.setLocalMatrix(matrix3);
            }
            paint.setShader(linearGradient);
        } else if (this.mType == BrushType.RADIAL_GRADIENT) {
            double d13 = (double) width;
            double d14 = (double) f;
            double d15 = (double) textSize;
            double fromRelative5 = PropHelper.fromRelative(this.mPoints[2], d13, 0.0d, d14, d15);
            double d16 = (double) height;
            double fromRelative6 = PropHelper.fromRelative(this.mPoints[3], d16, 0.0d, d14, d15);
            double fromRelative7 = PropHelper.fromRelative(this.mPoints[4], d13, (double) f3, d14, d15);
            double fromRelative8 = PropHelper.fromRelative(this.mPoints[5], d16, (double) f4, d14, d15);
            double d17 = fromRelative6 / fromRelative5;
            Shader radialGradient = new RadialGradient((float) fromRelative7, (float) (fromRelative8 / d17), (float) fromRelative5, iArr, fArr, Shader.TileMode.CLAMP);
            Matrix matrix4 = new Matrix();
            matrix4.preScale(1.0f, (float) d17);
            Matrix matrix5 = this.mMatrix;
            if (matrix5 != null) {
                matrix4.preConcat(matrix5);
            }
            radialGradient.setLocalMatrix(matrix4);
            paint.setShader(radialGradient);
        }
    }
}
