package com.swmansion.gesturehandler;

import android.app.Activity;
import android.content.Context;
import android.content.ContextWrapper;
import android.graphics.Rect;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import androidx.core.app.NotificationCompat;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.PixelUtil;
import com.swmansion.gesturehandler.GestureHandler;
import java.util.Arrays;
import kotlin.Unit;
import kotlin.collections.ArraysKt;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Reflection;
import kotlin.text.StringsKt;

public class GestureHandler<ConcreteGestureHandlerT extends GestureHandler<ConcreteGestureHandlerT>> {
    public static final int ACTION_TYPE_JS_FUNCTION_NEW_API;
    public static final int ACTION_TYPE_JS_FUNCTION_OLD_API;
    public static final int ACTION_TYPE_NATIVE_ANIMATED_EVENT;
    public static final int ACTION_TYPE_REANIMATED_WORKLET;
    public static final Companion Companion = new Companion(null);
    public static final int DIRECTION_DOWN;
    public static final int DIRECTION_LEFT;
    public static final int DIRECTION_RIGHT;
    public static final int DIRECTION_UP;
    private static final int HIT_SLOP_BOTTOM_IDX;
    private static final int HIT_SLOP_HEIGHT_IDX;
    private static final int HIT_SLOP_LEFT_IDX;
    public static final float HIT_SLOP_NONE;
    private static final int HIT_SLOP_RIGHT_IDX;
    private static final int HIT_SLOP_TOP_IDX;
    private static final int HIT_SLOP_WIDTH_IDX;
    private static final int MAX_POINTERS_COUNT;
    public static final int STATE_ACTIVE;
    public static final int STATE_BEGAN;
    public static final int STATE_CANCELLED;
    public static final int STATE_END;
    public static final int STATE_FAILED;
    public static final int STATE_UNDETERMINED;
    private static short nextEventCoalescingKey;
    private static MotionEvent.PointerCoords[] pointerCoords;
    private static MotionEvent.PointerProperties[] pointerProps;
    private int actionType;
    private int activationIndex;
    private WritableArray allTouchesPayload;
    private WritableArray changedTouchesPayload;
    private short eventCoalescingKey;
    private float[] hitSlop;
    private GestureHandlerInteractionController interactionController;
    private boolean isActive;
    private boolean isAwaiting;
    private boolean isEnabled;
    private boolean isWithinBounds;
    private float lastAbsolutePositionX;
    private float lastAbsolutePositionY;
    private float lastEventOffsetX;
    private float lastEventOffsetY;
    private boolean manualActivation;
    private boolean needsPointerData;
    private int numberOfPointers;
    private OnTouchEventListener onTouchEventListener;
    private GestureHandlerOrchestrator orchestrator;
    private boolean shouldCancelWhenOutside;
    private boolean shouldResetProgress;
    private int state;
    private int tag;
    private int touchEventType;
    private final int[] trackedPointerIDs = new int[12];
    private final PointerData[] trackedPointers;
    private int trackedPointersCount;
    private int trackedPointersIDsCount;
    private View view;
    private final int[] windowOffset;
    private float x;
    private float y;

    public void onCancel() {
    }

    public void onPrepare() {
    }

    public void onReset() {
    }

    public void onStateChange(int i, int i2) {
    }

    public void resetProgress() {
    }

    public GestureHandler() {
        int[] iArr = new int[2];
        for (int i = 0; i < 2; i++) {
            iArr[i] = 0;
        }
        this.windowOffset = iArr;
        this.isEnabled = true;
        PointerData[] pointerDataArr = new PointerData[12];
        for (int i2 = 0; i2 < 12; i2++) {
            pointerDataArr[i2] = null;
        }
        this.trackedPointers = pointerDataArr;
    }

    public final int getTag() {
        return this.tag;
    }

    public final void setTag(int i) {
        this.tag = i;
    }

    public final View getView() {
        return this.view;
    }

    public final int getState() {
        return this.state;
    }

    public final float getX() {
        return this.x;
    }

    public final float getY() {
        return this.y;
    }

    public final boolean isWithinBounds() {
        return this.isWithinBounds;
    }

    public final boolean isEnabled() {
        return this.isEnabled;
    }

    public final int getActionType() {
        return this.actionType;
    }

    public final void setActionType(int i) {
        this.actionType = i;
    }

    public final WritableArray getChangedTouchesPayload() {
        return this.changedTouchesPayload;
    }

    public final WritableArray getAllTouchesPayload() {
        return this.allTouchesPayload;
    }

    public final int getTouchEventType() {
        return this.touchEventType;
    }

    public final int getTrackedPointersCount() {
        return this.trackedPointersCount;
    }

    public final boolean getNeedsPointerData() {
        return this.needsPointerData;
    }

    public final void setNeedsPointerData(boolean z) {
        this.needsPointerData = z;
    }

    public final short getEventCoalescingKey() {
        return this.eventCoalescingKey;
    }

    public final float getLastAbsolutePositionX() {
        return this.lastAbsolutePositionX;
    }

    public final float getLastAbsolutePositionY() {
        return this.lastAbsolutePositionY;
    }

    public final int getNumberOfPointers() {
        return this.numberOfPointers;
    }

    public final ConcreteGestureHandlerT self() {
        return this;
    }

    /* JADX WARN: Type inference failed for: r0v1, types: [java.lang.Object, ConcreteGestureHandlerT extends com.swmansion.gesturehandler.GestureHandler<ConcreteGestureHandlerT>, com.swmansion.gesturehandler.GestureHandler] */
    public final ConcreteGestureHandlerT applySelf(Function1<? super ConcreteGestureHandlerT, Unit> function1) {
        Intrinsics.checkNotNullParameter(function1, "block");
        GestureHandler self = self();
        function1.invoke(self);
        return self;
    }

    public final int getActivationIndex() {
        return this.activationIndex;
    }

    public final void setActivationIndex(int i) {
        this.activationIndex = i;
    }

    public final boolean isActive() {
        return this.isActive;
    }

    public final void setActive(boolean z) {
        this.isActive = z;
    }

    public final boolean isAwaiting() {
        return this.isAwaiting;
    }

    public final void setAwaiting(boolean z) {
        this.isAwaiting = z;
    }

    public final boolean getShouldResetProgress() {
        return this.shouldResetProgress;
    }

    public final void setShouldResetProgress(boolean z) {
        this.shouldResetProgress = z;
    }

    public void dispatchStateChange(int i, int i2) {
        OnTouchEventListener onTouchEventListener2 = this.onTouchEventListener;
        if (onTouchEventListener2 != null) {
            onTouchEventListener2.onStateChange(self(), i, i2);
        }
    }

    public void dispatchHandlerUpdate(MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
        OnTouchEventListener onTouchEventListener2 = this.onTouchEventListener;
        if (onTouchEventListener2 != null) {
            onTouchEventListener2.onHandlerUpdate(self(), motionEvent);
        }
    }

    public void dispatchTouchEvent() {
        OnTouchEventListener onTouchEventListener2;
        if (this.changedTouchesPayload != null && (onTouchEventListener2 = this.onTouchEventListener) != null) {
            onTouchEventListener2.onTouchEvent(self());
        }
    }

    public void resetConfig() {
        this.needsPointerData = false;
        this.manualActivation = false;
        this.shouldCancelWhenOutside = false;
        this.isEnabled = true;
        this.hitSlop = null;
    }

    public final boolean hasCommonPointers(GestureHandler<?> gestureHandler) {
        Intrinsics.checkNotNullParameter(gestureHandler, "other");
        int length = this.trackedPointerIDs.length;
        for (int i = 0; i < length; i++) {
            if (!(this.trackedPointerIDs[i] == -1 || gestureHandler.trackedPointerIDs[i] == -1)) {
                return true;
            }
        }
        return false;
    }

    /* renamed from: setEnabled$lambda-3$lambda-2 */
    public static final void m6setEnabled$lambda3$lambda2(GestureHandler gestureHandler) {
        Intrinsics.checkNotNullParameter(gestureHandler, "$this_applySelf");
        gestureHandler.cancel();
    }

    public final ConcreteGestureHandlerT setHitSlop(float f) {
        return setHitSlop(f, f, f, f, Float.NaN, Float.NaN);
    }

    public final void prepare(View view2, GestureHandlerOrchestrator gestureHandlerOrchestrator) {
        if (this.view == null && this.orchestrator == null) {
            Arrays.fill(this.trackedPointerIDs, -1);
            this.trackedPointersIDsCount = 0;
            this.state = 0;
            this.view = view2;
            this.orchestrator = gestureHandlerOrchestrator;
            View view3 = null;
            Window window = getWindow(view2 != null ? view2.getContext() : null);
            if (window != null) {
                view3 = window.getDecorView();
            }
            if (view3 != null) {
                Rect rect = new Rect();
                view3.getWindowVisibleDisplayFrame(rect);
                this.windowOffset[0] = rect.left;
                this.windowOffset[1] = rect.top;
            } else {
                int[] iArr = this.windowOffset;
                iArr[0] = 0;
                iArr[1] = 0;
            }
            onPrepare();
            return;
        }
        throw new IllegalStateException("Already prepared or hasn't been reset".toString());
    }

    private final Window getWindow(Context context) {
        if (context == null) {
            return null;
        }
        if (context instanceof Activity) {
            return ((Activity) context).getWindow();
        }
        if (context instanceof ContextWrapper) {
            return getWindow(((ContextWrapper) context).getBaseContext());
        }
        return null;
    }

    private final int findNextLocalPointerId() {
        int[] iArr;
        int i = 0;
        while (i < this.trackedPointersIDsCount) {
            int i2 = 0;
            while (true) {
                iArr = this.trackedPointerIDs;
                if (i2 < iArr.length && iArr[i2] != i) {
                    i2++;
                }
            }
            if (i2 == iArr.length) {
                return i;
            }
            i++;
        }
        return i;
    }

    public final void startTrackingPointer(int i) {
        int[] iArr = this.trackedPointerIDs;
        if (iArr[i] == -1) {
            iArr[i] = findNextLocalPointerId();
            this.trackedPointersIDsCount++;
        }
    }

    public final void stopTrackingPointer(int i) {
        int[] iArr = this.trackedPointerIDs;
        if (iArr[i] != -1) {
            iArr[i] = -1;
            this.trackedPointersIDsCount--;
        }
    }

    private final boolean needAdapt(MotionEvent motionEvent) {
        if (motionEvent.getPointerCount() != this.trackedPointersIDsCount) {
            return true;
        }
        int length = this.trackedPointerIDs.length;
        for (int i = 0; i < length; i++) {
            int i2 = this.trackedPointerIDs[i];
            if (!(i2 == -1 || i2 == i)) {
                return true;
            }
        }
        return false;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v9, types: [android.view.MotionEvent$PointerProperties[]] */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00ba  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00c1  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00c3  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x00c6  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x013f  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0150  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x0154  */
    /* JADX WARNING: Removed duplicated region for block: B:80:0x00b6 A[EDGE_INSN: B:80:0x00b6->B:42:0x00b6 ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Unknown variable types count: 1 */
    private final MotionEvent adaptEvent(MotionEvent motionEvent) {
        int i;
        int pointerCount;
        int i2;
        MotionEvent.PointerCoords[] pointerCoordsArr;
        MotionEvent.PointerProperties[] pointerPropertiesArr;
        MotionEvent.PointerCoords[] pointerCoordsArr2;
        ?? r3;
        if (!needAdapt(motionEvent)) {
            return motionEvent;
        }
        int actionMasked = motionEvent.getActionMasked();
        int i3 = 2;
        if (actionMasked != 0) {
            if (actionMasked != 1) {
                if (actionMasked != 5) {
                    if (actionMasked != 6) {
                        i3 = actionMasked;
                        i = -1;
                        Companion.initPointerProps(this.trackedPointersIDsCount);
                        float rawX = motionEvent.getRawX() - motionEvent.getX();
                        float rawY = motionEvent.getRawY() - motionEvent.getY();
                        motionEvent.offsetLocation(rawX, rawY);
                        pointerCount = motionEvent.getPointerCount();
                        int i4 = i3;
                        i2 = 0;
                        int i5 = 0;
                        while (true) {
                            pointerCoordsArr = null;
                            if (i2 >= pointerCount) {
                                break;
                            }
                            int pointerId = motionEvent.getPointerId(i2);
                            if (this.trackedPointerIDs[pointerId] != -1) {
                                MotionEvent.PointerProperties[] pointerPropertiesArr2 = pointerProps;
                                if (pointerPropertiesArr2 == null) {
                                    Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                                    pointerPropertiesArr2 = null;
                                }
                                motionEvent.getPointerProperties(i2, pointerPropertiesArr2[i5]);
                                MotionEvent.PointerProperties[] pointerPropertiesArr3 = pointerProps;
                                if (pointerPropertiesArr3 == null) {
                                    Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                                    pointerPropertiesArr3 = null;
                                }
                                MotionEvent.PointerProperties pointerProperties = pointerPropertiesArr3[i5];
                                Intrinsics.checkNotNull(pointerProperties);
                                pointerProperties.id = this.trackedPointerIDs[pointerId];
                                MotionEvent.PointerCoords[] pointerCoordsArr3 = pointerCoords;
                                if (pointerCoordsArr3 == null) {
                                    Intrinsics.throwUninitializedPropertyAccessException("pointerCoords");
                                } else {
                                    pointerCoordsArr = pointerCoordsArr3;
                                }
                                motionEvent.getPointerCoords(i2, pointerCoordsArr[i5]);
                                if (i2 == i) {
                                    i4 |= i5 << 8;
                                }
                                i5++;
                            }
                            i2++;
                        }
                        pointerPropertiesArr = pointerProps;
                        if (pointerPropertiesArr == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                            pointerPropertiesArr = null;
                        }
                        if (!(pointerPropertiesArr.length == 0)) {
                            MotionEvent.PointerCoords[] pointerCoordsArr4 = pointerCoords;
                            if (pointerCoordsArr4 == null) {
                                Intrinsics.throwUninitializedPropertyAccessException("pointerCoords");
                                pointerCoordsArr4 = null;
                            }
                            if (!(pointerCoordsArr4.length == 0)) {
                                try {
                                    long downTime = motionEvent.getDownTime();
                                    long eventTime = motionEvent.getEventTime();
                                    MotionEvent.PointerProperties[] pointerPropertiesArr4 = pointerProps;
                                    if (pointerPropertiesArr4 == null) {
                                        Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                                        pointerPropertiesArr4 = null;
                                    }
                                    MotionEvent.PointerCoords[] pointerCoordsArr5 = pointerCoords;
                                    if (pointerCoordsArr5 == null) {
                                        Intrinsics.throwUninitializedPropertyAccessException("pointerCoords");
                                        pointerCoordsArr5 = null;
                                    }
                                    MotionEvent obtain = MotionEvent.obtain(downTime, eventTime, i4, i5, pointerPropertiesArr4, pointerCoordsArr5, motionEvent.getMetaState(), motionEvent.getButtonState(), motionEvent.getXPrecision(), motionEvent.getYPrecision(), motionEvent.getDeviceId(), motionEvent.getEdgeFlags(), motionEvent.getSource(), motionEvent.getFlags());
                                    Intrinsics.checkNotNullExpressionValue(obtain, "obtain(\n        event.do…      event.flags\n      )");
                                    float f = -rawX;
                                    float f2 = -rawY;
                                    motionEvent.offsetLocation(f, f2);
                                    obtain.offsetLocation(f, f2);
                                    return obtain;
                                } catch (IllegalArgumentException e) {
                                    throw new AdaptEventException(this, motionEvent, e);
                                }
                            }
                        }
                        StringBuilder sb = new StringBuilder();
                        sb.append("pointerCoords.size=");
                        pointerCoordsArr2 = pointerCoords;
                        if (pointerCoordsArr2 == null) {
                            Intrinsics.throwUninitializedPropertyAccessException("pointerCoords");
                            pointerCoordsArr2 = null;
                        }
                        sb.append(pointerCoordsArr2.length);
                        sb.append(", pointerProps.size=");
                        r3 = pointerProps;
                        if (r3 == 0) {
                            Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                        } else {
                            pointerCoordsArr = r3;
                        }
                        sb.append(pointerCoordsArr.length);
                        throw new IllegalStateException(sb.toString());
                    }
                }
            }
            i = motionEvent.getActionIndex();
            if (this.trackedPointerIDs[motionEvent.getPointerId(i)] != -1) {
                i3 = this.trackedPointersIDsCount == 1 ? 1 : 6;
            }
            Companion.initPointerProps(this.trackedPointersIDsCount);
            float rawX2 = motionEvent.getRawX() - motionEvent.getX();
            float rawY2 = motionEvent.getRawY() - motionEvent.getY();
            motionEvent.offsetLocation(rawX2, rawY2);
            pointerCount = motionEvent.getPointerCount();
            int i42 = i3;
            i2 = 0;
            int i52 = 0;
            while (true) {
                pointerCoordsArr = null;
                if (i2 >= pointerCount) {
                }
                i2++;
            }
            pointerPropertiesArr = pointerProps;
            if (pointerPropertiesArr == null) {
            }
            if (!(pointerPropertiesArr.length == 0)) {
            }
            StringBuilder sb2 = new StringBuilder();
            sb2.append("pointerCoords.size=");
            pointerCoordsArr2 = pointerCoords;
            if (pointerCoordsArr2 == null) {
            }
            sb2.append(pointerCoordsArr2.length);
            sb2.append(", pointerProps.size=");
            r3 = pointerProps;
            if (r3 == 0) {
            }
            sb2.append(pointerCoordsArr.length);
            throw new IllegalStateException(sb2.toString());
        }
        i = motionEvent.getActionIndex();
        if (this.trackedPointerIDs[motionEvent.getPointerId(i)] != -1) {
            i3 = this.trackedPointersIDsCount == 1 ? 0 : 5;
        }
        Companion.initPointerProps(this.trackedPointersIDsCount);
        float rawX22 = motionEvent.getRawX() - motionEvent.getX();
        float rawY22 = motionEvent.getRawY() - motionEvent.getY();
        motionEvent.offsetLocation(rawX22, rawY22);
        pointerCount = motionEvent.getPointerCount();
        int i422 = i3;
        i2 = 0;
        int i522 = 0;
        while (true) {
            pointerCoordsArr = null;
            if (i2 >= pointerCount) {
            }
            i2++;
        }
        pointerPropertiesArr = pointerProps;
        if (pointerPropertiesArr == null) {
        }
        if (!(pointerPropertiesArr.length == 0)) {
        }
        StringBuilder sb22 = new StringBuilder();
        sb22.append("pointerCoords.size=");
        pointerCoordsArr2 = pointerCoords;
        if (pointerCoordsArr2 == null) {
        }
        sb22.append(pointerCoordsArr2.length);
        sb22.append(", pointerProps.size=");
        r3 = pointerProps;
        if (r3 == 0) {
        }
        sb22.append(pointerCoordsArr.length);
        throw new IllegalStateException(sb22.toString());
    }

    public static final class AdaptEventException extends Exception {
        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public AdaptEventException(GestureHandler<?> gestureHandler, MotionEvent motionEvent, IllegalArgumentException illegalArgumentException) {
            super(StringsKt.trimIndent("\n    handler: " + Reflection.getOrCreateKotlinClass(gestureHandler.getClass()).getSimpleName() + "\n    state: " + gestureHandler.getState() + "\n    view: " + gestureHandler.getView() + "\n    orchestrator: " + ((GestureHandler) gestureHandler).orchestrator + "\n    isEnabled: " + gestureHandler.isEnabled() + "\n    isActive: " + gestureHandler.isActive() + "\n    isAwaiting: " + gestureHandler.isAwaiting() + "\n    trackedPointersCount: " + ((GestureHandler) gestureHandler).trackedPointersIDsCount + "\n    trackedPointers: " + ArraysKt.joinToString$default(((GestureHandler) gestureHandler).trackedPointerIDs, (CharSequence) ", ", (CharSequence) null, (CharSequence) null, 0, (CharSequence) null, (Function1) null, 62, (Object) null) + "\n    while handling event: " + motionEvent + "\n  "), illegalArgumentException);
            Intrinsics.checkNotNullParameter(gestureHandler, "handler");
            Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
            Intrinsics.checkNotNullParameter(illegalArgumentException, "e");
        }
    }

    public final void handle(MotionEvent motionEvent) {
        int i;
        Intrinsics.checkNotNullParameter(motionEvent, "origEvent");
        if (this.isEnabled && (i = this.state) != 3 && i != 1 && i != 5 && this.trackedPointersIDsCount >= 1) {
            try {
                MotionEvent adaptEvent = adaptEvent(motionEvent);
                this.x = adaptEvent.getX();
                this.y = adaptEvent.getY();
                this.numberOfPointers = adaptEvent.getPointerCount();
                boolean isWithinBounds2 = isWithinBounds(this.view, this.x, this.y);
                this.isWithinBounds = isWithinBounds2;
                if (!this.shouldCancelWhenOutside || isWithinBounds2) {
                    this.lastAbsolutePositionX = GestureUtils.INSTANCE.getLastPointerX(adaptEvent, true);
                    this.lastAbsolutePositionY = GestureUtils.INSTANCE.getLastPointerY(adaptEvent, true);
                    this.lastEventOffsetX = adaptEvent.getRawX() - adaptEvent.getX();
                    this.lastEventOffsetY = adaptEvent.getRawY() - adaptEvent.getY();
                    onHandle(adaptEvent);
                    if (!Intrinsics.areEqual(adaptEvent, motionEvent)) {
                        adaptEvent.recycle();
                        return;
                    }
                    return;
                }
                int i2 = this.state;
                if (i2 == 4) {
                    cancel();
                } else if (i2 == 2) {
                    fail();
                }
            } catch (AdaptEventException unused) {
                fail();
            }
        }
    }

    private final void dispatchTouchDownEvent(MotionEvent motionEvent) {
        this.changedTouchesPayload = null;
        this.touchEventType = 1;
        int pointerId = motionEvent.getPointerId(motionEvent.getActionIndex());
        this.trackedPointers[pointerId] = new PointerData(pointerId, motionEvent.getX(motionEvent.getActionIndex()), motionEvent.getY(motionEvent.getActionIndex()), (motionEvent.getX(motionEvent.getActionIndex()) + (motionEvent.getRawX() - motionEvent.getX())) - ((float) this.windowOffset[0]), (motionEvent.getY(motionEvent.getActionIndex()) + (motionEvent.getRawY() - motionEvent.getY())) - ((float) this.windowOffset[1]));
        this.trackedPointersCount++;
        PointerData pointerData = this.trackedPointers[pointerId];
        Intrinsics.checkNotNull(pointerData);
        addChangedPointer(pointerData);
        extractAllPointersData();
        dispatchTouchEvent();
    }

    private final void dispatchTouchUpEvent(MotionEvent motionEvent) {
        extractAllPointersData();
        this.changedTouchesPayload = null;
        this.touchEventType = 3;
        int pointerId = motionEvent.getPointerId(motionEvent.getActionIndex());
        this.trackedPointers[pointerId] = new PointerData(pointerId, motionEvent.getX(motionEvent.getActionIndex()), motionEvent.getY(motionEvent.getActionIndex()), (motionEvent.getX(motionEvent.getActionIndex()) + (motionEvent.getRawX() - motionEvent.getX())) - ((float) this.windowOffset[0]), (motionEvent.getY(motionEvent.getActionIndex()) + (motionEvent.getRawY() - motionEvent.getY())) - ((float) this.windowOffset[1]));
        PointerData pointerData = this.trackedPointers[pointerId];
        Intrinsics.checkNotNull(pointerData);
        addChangedPointer(pointerData);
        this.trackedPointers[pointerId] = null;
        this.trackedPointersCount--;
        dispatchTouchEvent();
    }

    private final void dispatchTouchMoveEvent(MotionEvent motionEvent) {
        this.changedTouchesPayload = null;
        this.touchEventType = 2;
        float rawX = motionEvent.getRawX() - motionEvent.getX();
        float rawY = motionEvent.getRawY() - motionEvent.getY();
        int pointerCount = motionEvent.getPointerCount();
        int i = 0;
        for (int i2 = 0; i2 < pointerCount; i2++) {
            PointerData pointerData = this.trackedPointers[motionEvent.getPointerId(i2)];
            if (pointerData != null) {
                if (pointerData.getX() == motionEvent.getX(i2)) {
                    if (pointerData.getY() == motionEvent.getY(i2)) {
                    }
                }
                pointerData.setX(motionEvent.getX(i2));
                pointerData.setY(motionEvent.getY(i2));
                pointerData.setAbsoluteX((motionEvent.getX(i2) + rawX) - ((float) this.windowOffset[0]));
                pointerData.setAbsoluteY((motionEvent.getY(i2) + rawY) - ((float) this.windowOffset[1]));
                addChangedPointer(pointerData);
                i++;
            }
        }
        if (i > 0) {
            extractAllPointersData();
            dispatchTouchEvent();
        }
    }

    public final void updatePointerData(MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
        if (motionEvent.getActionMasked() == 0 || motionEvent.getActionMasked() == 5) {
            dispatchTouchDownEvent(motionEvent);
            dispatchTouchMoveEvent(motionEvent);
        } else if (motionEvent.getActionMasked() == 1 || motionEvent.getActionMasked() == 6) {
            dispatchTouchMoveEvent(motionEvent);
            dispatchTouchUpEvent(motionEvent);
        } else if (motionEvent.getActionMasked() == 2) {
            dispatchTouchMoveEvent(motionEvent);
        }
    }

    private final void extractAllPointersData() {
        this.allTouchesPayload = null;
        PointerData[] pointerDataArr = this.trackedPointers;
        for (PointerData pointerData : pointerDataArr) {
            if (pointerData != null) {
                addPointerToAll(pointerData);
            }
        }
    }

    private final void cancelPointers() {
        this.touchEventType = 4;
        this.changedTouchesPayload = null;
        extractAllPointersData();
        PointerData[] pointerDataArr = this.trackedPointers;
        for (PointerData pointerData : pointerDataArr) {
            if (pointerData != null) {
                addChangedPointer(pointerData);
            }
        }
        this.trackedPointersCount = 0;
        ArraysKt.fill$default(this.trackedPointers, (Object) null, 0, 0, 6, (Object) null);
        dispatchTouchEvent();
    }

    private final void addChangedPointer(PointerData pointerData) {
        if (this.changedTouchesPayload == null) {
            this.changedTouchesPayload = Arguments.createArray();
        }
        WritableArray writableArray = this.changedTouchesPayload;
        Intrinsics.checkNotNull(writableArray);
        writableArray.pushMap(createPointerData(pointerData));
    }

    private final void addPointerToAll(PointerData pointerData) {
        if (this.allTouchesPayload == null) {
            this.allTouchesPayload = Arguments.createArray();
        }
        WritableArray writableArray = this.allTouchesPayload;
        Intrinsics.checkNotNull(writableArray);
        writableArray.pushMap(createPointerData(pointerData));
    }

    private final WritableMap createPointerData(PointerData pointerData) {
        WritableMap createMap = Arguments.createMap();
        createMap.putInt("id", pointerData.getPointerId());
        createMap.putDouble("x", (double) PixelUtil.toDIPFromPixel(pointerData.getX()));
        createMap.putDouble("y", (double) PixelUtil.toDIPFromPixel(pointerData.getY()));
        createMap.putDouble("absoluteX", (double) PixelUtil.toDIPFromPixel(pointerData.getAbsoluteX()));
        createMap.putDouble("absoluteY", (double) PixelUtil.toDIPFromPixel(pointerData.getAbsoluteY()));
        return createMap;
    }

    public final WritableArray consumeChangedTouchesPayload() {
        WritableArray writableArray = this.changedTouchesPayload;
        this.changedTouchesPayload = null;
        return writableArray;
    }

    public final WritableArray consumeAllTouchesPayload() {
        WritableArray writableArray = this.allTouchesPayload;
        this.allTouchesPayload = null;
        return writableArray;
    }

    private final void moveToState(int i) {
        UiThreadUtil.assertOnUiThread();
        if (this.state != i) {
            if (this.trackedPointersCount > 0 && (i == 5 || i == 3 || i == 1)) {
                cancelPointers();
            }
            int i2 = this.state;
            this.state = i;
            if (i == 4) {
                short s = nextEventCoalescingKey;
                nextEventCoalescingKey = (short) (s + 1);
                this.eventCoalescingKey = s;
            }
            GestureHandlerOrchestrator gestureHandlerOrchestrator = this.orchestrator;
            Intrinsics.checkNotNull(gestureHandlerOrchestrator);
            gestureHandlerOrchestrator.onHandlerStateChange(this, i, i2);
            onStateChange(i, i2);
        }
    }

    public final boolean wantEvents() {
        int i;
        if (!this.isEnabled || (i = this.state) == 1 || i == 3 || i == 5 || this.trackedPointersIDsCount <= 0) {
            return false;
        }
        return true;
    }

    public boolean shouldRequireToWaitForFailure(GestureHandler<?> gestureHandler) {
        GestureHandlerInteractionController gestureHandlerInteractionController;
        Intrinsics.checkNotNullParameter(gestureHandler, "handler");
        if (gestureHandler == this || (gestureHandlerInteractionController = this.interactionController) == null) {
            return false;
        }
        return gestureHandlerInteractionController.shouldRequireHandlerToWaitForFailure(this, gestureHandler);
    }

    public final boolean shouldWaitForHandlerFailure(GestureHandler<?> gestureHandler) {
        GestureHandlerInteractionController gestureHandlerInteractionController;
        Intrinsics.checkNotNullParameter(gestureHandler, "handler");
        if (gestureHandler == this || (gestureHandlerInteractionController = this.interactionController) == null) {
            return false;
        }
        return gestureHandlerInteractionController.shouldWaitForHandlerFailure(this, gestureHandler);
    }

    public boolean shouldRecognizeSimultaneously(GestureHandler<?> gestureHandler) {
        Intrinsics.checkNotNullParameter(gestureHandler, "handler");
        if (gestureHandler == this) {
            return true;
        }
        GestureHandlerInteractionController gestureHandlerInteractionController = this.interactionController;
        if (gestureHandlerInteractionController != null) {
            return gestureHandlerInteractionController.shouldRecognizeSimultaneously(this, gestureHandler);
        }
        return false;
    }

    public boolean shouldBeCancelledBy(GestureHandler<?> gestureHandler) {
        GestureHandlerInteractionController gestureHandlerInteractionController;
        Intrinsics.checkNotNullParameter(gestureHandler, "handler");
        if (gestureHandler == this || (gestureHandlerInteractionController = this.interactionController) == null) {
            return false;
        }
        return gestureHandlerInteractionController.shouldHandlerBeCancelledBy(this, gestureHandler);
    }

    public final boolean isWithinBounds(View view2, float f, float f2) {
        float f3;
        Intrinsics.checkNotNull(view2);
        float width = (float) view2.getWidth();
        float height = (float) view2.getHeight();
        float[] fArr = this.hitSlop;
        float f4 = 0.0f;
        if (fArr != null) {
            Intrinsics.checkNotNull(fArr);
            float f5 = fArr[0];
            float[] fArr2 = this.hitSlop;
            Intrinsics.checkNotNull(fArr2);
            float f6 = fArr2[1];
            float[] fArr3 = this.hitSlop;
            Intrinsics.checkNotNull(fArr3);
            float f7 = fArr3[2];
            float[] fArr4 = this.hitSlop;
            Intrinsics.checkNotNull(fArr4);
            float f8 = fArr4[3];
            Companion companion = Companion;
            float f9 = companion.hitSlopSet(f5) ? 0.0f - f5 : 0.0f;
            if (companion.hitSlopSet(f6)) {
                f4 = 0.0f - f6;
            }
            if (companion.hitSlopSet(f7)) {
                width += f7;
            }
            if (companion.hitSlopSet(f8)) {
                height += f8;
            }
            float[] fArr5 = this.hitSlop;
            Intrinsics.checkNotNull(fArr5);
            float f10 = fArr5[4];
            float[] fArr6 = this.hitSlop;
            Intrinsics.checkNotNull(fArr6);
            float f11 = fArr6[5];
            if (companion.hitSlopSet(f10)) {
                if (!companion.hitSlopSet(f5)) {
                    f9 = width - f10;
                } else if (!companion.hitSlopSet(f7)) {
                    width = f10 + f9;
                }
            }
            if (companion.hitSlopSet(f11)) {
                if (!companion.hitSlopSet(f6)) {
                    f4 = height - f11;
                } else if (!companion.hitSlopSet(f8)) {
                    height = f4 + f11;
                }
            }
            f3 = f4;
            f4 = f9;
        } else {
            f3 = 0.0f;
        }
        if (f4 <= f && f <= width) {
            if (f3 <= f2 && f2 <= height) {
                return true;
            }
        }
        return false;
    }

    public final void cancel() {
        int i = this.state;
        if (i == 4 || i == 0 || i == 2) {
            onCancel();
            moveToState(3);
        }
    }

    public final void fail() {
        int i = this.state;
        if (i == 4 || i == 0 || i == 2) {
            moveToState(1);
        }
    }

    public final void activate() {
        activate(false);
    }

    public void activate(boolean z) {
        if (!this.manualActivation || z) {
            int i = this.state;
            if (i == 0 || i == 2) {
                moveToState(4);
            }
        }
    }

    public final void begin() {
        if (this.state == 0) {
            moveToState(2);
        }
    }

    public final void end() {
        int i = this.state;
        if (i == 2 || i == 4) {
            moveToState(5);
        }
    }

    public void onHandle(MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
        moveToState(1);
    }

    public final void reset() {
        this.view = null;
        this.orchestrator = null;
        Arrays.fill(this.trackedPointerIDs, -1);
        this.trackedPointersIDsCount = 0;
        this.trackedPointersCount = 0;
        ArraysKt.fill$default(this.trackedPointers, (Object) null, 0, 0, 6, (Object) null);
        this.touchEventType = 0;
        onReset();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: com.swmansion.gesturehandler.GestureHandler<ConcreteGestureHandlerT extends com.swmansion.gesturehandler.GestureHandler<ConcreteGestureHandlerT>> */
    /* JADX WARN: Multi-variable type inference failed */
    public final GestureHandler<?> setOnTouchEventListener(OnTouchEventListener onTouchEventListener2) {
        this.onTouchEventListener = onTouchEventListener2;
        return this;
    }

    public String toString() {
        String str;
        View view2 = this.view;
        if (view2 == null) {
            str = null;
        } else {
            Intrinsics.checkNotNull(view2);
            str = view2.getClass().getSimpleName();
        }
        return getClass().getSimpleName() + "@[" + this.tag + "]:" + str;
    }

    public final float getLastRelativePositionX() {
        return this.lastAbsolutePositionX - this.lastEventOffsetX;
    }

    public final float getLastRelativePositionY() {
        return this.lastAbsolutePositionY - this.lastEventOffsetY;
    }

    public final float getLastPositionInWindowX() {
        return this.lastAbsolutePositionX - ((float) this.windowOffset[0]);
    }

    public final float getLastPositionInWindowY() {
        return this.lastAbsolutePositionY - ((float) this.windowOffset[1]);
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        public final String stateToString(int i) {
            if (i == 0) {
                return "UNDETERMINED";
            }
            if (i == 1) {
                return "FAILED";
            }
            if (i == 2) {
                return "BEGIN";
            }
            if (i == 3) {
                return "CANCELLED";
            }
            if (i == 4) {
                return "ACTIVE";
            }
            if (i != 5) {
                return null;
            }
            return "END";
        }

        private Companion() {
        }

        private final void initPointerProps(int i) {
            if (GestureHandler.pointerProps == null) {
                GestureHandler.pointerProps = new MotionEvent.PointerProperties[12];
                GestureHandler.pointerCoords = new MotionEvent.PointerCoords[12];
            }
            while (i > 0) {
                MotionEvent.PointerProperties[] pointerPropertiesArr = GestureHandler.pointerProps;
                MotionEvent.PointerCoords[] pointerCoordsArr = null;
                if (pointerPropertiesArr == null) {
                    Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                    pointerPropertiesArr = null;
                }
                int i2 = i - 1;
                if (pointerPropertiesArr[i2] == null) {
                    MotionEvent.PointerProperties[] pointerPropertiesArr2 = GestureHandler.pointerProps;
                    if (pointerPropertiesArr2 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("pointerProps");
                        pointerPropertiesArr2 = null;
                    }
                    pointerPropertiesArr2[i2] = new MotionEvent.PointerProperties();
                    MotionEvent.PointerCoords[] pointerCoordsArr2 = GestureHandler.pointerCoords;
                    if (pointerCoordsArr2 == null) {
                        Intrinsics.throwUninitializedPropertyAccessException("pointerCoords");
                    } else {
                        pointerCoordsArr = pointerCoordsArr2;
                    }
                    pointerCoordsArr[i2] = new MotionEvent.PointerCoords();
                    i--;
                } else {
                    return;
                }
            }
        }

        private final boolean hitSlopSet(float f) {
            return !Float.isNaN(f);
        }
    }

    public static final class PointerData {
        private float absoluteX;
        private float absoluteY;
        private final int pointerId;
        private float x;
        private float y;

        public static /* synthetic */ PointerData copy$default(PointerData pointerData, int i, float f, float f2, float f3, float f4, int i2, Object obj) {
            if ((i2 & 1) != 0) {
                i = pointerData.pointerId;
            }
            if ((i2 & 2) != 0) {
                f = pointerData.x;
            }
            if ((i2 & 4) != 0) {
                f2 = pointerData.y;
            }
            if ((i2 & 8) != 0) {
                f3 = pointerData.absoluteX;
            }
            if ((i2 & 16) != 0) {
                f4 = pointerData.absoluteY;
            }
            return pointerData.copy(i, f, f2, f3, f4);
        }

        public final int component1() {
            return this.pointerId;
        }

        public final float component2() {
            return this.x;
        }

        public final float component3() {
            return this.y;
        }

        public final float component4() {
            return this.absoluteX;
        }

        public final float component5() {
            return this.absoluteY;
        }

        public final PointerData copy(int i, float f, float f2, float f3, float f4) {
            return new PointerData(i, f, f2, f3, f4);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof PointerData)) {
                return false;
            }
            PointerData pointerData = (PointerData) obj;
            return this.pointerId == pointerData.pointerId && Intrinsics.areEqual(Float.valueOf(this.x), Float.valueOf(pointerData.x)) && Intrinsics.areEqual(Float.valueOf(this.y), Float.valueOf(pointerData.y)) && Intrinsics.areEqual(Float.valueOf(this.absoluteX), Float.valueOf(pointerData.absoluteX)) && Intrinsics.areEqual(Float.valueOf(this.absoluteY), Float.valueOf(pointerData.absoluteY));
        }

        public int hashCode() {
            return (((((((this.pointerId * 31) + Float.floatToIntBits(this.x)) * 31) + Float.floatToIntBits(this.y)) * 31) + Float.floatToIntBits(this.absoluteX)) * 31) + Float.floatToIntBits(this.absoluteY);
        }

        public String toString() {
            return "PointerData(pointerId=" + this.pointerId + ", x=" + this.x + ", y=" + this.y + ", absoluteX=" + this.absoluteX + ", absoluteY=" + this.absoluteY + ')';
        }

        public PointerData(int i, float f, float f2, float f3, float f4) {
            this.pointerId = i;
            this.x = f;
            this.y = f2;
            this.absoluteX = f3;
            this.absoluteY = f4;
        }

        public final int getPointerId() {
            return this.pointerId;
        }

        public final float getX() {
            return this.x;
        }

        public final void setX(float f) {
            this.x = f;
        }

        public final float getY() {
            return this.y;
        }

        public final void setY(float f) {
            this.y = f;
        }

        public final float getAbsoluteX() {
            return this.absoluteX;
        }

        public final void setAbsoluteX(float f) {
            this.absoluteX = f;
        }

        public final float getAbsoluteY() {
            return this.absoluteY;
        }

        public final void setAbsoluteY(float f) {
            this.absoluteY = f;
        }
    }

    public final ConcreteGestureHandlerT setShouldCancelWhenOutside(boolean z) {
        ConcreteGestureHandlerT concretegesturehandlert = (ConcreteGestureHandlerT) self();
        concretegesturehandlert.shouldCancelWhenOutside = z;
        return concretegesturehandlert;
    }

    public final ConcreteGestureHandlerT setEnabled(boolean z) {
        ConcreteGestureHandlerT concretegesturehandlert = (ConcreteGestureHandlerT) self();
        if (!(concretegesturehandlert.view == null || concretegesturehandlert.isEnabled == z)) {
            UiThreadUtil.runOnUiThread(new GestureHandler$$ExternalSyntheticLambda0(concretegesturehandlert));
        }
        concretegesturehandlert.isEnabled = z;
        return concretegesturehandlert;
    }

    public final ConcreteGestureHandlerT setManualActivation(boolean z) {
        ConcreteGestureHandlerT concretegesturehandlert = (ConcreteGestureHandlerT) self();
        concretegesturehandlert.manualActivation = z;
        return concretegesturehandlert;
    }

    public final ConcreteGestureHandlerT setHitSlop(float f, float f2, float f3, float f4, float f5, float f6) {
        ConcreteGestureHandlerT concretegesturehandlert = (ConcreteGestureHandlerT) self();
        if (concretegesturehandlert.hitSlop == null) {
            concretegesturehandlert.hitSlop = new float[6];
        }
        float[] fArr = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr);
        boolean z = false;
        fArr[0] = f;
        float[] fArr2 = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr2);
        fArr2[1] = f2;
        float[] fArr3 = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr3);
        fArr3[2] = f3;
        float[] fArr4 = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr4);
        fArr4[3] = f4;
        float[] fArr5 = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr5);
        fArr5[4] = f5;
        float[] fArr6 = concretegesturehandlert.hitSlop;
        Intrinsics.checkNotNull(fArr6);
        fArr6[5] = f6;
        Companion companion = Companion;
        if (!companion.hitSlopSet(f5) || !companion.hitSlopSet(f) || !companion.hitSlopSet(f3)) {
            if (!companion.hitSlopSet(f5) || companion.hitSlopSet(f) || companion.hitSlopSet(f3)) {
                if (!companion.hitSlopSet(f6) || !companion.hitSlopSet(f4) || !companion.hitSlopSet(f2)) {
                    if (!companion.hitSlopSet(f6) || companion.hitSlopSet(f4) || companion.hitSlopSet(f2)) {
                        z = true;
                    }
                    if (z) {
                        return concretegesturehandlert;
                    }
                    throw new IllegalArgumentException("When height is set one of top or bottom pads need to be defined".toString());
                }
                throw new IllegalArgumentException("Cannot have all of top, bottom and height defined".toString());
            }
            throw new IllegalArgumentException("When width is set one of left or right pads need to be defined".toString());
        }
        throw new IllegalArgumentException("Cannot have all of left, right and width defined".toString());
    }

    public final ConcreteGestureHandlerT setInteractionController(GestureHandlerInteractionController gestureHandlerInteractionController) {
        ConcreteGestureHandlerT concretegesturehandlert = (ConcreteGestureHandlerT) self();
        concretegesturehandlert.interactionController = gestureHandlerInteractionController;
        return concretegesturehandlert;
    }
}
