package com.swmansion.rnscreens;

import android.view.View;
import android.view.ViewParent;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleObserver;
import java.util.HashMap;
import java.util.Map;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

public final class LifecycleHelper {
    public static final Companion Companion = new Companion(null);
    private final View.OnLayoutChangeListener mRegisterOnLayoutChange = new LifecycleHelper$mRegisterOnLayoutChange$1(this);
    private final Map<View, Lifecycle> mViewToLifecycleMap = new HashMap();

    /* access modifiers changed from: public */
    private final void registerViewWithLifecycleOwner(View view) {
        Fragment findNearestScreenFragmentAncestor = Companion.findNearestScreenFragmentAncestor(view);
        if (findNearestScreenFragmentAncestor != null && (view instanceof LifecycleObserver)) {
            Lifecycle lifecycle = findNearestScreenFragmentAncestor.getLifecycle();
            Intrinsics.checkNotNullExpressionValue(lifecycle, "parent.lifecycle");
            lifecycle.addObserver((LifecycleObserver) view);
            this.mViewToLifecycleMap.put(view, lifecycle);
        }
    }

    public final <T extends View & LifecycleObserver> void register(T t) {
        t.addOnLayoutChangeListener(this.mRegisterOnLayoutChange);
    }

    public final <T extends View & LifecycleObserver> void unregister(T t) {
        Lifecycle lifecycle = this.mViewToLifecycleMap.get(t);
        if (lifecycle != null) {
            lifecycle.removeObserver(t);
        }
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final Fragment findNearestScreenFragmentAncestor(View view) {
            Intrinsics.checkNotNullParameter(view, "view");
            ViewParent parent = view.getParent();
            while (parent != null && !(parent instanceof Screen)) {
                parent = parent.getParent();
            }
            if (parent != null) {
                return ((Screen) parent).getFragment();
            }
            return null;
        }
    }
}
