package expo.modules.kotlin.records;

import com.facebook.react.bridge.Dynamic;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableType;
import expo.modules.kotlin.allocators.ObjectConstructor;
import expo.modules.kotlin.allocators.ObjectConstructorFactory;
import expo.modules.kotlin.exception.CodedException;
import expo.modules.kotlin.exception.FieldCastException;
import expo.modules.kotlin.exception.FieldRequiredException;
import expo.modules.kotlin.exception.RecordCastException;
import expo.modules.kotlin.exception.UnexpectedException;
import expo.modules.kotlin.records.Record;
import expo.modules.kotlin.types.TypeConverter;
import expo.modules.kotlin.types.TypeConverterProvider;
import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.JvmClassMappingKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KClass;
import kotlin.reflect.KClassifier;
import kotlin.reflect.KProperty1;
import kotlin.reflect.KType;
import kotlin.reflect.full.KClasses;
import kotlin.reflect.jvm.ReflectJvmMapping;
import kotlin.text.StringsKt;

@Metadata(d1 = {"\u0000X\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010$\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0003\u0018\u0000*\b\b\u0000\u0010\u0001*\u00020\u00022\b\u0012\u0004\u0012\u0002H\u00010\u0003:\u0001\u001eB\u0015\u0012\u0006\u0010\u0004\u001a\u00020\u0005\u0012\u0006\u0010\u0006\u001a\u00020\u0007¢\u0006\u0002\u0010\bJ\u0015\u0010\u0012\u001a\u00028\u00002\u0006\u0010\u0013\u001a\u00020\u0014H\u0016¢\u0006\u0002\u0010\u0015J\"\u0010\u0016\u001a\b\u0012\u0004\u0012\u0002H\u00010\u0017\"\u0004\b\u0001\u0010\u00012\f\u0010\u0018\u001a\b\u0012\u0004\u0012\u0002H\u00010\u0019H\u0002J&\u0010\u001a\u001a\f\u0012\b\u0012\u0006\u0012\u0002\b\u00030\u001c0\u001b2\u0012\u0010\u001d\u001a\u000e\u0012\u0006\b\u0001\u0012\u00020\u000e\u0012\u0002\b\u00030\rH\u0002R\u000e\u0010\u0004\u001a\u00020\u0005X\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u0004¢\u0006\u0002\n\u0000R&\u0010\u000b\u001a\u001a\u0012\u0010\u0012\u000e\u0012\u0006\b\u0001\u0012\u00020\u000e\u0012\u0002\b\u00030\r\u0012\u0004\u0012\u00020\u000f0\fX\u0004¢\u0006\u0002\n\u0000R\u0011\u0010\u0006\u001a\u00020\u0007¢\u0006\b\n\u0000\u001a\u0004\b\u0010\u0010\u0011¨\u0006\u001f"}, d2 = {"Lexpo/modules/kotlin/records/RecordTypeConverter;", "T", "Lexpo/modules/kotlin/records/Record;", "Lexpo/modules/kotlin/types/TypeConverter;", "converterProvider", "Lexpo/modules/kotlin/types/TypeConverterProvider;", "type", "Lkotlin/reflect/KType;", "(Lexpo/modules/kotlin/types/TypeConverterProvider;Lkotlin/reflect/KType;)V", "objectConstructorFactory", "Lexpo/modules/kotlin/allocators/ObjectConstructorFactory;", "propertyDescriptors", "", "Lkotlin/reflect/KProperty1;", "", "Lexpo/modules/kotlin/records/RecordTypeConverter$PropertyDescriptor;", "getType", "()Lkotlin/reflect/KType;", "convertNonOptional", "value", "Lcom/facebook/react/bridge/Dynamic;", "(Lcom/facebook/react/bridge/Dynamic;)Lexpo/modules/kotlin/records/Record;", "getObjectConstructor", "Lexpo/modules/kotlin/allocators/ObjectConstructor;", "clazz", "Ljava/lang/Class;", "getValidators", "", "Lexpo/modules/kotlin/records/FieldValidator;", "property", "PropertyDescriptor", "expo-modules-core_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: RecordTypeConverter.kt */
public final class RecordTypeConverter<T extends Record> extends TypeConverter<T> {
    private final TypeConverterProvider converterProvider;
    private final ObjectConstructorFactory objectConstructorFactory = new ObjectConstructorFactory();
    private final Map<KProperty1<? extends Object, ?>, PropertyDescriptor> propertyDescriptors;
    private final KType type;

    public final KType getType() {
        return this.type;
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public RecordTypeConverter(TypeConverterProvider typeConverterProvider, KType kType) {
        super(kType.isMarkedNullable());
        Pair pair;
        T t;
        Intrinsics.checkNotNullParameter(typeConverterProvider, "converterProvider");
        Intrinsics.checkNotNullParameter(kType, "type");
        this.converterProvider = typeConverterProvider;
        this.type = kType;
        KClassifier classifier = kType.getClassifier();
        Objects.requireNonNull(classifier, "null cannot be cast to non-null type kotlin.reflect.KClass<*>");
        Collection<KProperty1<? extends Object, ?>> memberProperties = KClasses.getMemberProperties((KClass) classifier);
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(memberProperties, 10));
        for (KProperty1<? extends Object, ?> kProperty1 : memberProperties) {
            KProperty1<? extends Object, ?> kProperty12 = kProperty1;
            Iterator<T> it = kProperty12.getAnnotations().iterator();
            while (true) {
                pair = null;
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (t instanceof Field) {
                    break;
                }
            }
            T t2 = t;
            if (t2 != null) {
                TypeConverter<?> obtainTypeConverter = this.converterProvider.obtainTypeConverter(kProperty1.getReturnType());
                Iterator<T> it2 = kProperty12.getAnnotations().iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        break;
                    }
                    T next = it2.next();
                    if (next instanceof Required) {
                        pair = next;
                        break;
                    }
                }
                pair = TuplesKt.to(kProperty1, new PropertyDescriptor(obtainTypeConverter, t2, ((Required) pair) != null, getValidators(kProperty1)));
            }
            arrayList.add(pair);
        }
        this.propertyDescriptors = MapsKt.toMap(CollectionsKt.filterNotNull(arrayList));
    }

    @Override // expo.modules.kotlin.types.TypeConverter
    public T convertNonOptional(Dynamic dynamic) {
        Intrinsics.checkNotNullParameter(dynamic, "value");
        try {
            ReadableMap asMap = dynamic.asMap();
            KClassifier classifier = this.type.getClassifier();
            if (classifier != null) {
                T construct = getObjectConstructor(JvmClassMappingKt.getJavaClass((KClass) classifier)).construct();
                for (Map.Entry<KProperty1<? extends Object, ?>, PropertyDescriptor> entry : this.propertyDescriptors.entrySet()) {
                    KProperty1<? extends Object, ?> key = entry.getKey();
                    PropertyDescriptor value = entry.getValue();
                    String key2 = value.getFieldAnnotation().key();
                    if (StringsKt.isBlank(key2)) {
                        key2 = null;
                    }
                    if (key2 == null) {
                        key2 = key.getName();
                    }
                    if (asMap.hasKey(key2)) {
                        Dynamic dynamic2 = asMap.getDynamic(key2);
                        Intrinsics.checkNotNullExpressionValue(dynamic2, "jsMap.getDynamic(jsKey)");
                        try {
                            Field javaField = ReflectJvmMapping.getJavaField(key);
                            Intrinsics.checkNotNull(javaField);
                            try {
                                Object convert = value.getTypeConverter().convert(dynamic2);
                                if (convert != null) {
                                    Iterator<T> it = value.getValidators().iterator();
                                    while (it.hasNext()) {
                                        it.next().validate(convert);
                                    }
                                }
                                javaField.setAccessible(true);
                                javaField.set(construct, convert);
                                Unit unit = Unit.INSTANCE;
                            } catch (CodedException e) {
                                String name = key.getName();
                                KType returnType = key.getReturnType();
                                ReadableType type2 = dynamic2.getType();
                                Intrinsics.checkNotNullExpressionValue(type2, "type");
                                throw new FieldCastException(name, returnType, type2, e);
                            } catch (Throwable th) {
                                String name2 = key.getName();
                                KType returnType2 = key.getReturnType();
                                ReadableType type3 = dynamic2.getType();
                                Intrinsics.checkNotNullExpressionValue(type3, "type");
                                throw new FieldCastException(name2, returnType2, type3, new UnexpectedException(th));
                            }
                        } finally {
                            dynamic2.recycle();
                        }
                    } else if (value.isRequired()) {
                        throw new FieldRequiredException(key);
                    }
                }
                return construct;
            }
            throw new NullPointerException("null cannot be cast to non-null type kotlin.reflect.KClass<*>");
        } catch (CodedException e2) {
            throw new RecordCastException(this.type, e2);
        } catch (Throwable th2) {
            throw new RecordCastException(this.type, new UnexpectedException(th2));
        }
    }

    private final <T> ObjectConstructor<T> getObjectConstructor(Class<T> cls) {
        return this.objectConstructorFactory.get(cls);
    }

    private final List<FieldValidator<?>> getValidators(KProperty1<? extends Object, ?> kProperty1) {
        Pair pair;
        T t;
        List<Annotation> annotations = kProperty1.getAnnotations();
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(annotations, 10));
        for (T t2 : annotations) {
            Iterator<T> it = JvmClassMappingKt.getAnnotationClass(t2).getAnnotations().iterator();
            while (true) {
                pair = null;
                if (!it.hasNext()) {
                    t = null;
                    break;
                }
                t = it.next();
                if (t instanceof BindUsing) {
                    break;
                }
            }
            T t3 = t;
            if (t3 != null) {
                pair = TuplesKt.to(t2, t3);
            }
            arrayList.add(pair);
        }
        List<Pair> filterNotNull = CollectionsKt.filterNotNull(arrayList);
        ArrayList arrayList2 = new ArrayList(CollectionsKt.collectionSizeOrDefault(filterNotNull, 10));
        for (Pair pair2 : filterNotNull) {
            arrayList2.add(((ValidationBinder) KClasses.createInstance(Reflection.getOrCreateKotlinClass(((BindUsing) pair2.component2()).binder()))).bind((Annotation) pair2.component1(), kProperty1.getReturnType()));
        }
        return arrayList2;
    }

    /* access modifiers changed from: private */
    @Metadata(d1 = {"\u00004\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000b\n\u0000\n\u0002\u0010 \n\u0002\u0018\u0002\n\u0002\b\u0010\n\u0002\u0010\b\n\u0000\n\u0002\u0010\u000e\n\u0000\b\b\u0018\u00002\u00020\u0001B3\u0012\n\u0010\u0002\u001a\u0006\u0012\u0002\b\u00030\u0003\u0012\u0006\u0010\u0004\u001a\u00020\u0005\u0012\u0006\u0010\u0006\u001a\u00020\u0007\u0012\u0010\u0010\b\u001a\f\u0012\b\u0012\u0006\u0012\u0002\b\u00030\n0\t¢\u0006\u0002\u0010\u000bJ\r\u0010\u0013\u001a\u0006\u0012\u0002\b\u00030\u0003HÆ\u0003J\t\u0010\u0014\u001a\u00020\u0005HÆ\u0003J\t\u0010\u0015\u001a\u00020\u0007HÆ\u0003J\u0013\u0010\u0016\u001a\f\u0012\b\u0012\u0006\u0012\u0002\b\u00030\n0\tHÆ\u0003J?\u0010\u0017\u001a\u00020\u00002\f\b\u0002\u0010\u0002\u001a\u0006\u0012\u0002\b\u00030\u00032\b\b\u0002\u0010\u0004\u001a\u00020\u00052\b\b\u0002\u0010\u0006\u001a\u00020\u00072\u0012\b\u0002\u0010\b\u001a\f\u0012\b\u0012\u0006\u0012\u0002\b\u00030\n0\tHÆ\u0001J\u0013\u0010\u0018\u001a\u00020\u00072\b\u0010\u0019\u001a\u0004\u0018\u00010\u0001HÖ\u0003J\t\u0010\u001a\u001a\u00020\u001bHÖ\u0001J\t\u0010\u001c\u001a\u00020\u001dHÖ\u0001R\u0011\u0010\u0004\u001a\u00020\u0005¢\u0006\b\n\u0000\u001a\u0004\b\f\u0010\rR\u0011\u0010\u0006\u001a\u00020\u0007¢\u0006\b\n\u0000\u001a\u0004\b\u0006\u0010\u000eR\u0015\u0010\u0002\u001a\u0006\u0012\u0002\b\u00030\u0003¢\u0006\b\n\u0000\u001a\u0004\b\u000f\u0010\u0010R\u001b\u0010\b\u001a\f\u0012\b\u0012\u0006\u0012\u0002\b\u00030\n0\t¢\u0006\b\n\u0000\u001a\u0004\b\u0011\u0010\u0012¨\u0006\u001e"}, d2 = {"Lexpo/modules/kotlin/records/RecordTypeConverter$PropertyDescriptor;", "", "typeConverter", "Lexpo/modules/kotlin/types/TypeConverter;", "fieldAnnotation", "Lexpo/modules/kotlin/records/Field;", "isRequired", "", "validators", "", "Lexpo/modules/kotlin/records/FieldValidator;", "(Lexpo/modules/kotlin/types/TypeConverter;Lexpo/modules/kotlin/records/Field;ZLjava/util/List;)V", "getFieldAnnotation", "()Lexpo/modules/kotlin/records/Field;", "()Z", "getTypeConverter", "()Lexpo/modules/kotlin/types/TypeConverter;", "getValidators", "()Ljava/util/List;", "component1", "component2", "component3", "component4", "copy", "equals", "other", "hashCode", "", "toString", "", "expo-modules-core_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: RecordTypeConverter.kt */
    public static final class PropertyDescriptor {
        private final Field fieldAnnotation;
        private final boolean isRequired;
        private final TypeConverter<?> typeConverter;
        private final List<FieldValidator<?>> validators;

        /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: expo.modules.kotlin.records.RecordTypeConverter$PropertyDescriptor */
        /* JADX WARN: Multi-variable type inference failed */
        public static /* synthetic */ PropertyDescriptor copy$default(PropertyDescriptor propertyDescriptor, TypeConverter typeConverter2, Field field, boolean z, List list, int i, Object obj) {
            if ((i & 1) != 0) {
                typeConverter2 = propertyDescriptor.typeConverter;
            }
            if ((i & 2) != 0) {
                field = propertyDescriptor.fieldAnnotation;
            }
            if ((i & 4) != 0) {
                z = propertyDescriptor.isRequired;
            }
            if ((i & 8) != 0) {
                list = propertyDescriptor.validators;
            }
            return propertyDescriptor.copy(typeConverter2, field, z, list);
        }

        public final TypeConverter<?> component1() {
            return this.typeConverter;
        }

        public final Field component2() {
            return this.fieldAnnotation;
        }

        public final boolean component3() {
            return this.isRequired;
        }

        public final List<FieldValidator<?>> component4() {
            return this.validators;
        }

        public final PropertyDescriptor copy(TypeConverter<?> typeConverter2, Field field, boolean z, List<? extends FieldValidator<?>> list) {
            Intrinsics.checkNotNullParameter(typeConverter2, "typeConverter");
            Intrinsics.checkNotNullParameter(field, "fieldAnnotation");
            Intrinsics.checkNotNullParameter(list, "validators");
            return new PropertyDescriptor(typeConverter2, field, z, list);
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof PropertyDescriptor)) {
                return false;
            }
            PropertyDescriptor propertyDescriptor = (PropertyDescriptor) obj;
            return Intrinsics.areEqual(this.typeConverter, propertyDescriptor.typeConverter) && Intrinsics.areEqual(this.fieldAnnotation, propertyDescriptor.fieldAnnotation) && this.isRequired == propertyDescriptor.isRequired && Intrinsics.areEqual(this.validators, propertyDescriptor.validators);
        }

        public int hashCode() {
            int hashCode = ((this.typeConverter.hashCode() * 31) + this.fieldAnnotation.hashCode()) * 31;
            boolean z = this.isRequired;
            if (z) {
                z = true;
            }
            int i = z ? 1 : 0;
            int i2 = z ? 1 : 0;
            int i3 = z ? 1 : 0;
            return ((hashCode + i) * 31) + this.validators.hashCode();
        }

        public String toString() {
            TypeConverter<?> typeConverter2 = this.typeConverter;
            Field field = this.fieldAnnotation;
            boolean z = this.isRequired;
            List<FieldValidator<?>> list = this.validators;
            return "PropertyDescriptor(typeConverter=" + typeConverter2 + ", fieldAnnotation=" + field + ", isRequired=" + z + ", validators=" + list + ")";
        }

        /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: java.util.List<? extends expo.modules.kotlin.records.FieldValidator<?>> */
        /* JADX WARN: Multi-variable type inference failed */
        public PropertyDescriptor(TypeConverter<?> typeConverter2, Field field, boolean z, List<? extends FieldValidator<?>> list) {
            Intrinsics.checkNotNullParameter(typeConverter2, "typeConverter");
            Intrinsics.checkNotNullParameter(field, "fieldAnnotation");
            Intrinsics.checkNotNullParameter(list, "validators");
            this.typeConverter = typeConverter2;
            this.fieldAnnotation = field;
            this.isRequired = z;
            this.validators = list;
        }

        public final TypeConverter<?> getTypeConverter() {
            return this.typeConverter;
        }

        public final Field getFieldAnnotation() {
            return this.fieldAnnotation;
        }

        public final boolean isRequired() {
            return this.isRequired;
        }

        public final List<FieldValidator<?>> getValidators() {
            return this.validators;
        }
    }
}
