package expo.modules.kotlin.types;

import android.os.Bundle;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import expo.modules.kotlin.records.Record;
import java.util.Map;
import kotlin.Unit;
import kotlin.jvm.internal.Intrinsics;

public final class JSTypeConverter {
    public static final JSTypeConverter INSTANCE = new JSTypeConverter();

    public interface ContainerProvider {
        WritableArray createArray();

        WritableMap createMap();
    }

    private JSTypeConverter() {
    }

    public static final class DefaultContainerProvider implements ContainerProvider {
        public static final DefaultContainerProvider INSTANCE = new DefaultContainerProvider();

        private DefaultContainerProvider() {
        }

        @Override // expo.modules.kotlin.types.JSTypeConverter.ContainerProvider
        public WritableMap createMap() {
            WritableMap createMap = Arguments.createMap();
            Intrinsics.checkNotNullExpressionValue(createMap, "createMap()");
            return createMap;
        }

        @Override // expo.modules.kotlin.types.JSTypeConverter.ContainerProvider
        public WritableArray createArray() {
            WritableArray createArray = Arguments.createArray();
            Intrinsics.checkNotNullExpressionValue(createArray, "createArray()");
            return createArray;
        }
    }

    public static /* synthetic */ Object convertToJSValue$default(JSTypeConverter jSTypeConverter, Object obj, ContainerProvider containerProvider, int i, Object obj2) {
        if ((i & 2) != 0) {
            containerProvider = DefaultContainerProvider.INSTANCE;
        }
        return jSTypeConverter.convertToJSValue(obj, containerProvider);
    }

    public final Object convertToJSValue(Object obj, ContainerProvider containerProvider) {
        Intrinsics.checkNotNullParameter(containerProvider, "containerProvider");
        if (obj == null ? true : obj instanceof Unit) {
            return null;
        }
        if (obj instanceof Bundle) {
            return JSTypeConverterHelperKt.toJSValue((Bundle) obj, containerProvider);
        }
        if (obj instanceof Iterable) {
            return JSTypeConverterHelperKt.toJSValue((Iterable) obj, containerProvider);
        }
        if (obj instanceof Object[]) {
            return JSTypeConverterHelperKt.toJSValue((Object[]) obj, containerProvider);
        }
        if (obj instanceof int[]) {
            return JSTypeConverterHelperKt.toJSValue((int[]) obj, containerProvider);
        }
        if (obj instanceof float[]) {
            return JSTypeConverterHelperKt.toJSValue((float[]) obj, containerProvider);
        }
        if (obj instanceof double[]) {
            return JSTypeConverterHelperKt.toJSValue((double[]) obj, containerProvider);
        }
        if (obj instanceof Map) {
            return JSTypeConverterHelperKt.toJSValue((Map) obj, containerProvider);
        }
        if (obj instanceof Enum) {
            return JSTypeConverterHelperKt.toJSValue((Enum) obj);
        }
        return obj instanceof Record ? JSTypeConverterHelperKt.toJSValue((Record) obj, containerProvider) : obj;
    }
}
