package expo.modules.kotlin.types;

import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import expo.modules.kotlin.exception.MissingTypeConverter;
import expo.modules.kotlin.records.Record;
import expo.modules.kotlin.records.RecordTypeConverter;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import kotlin.Metadata;
import kotlin.Pair;
import kotlin.TuplesKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.JvmClassMappingKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KClass;
import kotlin.reflect.KClassifier;
import kotlin.reflect.KType;
import kotlin.reflect.full.KClasses;
import kotlin.reflect.full.KClassifiers;

@Metadata(d1 = {"\u0000.\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010$\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010%\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u000b\n\u0002\b\u0003\bÆ\u0002\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J \u0010\n\u001a\u0012\u0012\u0004\u0012\u00020\u0005\u0012\b\u0012\u0006\u0012\u0002\b\u00030\u00060\u00042\u0006\u0010\u000b\u001a\u00020\fH\u0002J\u0014\u0010\r\u001a\u0006\u0012\u0002\b\u00030\u00062\u0006\u0010\u000e\u001a\u00020\u0005H\u0016R\u001e\u0010\u0003\u001a\u0012\u0012\u0004\u0012\u00020\u0005\u0012\b\u0012\u0006\u0012\u0002\b\u00030\u00060\u0004X\u0004¢\u0006\u0002\n\u0000R\"\u0010\u0007\u001a\u0016\u0012\b\u0012\u0006\u0012\u0002\b\u00030\t\u0012\b\u0012\u0006\u0012\u0002\b\u00030\u00060\bX\u0004¢\u0006\u0002\n\u0000¨\u0006\u000f"}, d2 = {"Lexpo/modules/kotlin/types/TypeConverterProviderImpl;", "Lexpo/modules/kotlin/types/TypeConverterProvider;", "()V", "cachedConverters", "", "Lkotlin/reflect/KType;", "Lexpo/modules/kotlin/types/TypeConverter;", "cachedRecordConverters", "", "Lkotlin/reflect/KClass;", "createCashedConverters", "isOptional", "", "obtainTypeConverter", "type", "expo-modules-core_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: TypeConverterProvider.kt */
public final class TypeConverterProviderImpl implements TypeConverterProvider {
    public static final TypeConverterProviderImpl INSTANCE;
    private static final Map<KType, TypeConverter<?>> cachedConverters;
    private static final Map<KClass<?>, TypeConverter<?>> cachedRecordConverters = new LinkedHashMap();

    private TypeConverterProviderImpl() {
    }

    static {
        TypeConverterProviderImpl typeConverterProviderImpl = new TypeConverterProviderImpl();
        INSTANCE = typeConverterProviderImpl;
        cachedConverters = MapsKt.plus(typeConverterProviderImpl.createCashedConverters(false), typeConverterProviderImpl.createCashedConverters(true));
    }

    @Override // expo.modules.kotlin.types.TypeConverterProvider
    public TypeConverter<?> obtainTypeConverter(KType kType) {
        Intrinsics.checkNotNullParameter(kType, "type");
        TypeConverter<?> typeConverter = cachedConverters.get(kType);
        if (typeConverter != null) {
            return typeConverter;
        }
        KClassifier classifier = kType.getClassifier();
        KClass<?> kClass = classifier instanceof KClass ? (KClass) classifier : null;
        if (kClass == null) {
            throw new MissingTypeConverter(kType);
        } else if (JvmClassMappingKt.getJavaClass((KClass) kClass).isArray()) {
            return new ArrayTypeConverter(this, kType);
        } else {
            if (KClasses.isSubclassOf(kClass, Reflection.getOrCreateKotlinClass(List.class))) {
                return new ListTypeConverter(this, kType);
            }
            if (KClasses.isSubclassOf(kClass, Reflection.getOrCreateKotlinClass(Map.class))) {
                return new MapTypeConverter(this, kType);
            }
            if (KClasses.isSubclassOf(kClass, Reflection.getOrCreateKotlinClass(Pair.class))) {
                return new PairTypeConverter(this, kType);
            }
            if (KClasses.isSubclassOf(kClass, Reflection.getOrCreateKotlinClass(Object[].class))) {
                return new ArrayTypeConverter(this, kType);
            }
            if (JvmClassMappingKt.getJavaClass((KClass) kClass).isEnum()) {
                return new EnumTypeConverter(kClass, kType.isMarkedNullable());
            }
            Map<KClass<?>, TypeConverter<?>> map = cachedRecordConverters;
            TypeConverter<?> typeConverter2 = map.get(kClass);
            if (typeConverter2 != null) {
                return typeConverter2;
            }
            if (KClasses.isSubclassOf(kClass, Reflection.getOrCreateKotlinClass(Record.class))) {
                RecordTypeConverter recordTypeConverter = new RecordTypeConverter(this, kType);
                map.put(kClass, recordTypeConverter);
                return recordTypeConverter;
            }
            throw new MissingTypeConverter(kType);
        }
    }

    private final Map<KType, TypeConverter<?>> createCashedConverters(boolean z) {
        IntTypeConverter intTypeConverter = new IntTypeConverter(z);
        DoubleTypeConverter doubleTypeConverter = new DoubleTypeConverter(z);
        FloatTypeConverter floatTypeConverter = new FloatTypeConverter(z);
        BoolTypeConverter boolTypeConverter = new BoolTypeConverter(z);
        return MapsKt.mapOf(TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Integer.TYPE), null, z, null, 5, null), intTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Integer.class), null, z, null, 5, null), intTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Double.TYPE), null, z, null, 5, null), doubleTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Double.class), null, z, null, 5, null), doubleTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Float.TYPE), null, z, null, 5, null), floatTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Float.class), null, z, null, 5, null), floatTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Boolean.TYPE), null, z, null, 5, null), boolTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(Boolean.class), null, z, null, 5, null), boolTypeConverter), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(String.class), null, z, null, 5, null), new StringTypeConverter(z)), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(ReadableArray.class), null, z, null, 5, null), new ReadableArrayTypeConverter(z)), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(ReadableMap.class), null, z, null, 5, null), new ReadableMapTypeConverter(z)), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(int[].class), null, z, null, 5, null), new PrimitiveIntArrayTypeConverter(z)), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(double[].class), null, z, null, 5, null), new PrimitiveDoubleArrayTypeConverter(z)), TuplesKt.to(KClassifiers.createType$default(Reflection.getOrCreateKotlinClass(float[].class), null, z, null, 5, null), new PrimitiveFloatArrayTypeConverter(z)));
    }
}
