package expo.modules.kotlin.views;

import android.content.Context;
import android.util.Log;
import android.view.View;
import androidx.autofill.HintConstants;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.common.MapBuilder;
import expo.modules.kotlin.ModuleHolder;
import expo.modules.kotlin.callbacks.ViewCallbackDelegate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;
import kotlin.Metadata;
import kotlin.TuplesKt;
import kotlin.Unit;
import kotlin.collections.CollectionsKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.JvmClassMappingKt;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.reflect.KClass;
import kotlin.reflect.KProperty1;
import kotlin.reflect.full.KClasses;
import kotlin.reflect.jvm.KCallablesJvm;

@Metadata(d1 = {"\u0000L\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0006\n\u0002\u0010\u000e\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0002\b\u0003\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010$\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0000\u0018\u00002\u00020\u0001B\r\u0012\u0006\u0010\u0002\u001a\u00020\u0003¢\u0006\u0002\u0010\u0004J\u0010\u0010\u0014\u001a\u00020\u00152\u0006\u0010\u0016\u001a\u00020\u0017H\u0002J\u000e\u0010\u0018\u001a\u00020\u00172\u0006\u0010\u0019\u001a\u00020\u001aJ\u0014\u0010\u001b\u001a\u0010\u0012\u0004\u0012\u00020\r\u0012\u0004\u0012\u00020\u0001\u0018\u00010\u001cJ\u0015\u0010\u001d\u001a\u0004\u0018\u00010\u00152\u0006\u0010\u0016\u001a\u00020\u0017¢\u0006\u0002\u0010\u001eJ\u0016\u0010\u001f\u001a\u00020\u00152\u0006\u0010\u0016\u001a\u00020\u00172\u0006\u0010 \u001a\u00020!R\u0014\u0010\u0005\u001a\u00020\u00068BX\u0004¢\u0006\u0006\u001a\u0004\b\u0007\u0010\bR\u001a\u0010\u0002\u001a\u00020\u0003X\u000e¢\u0006\u000e\n\u0000\u001a\u0004\b\t\u0010\n\"\u0004\b\u000b\u0010\u0004R\u0011\u0010\f\u001a\u00020\r8F¢\u0006\u0006\u001a\u0004\b\u000e\u0010\u000fR\u0016\u0010\u0010\u001a\u0004\u0018\u00010\u00118@X\u0004¢\u0006\u0006\u001a\u0004\b\u0012\u0010\u0013¨\u0006\""}, d2 = {"Lexpo/modules/kotlin/views/ViewManagerWrapperDelegate;", "", "moduleHolder", "Lexpo/modules/kotlin/ModuleHolder;", "(Lexpo/modules/kotlin/ModuleHolder;)V", "definition", "Lexpo/modules/kotlin/views/ViewManagerDefinition;", "getDefinition", "()Lexpo/modules/kotlin/views/ViewManagerDefinition;", "getModuleHolder$expo_modules_core_release", "()Lexpo/modules/kotlin/ModuleHolder;", "setModuleHolder$expo_modules_core_release", HintConstants.AUTOFILL_HINT_NAME, "", "getName", "()Ljava/lang/String;", "viewGroupDefinition", "Lexpo/modules/kotlin/views/ViewGroupDefinition;", "getViewGroupDefinition$expo_modules_core_release", "()Lexpo/modules/kotlin/views/ViewGroupDefinition;", "configureView", "", "view", "Landroid/view/View;", "createView", "context", "Landroid/content/Context;", "getExportedCustomDirectEventTypeConstants", "", "onDestroy", "(Landroid/view/View;)Lkotlin/Unit;", "setProxiedProperties", "proxiedProperties", "Lcom/facebook/react/bridge/ReadableMap;", "expo-modules-core_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: ViewManagerWrapperDelegate.kt */
public final class ViewManagerWrapperDelegate {
    private ModuleHolder moduleHolder;

    public ViewManagerWrapperDelegate(ModuleHolder moduleHolder2) {
        Intrinsics.checkNotNullParameter(moduleHolder2, "moduleHolder");
        this.moduleHolder = moduleHolder2;
    }

    public final ModuleHolder getModuleHolder$expo_modules_core_release() {
        return this.moduleHolder;
    }

    public final void setModuleHolder$expo_modules_core_release(ModuleHolder moduleHolder2) {
        Intrinsics.checkNotNullParameter(moduleHolder2, "<set-?>");
        this.moduleHolder = moduleHolder2;
    }

    private final ViewManagerDefinition getDefinition() {
        ViewManagerDefinition viewManagerDefinition = this.moduleHolder.getDefinition().getViewManagerDefinition();
        if (viewManagerDefinition != null) {
            return viewManagerDefinition;
        }
        throw new IllegalArgumentException("Required value was null.".toString());
    }

    public final ViewGroupDefinition getViewGroupDefinition$expo_modules_core_release() {
        return getDefinition().getViewGroupDefinition();
    }

    public final String getName() {
        return this.moduleHolder.getName();
    }

    public final View createView(Context context) {
        Intrinsics.checkNotNullParameter(context, "context");
        View createView = getDefinition().createView(context);
        configureView(createView);
        return createView;
    }

    public final void setProxiedProperties(View view, ReadableMap readableMap) {
        Intrinsics.checkNotNullParameter(view, "view");
        Intrinsics.checkNotNullParameter(readableMap, "proxiedProperties");
        getDefinition().setProps(readableMap, view);
    }

    public final Unit onDestroy(View view) {
        Intrinsics.checkNotNullParameter(view, "view");
        Function1<View, Unit> onViewDestroys = getDefinition().getOnViewDestroys();
        if (onViewDestroys == null) {
            return null;
        }
        onViewDestroys.invoke(view);
        return Unit.INSTANCE;
    }

    public final Map<String, Object> getExportedCustomDirectEventTypeConstants() {
        String[] names;
        MapBuilder.Builder builder = MapBuilder.builder();
        CallbacksDefinition callbacksDefinition = getDefinition().getCallbacksDefinition();
        if (!(callbacksDefinition == null || (names = callbacksDefinition.getNames()) == null)) {
            int i = 0;
            int length = names.length;
            while (i < length) {
                String str = names[i];
                i++;
                builder.put(str, MapBuilder.of("registrationName", str));
            }
        }
        return builder.build();
    }

    private final void configureView(View view) {
        String[] names;
        CallbacksDefinition callbacksDefinition = getDefinition().getCallbacksDefinition();
        if (!(callbacksDefinition == null || (names = callbacksDefinition.getNames()) == null)) {
            KClass kotlinClass = JvmClassMappingKt.getKotlinClass(view.getClass());
            Collection<KProperty1> declaredMemberProperties = KClasses.getDeclaredMemberProperties(kotlinClass);
            ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(declaredMemberProperties, 10));
            for (KProperty1 kProperty1 : declaredMemberProperties) {
                arrayList.add(TuplesKt.to(kProperty1.getName(), kProperty1));
            }
            Map map = MapsKt.toMap(arrayList);
            int i = 0;
            int length = names.length;
            while (i < length) {
                String str = names[i];
                i++;
                Object obj = map.get(str);
                if (obj == null) {
                    String simpleName = kotlinClass.getSimpleName();
                    Log.w("ExpoModuleCore", "Property `" + str + "` does not exist in " + simpleName + ".");
                } else {
                    KProperty1 kProperty12 = (KProperty1) obj;
                    KCallablesJvm.setAccessible(kProperty12, true);
                    Object delegate = kProperty12.getDelegate(view);
                    if (delegate == null) {
                        String simpleName2 = kotlinClass.getSimpleName();
                        Log.w("ExpoModulesCore", "Property delegate for `" + str + "` in " + simpleName2 + " does not exist.");
                    } else {
                        ViewCallbackDelegate viewCallbackDelegate = delegate instanceof ViewCallbackDelegate ? (ViewCallbackDelegate) delegate : null;
                        if (viewCallbackDelegate == null) {
                            Log.w("ExpoModulesCore", "Property delegate for `" + str + "` cannot be cased to `ViewCallbackDelegate`.");
                        } else {
                            viewCallbackDelegate.setValidated$expo_modules_core_release(true);
                        }
                    }
                }
            }
        }
    }
}
