package fr.greweb.reactnativeviewshot;

import android.app.Activity;
import android.content.res.Resources;
import android.graphics.Matrix;
import android.os.Build;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import androidx.core.util.Pair;
import java.util.Locale;
import java.util.Stack;
import javax.annotation.Nullable;

public final class DebugViews {
    public static final Matrix EMPTY_MATRIX = new Matrix();
    public static final int LOG_MSG_LIMIT = 200;

    public static int longDebug(String str, String str2) {
        int i = 0;
        while (str2.length() > 0) {
            int indexOf = str2.indexOf("\n");
            int min = Math.min(str2.length(), Math.min(indexOf < 0 ? 200 : indexOf + 1, 200));
            Log.d(str, String.format(Locale.US, "%02d: %s", Integer.valueOf(i), str2.substring(0, min)));
            str2 = str2.substring(min);
            i++;
        }
        return i;
    }

    public static String logViewHierarchy(Activity activity) {
        View findViewById = activity.findViewById(16908290);
        if (findViewById != null) {
            return logViewHierarchy(findViewById);
        }
        return "Activity [" + activity.getClass().getSimpleName() + "] is not initialized yet. ";
    }

    private static String logViewHierarchy(View view) {
        StringBuilder sb = new StringBuilder(8192);
        sb.append("\n");
        Resources resources = view.getResources();
        Stack stack = new Stack();
        stack.push(Pair.create("", view));
        while (!stack.empty()) {
            Pair pair = (Pair) stack.pop();
            S s = pair.second;
            F f = pair.first;
            boolean z = stack.empty() || !f.equals(((Pair) stack.peek()).first);
            StringBuilder sb2 = new StringBuilder();
            sb2.append("");
            sb2.append((String) f);
            sb2.append(z ? "└── " : "├── ");
            sb.append(sb2.toString() + s.getClass().getSimpleName() + dumpProperties(resources, s));
            sb.append("\n");
            if (s instanceof ViewGroup) {
                S s2 = s;
                for (int childCount = s2.getChildCount() - 1; childCount >= 0; childCount--) {
                    StringBuilder sb3 = new StringBuilder();
                    sb3.append((String) f);
                    sb3.append(z ? "    " : "│   ");
                    stack.push(Pair.create(sb3.toString(), s2.getChildAt(childCount)));
                }
            }
        }
        return sb.toString();
    }

    private static String dumpProperties(Resources resources, View view) {
        StringBuilder sb = new StringBuilder();
        sb.append(" ");
        sb.append("id=");
        sb.append(view.getId());
        sb.append(resolveIdToName(resources, view));
        int visibility = view.getVisibility();
        if (visibility == 0) {
            sb.append(", V--");
        } else if (visibility == 4) {
            sb.append(", -I-");
        } else if (visibility != 8) {
            sb.append(", ---");
        } else {
            sb.append(", --G");
        }
        if (!view.getMatrix().equals(EMPTY_MATRIX)) {
            sb.append(", ");
            sb.append("matrix=");
            sb.append(view.getMatrix().toShortString());
            if (!(0.0f == view.getRotation() && 0.0f == view.getRotationX() && 0.0f == view.getRotationY())) {
                sb.append(", rotate=[");
                sb.append(view.getRotation());
                sb.append(",");
                sb.append(view.getRotationX());
                sb.append(",");
                sb.append(view.getRotationY());
                sb.append("]");
                if (!(((float) (view.getWidth() / 2)) == view.getPivotX() && ((float) (view.getHeight() / 2)) == view.getPivotY())) {
                    sb.append(", pivot=[");
                    sb.append(view.getPivotX());
                    sb.append(",");
                    sb.append(view.getPivotY());
                    sb.append("]");
                }
            }
            if (Build.VERSION.SDK_INT >= 21 && !(0.0f == view.getTranslationX() && 0.0f == view.getTranslationY() && 0.0f == view.getTranslationZ())) {
                sb.append(", translate=[");
                sb.append(view.getTranslationX());
                sb.append(",");
                sb.append(view.getTranslationY());
                sb.append(",");
                sb.append(view.getTranslationZ());
                sb.append("]");
            }
            if (!(1.0f == view.getScaleX() && 1.0f == view.getScaleY())) {
                sb.append(", scale=[");
                sb.append(view.getScaleX());
                sb.append(",");
                sb.append(view.getScaleY());
                sb.append("]");
            }
        }
        if (!(view.getPaddingStart() == 0 && view.getPaddingTop() == 0 && view.getPaddingEnd() == 0 && view.getPaddingBottom() == 0)) {
            sb.append(", ");
            sb.append("padding=[");
            sb.append(view.getPaddingStart());
            sb.append(",");
            sb.append(view.getPaddingTop());
            sb.append(",");
            sb.append(view.getPaddingEnd());
            sb.append(",");
            sb.append(view.getPaddingBottom());
            sb.append("]");
        }
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (layoutParams instanceof ViewGroup.MarginLayoutParams) {
            ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) layoutParams;
            if (!(marginLayoutParams.leftMargin == 0 && marginLayoutParams.topMargin == 0 && marginLayoutParams.rightMargin == 0 && marginLayoutParams.bottomMargin == 0)) {
                sb.append(", ");
                sb.append("margin=[");
                sb.append(marginLayoutParams.leftMargin);
                sb.append(",");
                sb.append(marginLayoutParams.topMargin);
                sb.append(",");
                sb.append(marginLayoutParams.rightMargin);
                sb.append(",");
                sb.append(marginLayoutParams.bottomMargin);
                sb.append("]");
            }
        }
        sb.append(", position=[");
        sb.append(view.getLeft());
        sb.append(",");
        sb.append(view.getTop());
        sb.append("]");
        sb.append(", size=[");
        sb.append(view.getWidth());
        sb.append(",");
        sb.append(view.getHeight());
        sb.append("]");
        if (view instanceof TextView) {
            sb.append(", text=\"");
            sb.append(((TextView) view).getText());
            sb.append("\"");
        }
        return sb.toString();
    }

    private static String resolveIdToName(@Nullable Resources resources, View view) {
        if (resources == null) {
            return "";
        }
        try {
            return " / " + resources.getResourceEntryName(view.getId());
        } catch (Throwable unused) {
            return "";
        }
    }
}
