package net.squirrel.httpsplugin;

import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.AsyncTask;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.UnexpectedNativeTypeException;
import com.facebook.react.bridge.WritableMap;
import java.io.IOException;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import net.squirrel.httpsplugin.models.HttpRequest;
import net.squirrel.httpsplugin.models.HttpResponse;
import net.squirrel.httpsplugin.utils.HttpUtil;
import net.squirrel.httpsplugin.utils.JsonUtil;
import org.json.JSONException;

public class HttpsPluginModule extends ReactContextBaseJavaModule {
    private static final String OPT_BODY_KEY = "body";
    private static final String OPT_HEADER_KEY = "headers";
    private static final String OPT_METHOD_KEY = "method";
    private static final String OPT_SSL_PINNING_KEY = "sslconfig";
    private static final String OPT_TIMEOUT_KEY = "timeout";
    private String displayName = null;
    private HttpUtil httpUtil = new HttpUtil();
    private String packageName = null;
    private String version = null;
    private String versionCode = null;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "RNHttpsPlugin";
    }

    public HttpsPluginModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        try {
            PackageManager packageManager = reactApplicationContext.getPackageManager();
            String packageName2 = reactApplicationContext.getPackageName();
            this.packageName = packageName2;
            PackageInfo packageInfo = packageManager.getPackageInfo(packageName2, 0);
            this.displayName = packageManager.getApplicationLabel(packageManager.getApplicationInfo(this.packageName, 0)).toString();
            this.version = packageInfo.versionName;
            this.versionCode = String.valueOf(packageInfo.versionCode);
        } catch (PackageManager.NameNotFoundException unused) {
            System.out.println("RNAppInfo: package name not found");
        }
    }

    @ReactMethod
    public void fetch(String str, ReadableMap readableMap, Callback callback) {
        new FetchTask(readableMap, callback).executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, str);
    }

    private class FetchTask extends AsyncTask<String, Void, WritableMap> {
        private Callback callback;
        private ReadableMap opts;

        public FetchTask(ReadableMap readableMap, Callback callback2) {
            this.opts = readableMap;
            this.callback = callback2;
        }

        /* access modifiers changed from: protected */
        public WritableMap doInBackground(String... strArr) {
            try {
                WritableMap createMap = Arguments.createMap();
                HttpRequest httpRequest = new HttpRequest(strArr[0]);
                if (this.opts.hasKey(HttpsPluginModule.OPT_BODY_KEY)) {
                    httpRequest.body = this.opts.getString(HttpsPluginModule.OPT_BODY_KEY);
                }
                if (this.opts.hasKey(HttpsPluginModule.OPT_METHOD_KEY)) {
                    httpRequest.method = this.opts.getString(HttpsPluginModule.OPT_METHOD_KEY);
                }
                if (this.opts.hasKey(HttpsPluginModule.OPT_HEADER_KEY)) {
                    httpRequest.headers = JsonUtil.convertReadableMapToJson(this.opts.getMap(HttpsPluginModule.OPT_HEADER_KEY));
                }
                if (this.opts.hasKey(HttpsPluginModule.OPT_SSL_PINNING_KEY)) {
                    String string = this.opts.getMap(HttpsPluginModule.OPT_SSL_PINNING_KEY).getString("truststore");
                    String string2 = this.opts.getMap(HttpsPluginModule.OPT_SSL_PINNING_KEY).getString("keystore");
                    String string3 = this.opts.getMap(HttpsPluginModule.OPT_SSL_PINNING_KEY).getString("storeType");
                    String string4 = this.opts.getMap(HttpsPluginModule.OPT_SSL_PINNING_KEY).getString("storePassword");
                    httpRequest.truststore = string;
                    httpRequest.keystore = string2;
                    httpRequest.storeType = string3;
                    httpRequest.storePassword = string4;
                }
                if (this.opts.hasKey(HttpsPluginModule.OPT_TIMEOUT_KEY)) {
                    httpRequest.timeout = this.opts.getInt(HttpsPluginModule.OPT_TIMEOUT_KEY);
                }
                HttpResponse sendHttpRequest = HttpsPluginModule.this.httpUtil.sendHttpRequest(httpRequest);
                createMap.putInt("status", sendHttpRequest.statusCode);
                createMap.putString("statusText", sendHttpRequest.statusText);
                createMap.putString("bodyString", sendHttpRequest.bodyString);
                createMap.putMap(HttpsPluginModule.OPT_HEADER_KEY, sendHttpRequest.headers);
                return createMap;
            } catch (UnexpectedNativeTypeException | IOException | KeyManagementException | KeyStoreException | NoSuchAlgorithmException | CertificateException | JSONException e) {
                WritableMap createMap2 = Arguments.createMap();
                createMap2.putString("errorMessage", e.toString());
                return createMap2;
            }
        }

        /* access modifiers changed from: protected */
        public void onPostExecute(WritableMap writableMap) {
            if (writableMap.hasKey("errorMessage")) {
                this.callback.invoke(writableMap.getString("errorMessage"), null);
                return;
            }
            this.callback.invoke(null, writableMap);
        }
    }
}
