package com.facebook.soloader;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.annotation.Nullable;
import org.apache.commons.io.FilenameUtils;

public final class NativeDeps {
    private static final int DEFAULT_LIBS_CAPACITY = 512;
    private static final int INITIAL_HASH = 5381;
    private static final int LIB_PREFIX_LEN = 3;
    private static final int LIB_PREFIX_SUFFIX_LEN = (3 + 3);
    private static final int LIB_SUFFIX_LEN = 3;
    @Nullable
    private static byte[] sEncodedDeps = null;
    private static boolean sInitialized = false;
    private static Map<Integer, List<Integer>> sPrecomputedDeps;
    private static List<Integer> sPrecomputedLibs;

    public static String[] getDependencies(String str, File file) throws IOException {
        String[] tryGetDepsFromPrecomputedDeps;
        if (!sInitialized || (tryGetDepsFromPrecomputedDeps = tryGetDepsFromPrecomputedDeps(str)) == null) {
            return MinElf.extract_DT_NEEDED(file);
        }
        return tryGetDepsFromPrecomputedDeps;
    }

    public static String[] getDependencies(String str, ElfByteChannel elfByteChannel) throws IOException {
        String[] tryGetDepsFromPrecomputedDeps;
        if (sPrecomputedDeps == null || (tryGetDepsFromPrecomputedDeps = tryGetDepsFromPrecomputedDeps(str)) == null) {
            return MinElf.extract_DT_NEEDED(elfByteChannel);
        }
        return tryGetDepsFromPrecomputedDeps;
    }

    public static boolean useDepsFile(byte[] bArr, String str) throws IOException {
        if (!sInitialized) {
            synchronized (NativeDeps.class) {
                if (!sInitialized) {
                    return readDepsFromFile(bArr, str);
                }
            }
        }
        throw new IllegalStateException("Trying to initialize NativeDeps but it was already initialized");
    }

    private static void indexLib(int i, int i2) {
        sPrecomputedLibs.add(Integer.valueOf(i2));
        List<Integer> list = sPrecomputedDeps.get(Integer.valueOf(i));
        if (list == null) {
            list = new ArrayList<>();
            sPrecomputedDeps.put(Integer.valueOf(i), list);
        }
        list.add(Integer.valueOf(i2));
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0038  */
    /* JADX WARNING: Removed duplicated region for block: B:29:? A[RETURN, SYNTHETIC] */
    private static void indexDepsBytes(byte[] bArr, int i) {
        int i2;
        byte b;
        boolean z = true;
        int i3 = 0;
        int i4 = 0;
        while (true) {
            if (z) {
                i3 = INITIAL_HASH;
                i2 = i;
                while (true) {
                    try {
                        b = bArr[i2];
                        if (b <= 32) {
                            break;
                        }
                        i3 = (i3 << 5) + i3 + b;
                        i2++;
                    } catch (IndexOutOfBoundsException unused) {
                        if (!z) {
                            indexLib(i3, i);
                            return;
                        }
                        return;
                    }
                }
                indexLib(i3, i);
                z = b != 32;
            } else {
                while (bArr[i] != 10) {
                    try {
                        i++;
                    } catch (IndexOutOfBoundsException unused2) {
                        i = i4;
                        if (!z) {
                        }
                    }
                }
                z = true;
                i2 = i;
                i = i4;
            }
            int i5 = i2 + 1;
            i4 = i;
            i = i5;
        }
    }

    private static int verifyBytesAndGetOffset(byte[] bArr, byte[] bArr2) {
        if (bArr == null || bArr.length == 0 || bArr2.length < bArr.length + 4) {
            return -1;
        }
        if (bArr2.length != bArr.length + 4 + ByteBuffer.wrap(bArr2, bArr.length, 4).getInt()) {
            return -1;
        }
        for (int i = 0; i < bArr.length; i++) {
            if (bArr[i] != bArr2[i]) {
                return -1;
            }
        }
        return bArr.length + 4;
    }

    private static boolean readDepsFromFile(byte[] bArr, String str) throws IOException {
        try {
            FileInputStream fileInputStream = new FileInputStream(str);
            try {
                byte[] bArr2 = new byte[fileInputStream.available()];
                sEncodedDeps = bArr2;
                fileInputStream.read(bArr2);
                int verifyBytesAndGetOffset = verifyBytesAndGetOffset(bArr, sEncodedDeps);
                if (verifyBytesAndGetOffset == -1) {
                    sEncodedDeps = null;
                    fileInputStream.close();
                    return false;
                }
                sPrecomputedDeps = new HashMap(512);
                sPrecomputedLibs = new ArrayList(512);
                indexDepsBytes(sEncodedDeps, verifyBytesAndGetOffset);
                fileInputStream.close();
                sInitialized = true;
                return true;
            } catch (Throwable th) {
                th.addSuppressed(th);
            }
            throw th;
        } catch (IOException e) {
            sEncodedDeps = null;
            throw e;
        }
    }

    private static boolean libIsAtOffset(String str, int i) {
        int i2;
        int i3 = LIB_PREFIX_LEN;
        while (true) {
            int length = str.length();
            i2 = LIB_SUFFIX_LEN;
            if (i3 < length - i2 && i < sEncodedDeps.length && (str.codePointAt(i3) & 255) == sEncodedDeps[i]) {
                i3++;
                i++;
            }
        }
        return i3 == str.length() - i2;
    }

    private static int hashLib(String str) {
        int i = INITIAL_HASH;
        for (int i2 = LIB_PREFIX_LEN; i2 < str.length() - LIB_SUFFIX_LEN; i2++) {
            i = str.codePointAt(i2) + (i << 5) + i;
        }
        return i;
    }

    private static int getOffsetForLib(String str) {
        List<Integer> list = sPrecomputedDeps.get(Integer.valueOf(hashLib(str)));
        if (list == null) {
            return -1;
        }
        for (Integer num : list) {
            int intValue = num.intValue();
            if (libIsAtOffset(str, intValue)) {
                return intValue;
            }
        }
        return -1;
    }

    @Nullable
    private static String getLibString(int i) {
        if (i >= sPrecomputedLibs.size()) {
            return null;
        }
        int intValue = sPrecomputedLibs.get(i).intValue();
        int i2 = intValue;
        while (true) {
            byte[] bArr = sEncodedDeps;
            if (i2 >= bArr.length || bArr[i2] <= 32) {
                int i3 = (i2 - intValue) + LIB_PREFIX_SUFFIX_LEN;
                char[] cArr = new char[i3];
                cArr[0] = 'l';
                cArr[1] = 'i';
                cArr[2] = 'b';
            } else {
                i2++;
            }
        }
        int i32 = (i2 - intValue) + LIB_PREFIX_SUFFIX_LEN;
        char[] cArr2 = new char[i32];
        cArr2[0] = 'l';
        cArr2[1] = 'i';
        cArr2[2] = 'b';
        for (int i4 = 0; i4 < i32 - LIB_PREFIX_SUFFIX_LEN; i4++) {
            cArr2[LIB_PREFIX_LEN + i4] = (char) sEncodedDeps[intValue + i4];
        }
        cArr2[i32 - 3] = FilenameUtils.EXTENSION_SEPARATOR;
        cArr2[i32 - 2] = 's';
        cArr2[i32 - 1] = 'o';
        return new String(cArr2);
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0040  */
    @Nullable
    private static String[] getDepsForLibAtOffset(int i, int i2) {
        byte b;
        ArrayList arrayList = new ArrayList();
        int i3 = (i + i2) - LIB_PREFIX_SUFFIX_LEN;
        int i4 = 0;
        boolean z = false;
        while (true) {
            byte[] bArr = sEncodedDeps;
            if (i3 < bArr.length && (b = bArr[i3]) != 10) {
                if (b == 32) {
                    if (!z) {
                        continue;
                    } else {
                        String libString = getLibString(i4);
                        if (libString == null) {
                            return null;
                        }
                        arrayList.add(libString);
                        i4 = 0;
                        z = false;
                    }
                } else if (b < 48 || b > 57) {
                    return null;
                } else {
                    i4 = (i4 * 10) + (b - 48);
                    z = true;
                }
                i3++;
            } else if (z) {
                String libString2 = getLibString(i4);
                if (libString2 == null) {
                    return null;
                }
                arrayList.add(libString2);
            }
        }
        if (z) {
        }
        if (arrayList.size() == 0) {
            return null;
        }
        return (String[]) arrayList.toArray(new String[arrayList.size()]);
    }

    @Nullable
    static String[] tryGetDepsFromPrecomputedDeps(String str) {
        int offsetForLib;
        if (sInitialized && str.length() > LIB_PREFIX_SUFFIX_LEN && (offsetForLib = getOffsetForLib(str)) != -1) {
            return getDepsForLibAtOffset(offsetForLib, str.length());
        }
        return null;
    }
}
