package com.horcrux.svg;

import android.content.res.AssetManager;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.os.Build;
import android.view.ViewParent;
import com.facebook.common.util.UriUtil;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.horcrux.svg.TextProperties;
import javax.annotation.Nullable;

/* access modifiers changed from: package-private */
public class TSpanView extends TextView {
    private static final String FONTS = "fonts/";
    private static final String OTF = ".otf";
    private static final String TTF = ".ttf";
    private static final double radToDeg = 57.29577951308232d;
    private static final double tau = 6.283185307179586d;
    private Path mCache;
    @Nullable
    String mContent;
    private TextPathView textPath;

    public TSpanView(ReactContext reactContext) {
        super(reactContext);
    }

    @ReactProp(name = UriUtil.LOCAL_CONTENT_SCHEME)
    public void setContent(@Nullable String str) {
        this.mContent = str;
        invalidate();
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.TextView, com.horcrux.svg.GroupView
    public void draw(Canvas canvas, Paint paint, float f) {
        if (this.mContent != null) {
            drawPath(canvas, paint, f);
            return;
        }
        clip(canvas, paint);
        drawGroup(canvas, paint, f);
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView
    public void releaseCachedPath() {
        this.mCache = null;
        this.mPath = null;
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.TextView, com.horcrux.svg.GroupView
    public Path getPath(Canvas canvas, Paint paint) {
        Path path = this.mCache;
        if (path != null) {
            return path;
        }
        if (this.mContent == null) {
            return getGroupPath(canvas, paint);
        }
        setupTextPath();
        pushGlyphContext();
        this.mCache = getLinePath(this.mContent, paint, canvas);
        popGlyphContext();
        return this.mCache;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:103:0x0288 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:115:0x02d8  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x020f  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x021b  */
    /* JADX WARNING: Removed duplicated region for block: B:87:0x0227  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x023b  */
    /* JADX WARNING: Removed duplicated region for block: B:93:0x0251 A[ADDED_TO_REGION] */
    private Path getLinePath(String str, Paint paint, Canvas canvas) {
        boolean z;
        PathMeasure pathMeasure;
        double d;
        GlyphPathBag glyphPathBag;
        PathMeasure pathMeasure2;
        float[] fArr;
        double d2;
        GlyphContext glyphContext;
        boolean z2;
        int i;
        double d3;
        double d4;
        double d5;
        int i2;
        int i3;
        boolean z3;
        String str2;
        double d6;
        double d7;
        double d8;
        Matrix matrix;
        double d9;
        PathMeasure pathMeasure3;
        GlyphContext glyphContext2;
        double d10;
        int i4;
        int i5;
        float[] fArr2;
        float[] fArr3;
        Paint paint2;
        float[] fArr4;
        int i6;
        double d11;
        Path path;
        GlyphPathBag glyphPathBag2;
        String str3;
        double d12;
        PathMeasure pathMeasure4;
        double d13;
        float[] fArr5;
        float[] fArr6;
        double d14;
        char c;
        float f;
        String str4;
        Path path2;
        boolean z4;
        double d15;
        int i7;
        double d16;
        int i8;
        double d17;
        Paint paint3 = paint;
        int length = str.length();
        Path path3 = new Path();
        if (length == 0) {
            return path3;
        }
        boolean z5 = this.textPath != null;
        if (z5) {
            PathMeasure pathMeasure5 = new PathMeasure(this.textPath.getTextPath(canvas, paint3), false);
            double length2 = (double) pathMeasure5.getLength();
            boolean isClosed = pathMeasure5.isClosed();
            if (length2 == 0.0d) {
                return path3;
            }
            pathMeasure = pathMeasure5;
            d = length2;
            z = isClosed;
        } else {
            pathMeasure = null;
            d = 0.0d;
            z = false;
        }
        GlyphContext textRootGlyphContext = getTextRootGlyphContext();
        FontData font = textRootGlyphContext.getFont();
        applyTextPropertiesToPaint(paint3, font);
        GlyphPathBag glyphPathBag3 = new GlyphPathBag(paint3);
        boolean[] zArr = new boolean[length];
        char[] charArray = str.toCharArray();
        Path path4 = path3;
        double d18 = font.kerning;
        double d19 = font.wordSpacing;
        double d20 = font.letterSpacing;
        boolean z6 = !font.manualKerning;
        boolean z7 = d20 == 0.0d && font.fontVariantLigatures == TextProperties.FontVariantLigatures.normal;
        if (Build.VERSION.SDK_INT >= 21) {
            if (z7) {
                paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', " + "'hlig', 'cala', " + font.fontFeatureSettings);
            } else {
                paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', " + "'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, " + font.fontFeatureSettings);
            }
        }
        ReadableMap readableMap = font.fontData;
        float[] fArr7 = new float[length];
        paint3.getTextWidths(str, fArr7);
        TextProperties.TextAnchor textAnchor = font.textAnchor;
        double measureText = (double) paint3.measureText(str);
        double textAnchorOffset = getTextAnchorOffset(textAnchor, measureText);
        double fontSize = textRootGlyphContext.getFontSize();
        char c2 = 65535;
        if (z5) {
            boolean z8 = this.textPath.getMidLine() == TextProperties.TextPathMidLine.sharp;
            int i9 = this.textPath.getSide() == TextProperties.TextPathSide.right ? -1 : 1;
            d2 = measureText;
            fArr = fArr7;
            glyphPathBag = glyphPathBag3;
            pathMeasure2 = pathMeasure;
            glyphContext = textRootGlyphContext;
            double absoluteStartOffset = getAbsoluteStartOffset(this.textPath.getStartOffset(), d, fontSize);
            textAnchorOffset += absoluteStartOffset;
            if (z) {
                d4 = absoluteStartOffset + (textAnchor == TextProperties.TextAnchor.middle ? -(d / 2.0d) : 0.0d);
                d3 = d4 + d;
            } else {
                d3 = d;
                d4 = 0.0d;
            }
            z2 = z8;
            i = i9;
        } else {
            d2 = measureText;
            fArr = fArr7;
            glyphPathBag = glyphPathBag3;
            pathMeasure2 = pathMeasure;
            glyphContext = textRootGlyphContext;
            d3 = d;
            d4 = 0.0d;
            i = 1;
            z2 = false;
        }
        double d21 = 1.0d;
        double d22 = d;
        if (this.mTextLength != null) {
            d5 = d4;
            double fromRelative = PropHelper.fromRelative(this.mTextLength, (double) canvas.getWidth(), 0.0d, (double) this.mScale, fontSize);
            if (fromRelative < 0.0d) {
                throw new IllegalArgumentException("Negative textLength value");
            } else if (AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[this.mLengthAdjust.ordinal()] != 2) {
                d20 += (fromRelative - d2) / ((double) (length - 1));
            } else {
                d21 = fromRelative / d2;
            }
        } else {
            d5 = d4;
        }
        double d23 = d20;
        double d24 = (double) i;
        Paint.FontMetrics fontMetrics = paint.getFontMetrics();
        int i10 = i;
        double d25 = d21 * d24;
        double d26 = (double) fontMetrics.descent;
        double d27 = ((double) fontMetrics.leading) + d26;
        double d28 = (double) ((-fontMetrics.ascent) + fontMetrics.leading);
        double d29 = d24;
        double d30 = (double) (-fontMetrics.top);
        double d31 = d30 + d27;
        String baselineShift = getBaselineShift();
        TextProperties.AlignmentBaseline alignmentBaseline = getAlignmentBaseline();
        if (alignmentBaseline != null) {
            switch (alignmentBaseline) {
                case textBottom:
                case afterEdge:
                case textAfterEdge:
                case ideographic:
                    d28 = -d26;
                    break;
                case middle:
                    Rect rect = new Rect();
                    paint3.getTextBounds("x", 0, 1, rect);
                    d28 = (double) (rect.height() / 2);
                    break;
                case central:
                    d27 = (d28 - d26) / 2.0d;
                    d28 = d27;
                    break;
                case mathematical:
                    d17 = 0.5d;
                    d27 = d17 * d28;
                    d28 = d27;
                    break;
                case hanging:
                    d17 = 0.8d;
                    d27 = d17 * d28;
                    d28 = d27;
                    break;
                case bottom:
                    d28 = d27;
                    break;
                case center:
                    d27 = d31 / 2.0d;
                    d28 = d27;
                    break;
                case top:
                    d28 = d30;
                    break;
            }
            if (!(baselineShift == null || baselineShift.isEmpty() || (i8 = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[alignmentBaseline.ordinal()]) == 14 || i8 == 16)) {
                baselineShift.hashCode();
                switch (baselineShift.hashCode()) {
                    case -1720785339:
                        if (baselineShift.equals("baseline")) {
                            c2 = 0;
                            break;
                        }
                        break;
                    case 114240:
                        if (baselineShift.equals("sub")) {
                            c2 = 1;
                            break;
                        }
                        break;
                    case 109801339:
                        if (baselineShift.equals("super")) {
                            c2 = 2;
                            break;
                        }
                        break;
                }
                switch (c2) {
                    case 0:
                        break;
                    case 1:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i11 = readableMap.getInt("unitsPerEm");
                            ReadableMap map = readableMap.getMap("tables");
                            if (map.hasKey("os2")) {
                                ReadableMap map2 = map.getMap("os2");
                                if (map2.hasKey("ySubscriptYOffset")) {
                                    d28 += ((((double) this.mScale) * fontSize) * map2.getDouble("ySubscriptYOffset")) / ((double) i11);
                                    break;
                                }
                            }
                        }
                        break;
                    case 2:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i12 = readableMap.getInt("unitsPerEm");
                            ReadableMap map3 = readableMap.getMap("tables");
                            if (map3.hasKey("os2")) {
                                ReadableMap map4 = map3.getMap("os2");
                                if (map4.hasKey("ySuperscriptYOffset")) {
                                    d28 -= ((((double) this.mScale) * fontSize) * map4.getDouble("ySuperscriptYOffset")) / ((double) i12);
                                    break;
                                }
                            }
                        }
                        break;
                    default:
                        d28 -= PropHelper.fromRelative(baselineShift, ((double) this.mScale) * fontSize, 0.0d, (double) this.mScale, fontSize);
                        break;
                }
            }
            Matrix matrix2 = new Matrix();
            Matrix matrix3 = new Matrix();
            Matrix matrix4 = new Matrix();
            float[] fArr8 = new float[9];
            float[] fArr9 = new float[9];
            float[] fArr10 = new float[9];
            i2 = 0;
            while (i2 < length) {
                char c3 = charArray[i2];
                String valueOf = String.valueOf(c3);
                boolean z9 = zArr[i2];
                if (z9) {
                    i3 = length;
                    str2 = "";
                    z3 = false;
                } else {
                    int i13 = i2;
                    String str5 = valueOf;
                    z3 = false;
                    while (true) {
                        int i14 = i13 + 1;
                        if (i14 >= length || fArr[i14] > 0.0f) {
                            i3 = length;
                            str2 = str5;
                        } else {
                            str5 = str5 + String.valueOf(charArray[i14]);
                            zArr[i14] = true;
                            i13 = i14;
                            length = length;
                            z3 = true;
                        }
                    }
                    i3 = length;
                    str2 = str5;
                }
                double measureText2 = ((double) paint3.measureText(str2)) * d21;
                if (z6) {
                    d6 = d28;
                    d18 = (((double) fArr[i2]) * d21) - measureText2;
                } else {
                    d6 = d28;
                }
                boolean z10 = c3 == ' ';
                double d32 = measureText2 + (z10 ? d19 : 0.0d) + d23;
                if (z9) {
                    d7 = d23;
                    d8 = 0.0d;
                } else {
                    d7 = d23;
                    d8 = d18 + d32;
                }
                double nextX = glyphContext.nextX(d8);
                double nextY = glyphContext.nextY();
                double nextDeltaX = glyphContext.nextDeltaX();
                double nextDeltaY = glyphContext.nextDeltaY();
                double nextRotation = glyphContext.nextRotation();
                if (z9 || z10) {
                    paint2 = paint;
                    i4 = i2;
                } else {
                    double d33 = measureText2 * d29;
                    double d34 = (textAnchorOffset + ((nextX + nextDeltaX) * d29)) - (d32 * d29);
                    if (z5) {
                        i4 = i2;
                        double d35 = d34 + d33;
                        double d36 = d33 / 2.0d;
                        d12 = nextRotation;
                        double d37 = d34 + d36;
                        if (d37 <= d3 && d37 >= d5) {
                            glyphContext2 = glyphContext;
                            if (z2) {
                                pathMeasure2.getMatrix((float) d37, matrix3, 3);
                                pathMeasure4 = pathMeasure2;
                                matrix = matrix2;
                                str3 = str2;
                                d15 = nextY;
                                fArr5 = fArr8;
                            } else {
                                pathMeasure4 = pathMeasure2;
                                if (d34 < 0.0d) {
                                    str3 = str2;
                                    d15 = nextY;
                                    pathMeasure4.getMatrix(0.0f, matrix2, 3);
                                    matrix2.preTranslate((float) d34, 0.0f);
                                    i7 = 1;
                                } else {
                                    str3 = str2;
                                    d15 = nextY;
                                    i7 = 1;
                                    pathMeasure4.getMatrix((float) d34, matrix2, 1);
                                }
                                pathMeasure4.getMatrix((float) d37, matrix3, i7);
                                if (d35 > d22) {
                                    d16 = d22;
                                    pathMeasure4.getMatrix((float) d16, matrix4, 3);
                                    matrix4.preTranslate((float) (d35 - d16), 0.0f);
                                } else {
                                    d16 = d22;
                                    pathMeasure4.getMatrix((float) d35, matrix4, i7);
                                }
                                fArr5 = fArr8;
                                matrix2.getValues(fArr5);
                                matrix4.getValues(fArr10);
                                d22 = d16;
                                matrix = matrix2;
                                matrix3.preRotate((float) (Math.atan2(((double) fArr10[5]) - ((double) fArr5[5]), ((double) fArr10[2]) - ((double) fArr5[2])) * radToDeg * d29));
                                d36 = d36;
                            }
                            matrix3.preTranslate((float) (-d36), (float) (nextDeltaY + d6));
                            d13 = d25;
                            i6 = i10;
                            matrix3.preScale((float) d13, (float) i6);
                            matrix3.postTranslate(0.0f, (float) d15);
                        } else {
                            paint2 = paint;
                        }
                    } else {
                        i4 = i2;
                        matrix = matrix2;
                        str3 = str2;
                        glyphContext2 = glyphContext;
                        d12 = nextRotation;
                        i6 = i10;
                        fArr5 = fArr8;
                        d13 = d25;
                        pathMeasure4 = pathMeasure2;
                        matrix3.setTranslate((float) d34, (float) (nextY + nextDeltaY + d6));
                    }
                    float f2 = (float) d12;
                    matrix3.preRotate(f2);
                    if (z3) {
                        Path path5 = new Path();
                        d25 = d13;
                        d11 = d22;
                        c = 2;
                        pathMeasure3 = pathMeasure4;
                        fArr2 = fArr10;
                        d9 = d29;
                        d14 = d12;
                        f = 0.0f;
                        fArr6 = fArr9;
                        fArr3 = fArr5;
                        path = path4;
                        i5 = i3;
                        d10 = d19;
                        z4 = true;
                        paint.getTextPath(str3, 0, str3.length(), 0.0f, 0.0f, path5);
                        path2 = path5;
                        glyphPathBag2 = glyphPathBag;
                        str4 = str3;
                    } else {
                        d14 = d12;
                        d25 = d13;
                        pathMeasure3 = pathMeasure4;
                        fArr2 = fArr10;
                        fArr6 = fArr9;
                        glyphPathBag2 = glyphPathBag;
                        d11 = d22;
                        d9 = d29;
                        str4 = str3;
                        z4 = true;
                        f = 0.0f;
                        c = 2;
                        fArr3 = fArr5;
                        path = path4;
                        i5 = i3;
                        d10 = d19;
                        path2 = glyphPathBag2.getOrCreateAndCache(c3, str4);
                    }
                    RectF rectF = new RectF();
                    path2.computeBounds(rectF, z4);
                    if (rectF.width() == f) {
                        fArr4 = fArr6;
                        matrix3.getValues(fArr4);
                        float f3 = (float) ((double) fArr4[c]);
                        float f4 = (float) ((double) fArr4[5]);
                        canvas.rotate(f2, f3, f4);
                        paint2 = paint;
                        canvas.drawText(str4, f3, f4, paint2);
                        canvas.rotate((float) (-d14), f3, f4);
                    } else {
                        paint2 = paint;
                        fArr4 = fArr6;
                        path2.transform(matrix3);
                        path.addPath(path2);
                    }
                    glyphPathBag = glyphPathBag2;
                    i10 = i6;
                    paint3 = paint2;
                    fArr8 = fArr3;
                    fArr10 = fArr2;
                    length = i5;
                    d19 = d10;
                    glyphContext = glyphContext2;
                    pathMeasure2 = pathMeasure3;
                    d29 = d9;
                    d23 = d7;
                    path4 = path;
                    d22 = d11;
                    fArr9 = fArr4;
                    d28 = d6;
                    matrix2 = matrix;
                    i2 = i4 + 1;
                }
                matrix = matrix2;
                glyphContext2 = glyphContext;
                fArr2 = fArr10;
                i6 = i10;
                path = path4;
                fArr4 = fArr9;
                fArr3 = fArr8;
                pathMeasure3 = pathMeasure2;
                glyphPathBag2 = glyphPathBag;
                d11 = d22;
                d9 = d29;
                i5 = i3;
                d10 = d19;
                glyphPathBag = glyphPathBag2;
                i10 = i6;
                paint3 = paint2;
                fArr8 = fArr3;
                fArr10 = fArr2;
                length = i5;
                d19 = d10;
                glyphContext = glyphContext2;
                pathMeasure2 = pathMeasure3;
                d29 = d9;
                d23 = d7;
                path4 = path;
                d22 = d11;
                fArr9 = fArr4;
                d28 = d6;
                matrix2 = matrix;
                i2 = i4 + 1;
            }
            return path4;
        }
        d28 = 0.0d;
        baselineShift.hashCode();
        switch (baselineShift.hashCode()) {
            case -1720785339:
                break;
            case 114240:
                break;
            case 109801339:
                break;
        }
        switch (c2) {
        }
        Matrix matrix22 = new Matrix();
        Matrix matrix32 = new Matrix();
        Matrix matrix42 = new Matrix();
        float[] fArr82 = new float[9];
        float[] fArr92 = new float[9];
        float[] fArr102 = new float[9];
        i2 = 0;
        while (i2 < length) {
        }
        return path4;
    }

    private double getAbsoluteStartOffset(SVGLength sVGLength, double d, double d2) {
        return PropHelper.fromRelative(sVGLength, d, 0.0d, (double) this.mScale, d2);
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.horcrux.svg.TSpanView$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor;
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust;

        /* JADX WARNING: Can't wrap try/catch for region: R(43:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|(2:43|44)|45|47|48|(3:49|50|52)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(44:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|47|48|(3:49|50|52)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(46:0|(2:1|2)|3|(2:5|6)|7|9|10|11|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(47:0|(2:1|2)|3|5|6|7|9|10|11|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(48:0|1|2|3|5|6|7|9|10|11|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|47|48|49|50|52) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0039 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0043 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x004d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0058 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0063 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x006e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0079 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0085 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:31:0x0091 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x009d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x00a9 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:37:0x00b5 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:39:0x00c1 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x00cd */
        /* JADX WARNING: Missing exception handler attribute for start block: B:43:0x00d9 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:49:0x00f6 */
        static {
            int[] iArr = new int[TextProperties.TextAnchor.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor = iArr;
            try {
                iArr[TextProperties.TextAnchor.start.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.middle.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.end.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr2 = new int[TextProperties.AlignmentBaseline.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline = iArr2;
            iArr2[TextProperties.AlignmentBaseline.baseline.ordinal()] = 1;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBottom.ordinal()] = 2;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.afterEdge.ordinal()] = 3;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textAfterEdge.ordinal()] = 4;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.alphabetic.ordinal()] = 5;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.ideographic.ordinal()] = 6;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.middle.ordinal()] = 7;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.central.ordinal()] = 8;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.mathematical.ordinal()] = 9;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.hanging.ordinal()] = 10;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textTop.ordinal()] = 11;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.beforeEdge.ordinal()] = 12;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBeforeEdge.ordinal()] = 13;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.bottom.ordinal()] = 14;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.center.ordinal()] = 15;
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.top.ordinal()] = 16;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr3 = new int[TextProperties.TextLengthAdjust.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust = iArr3;
            iArr3[TextProperties.TextLengthAdjust.spacing.ordinal()] = 1;
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[TextProperties.TextLengthAdjust.spacingAndGlyphs.ordinal()] = 2;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    private double getTextAnchorOffset(TextProperties.TextAnchor textAnchor, double d) {
        int i = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[textAnchor.ordinal()];
        if (i == 2) {
            return (-d) / 2.0d;
        }
        if (i != 3) {
            return 0.0d;
        }
        return -d;
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(14:0|(1:2)(1:3)|4|(1:6)(1:7)|(1:(1:(1:13)(1:14)))(1:10)|15|16|17|18|19|20|21|22|24) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:18:0x0051 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:20:0x006a */
    private void applyTextPropertiesToPaint(Paint paint, FontData fontData) {
        AssetManager assets = this.mContext.getResources().getAssets();
        double d = fontData.fontSize * ((double) this.mScale);
        int i = 1;
        boolean z = fontData.fontWeight == TextProperties.FontWeight.Bold;
        boolean z2 = fontData.fontStyle == TextProperties.FontStyle.italic;
        if (z && z2) {
            i = 3;
        } else if (!z) {
            i = z2 ? 2 : 0;
        }
        Typeface typeface = null;
        String str = fontData.fontFamily;
        typeface = Typeface.createFromAsset(assets, FONTS + str + OTF);
        typeface = Typeface.createFromAsset(assets, FONTS + str + TTF);
        typeface = Typeface.create(str, i);
        paint.setTypeface(typeface);
        paint.setTextSize((float) d);
        paint.setTextAlign(Paint.Align.LEFT);
    }

    private void setupTextPath() {
        for (ViewParent parent = getParent(); parent != null; parent = parent.getParent()) {
            if (parent.getClass() == TextPathView.class) {
                this.textPath = (TextPathView) parent;
                return;
            } else if (!(parent instanceof TextView)) {
                return;
            }
        }
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.GroupView
    public int hitTest(float[] fArr) {
        if (this.mContent == null) {
            return super.hitTest(fArr);
        }
        if (this.mPath != null && this.mInvertible && this.mTransformInvertible) {
            float[] fArr2 = new float[2];
            this.mInvMatrix.mapPoints(fArr2, fArr);
            this.mInvTransform.mapPoints(fArr2);
            int round = Math.round(fArr2[0]);
            int round2 = Math.round(fArr2[1]);
            if (this.mRegion == null && this.mFillPath != null) {
                this.mRegion = getRegion(this.mFillPath);
            }
            if (this.mStrokeRegion == null && this.mStrokePath != null) {
                this.mStrokeRegion = getRegion(this.mStrokePath);
            }
            if ((this.mRegion != null && this.mRegion.contains(round, round2)) || (this.mStrokeRegion != null && this.mStrokeRegion.contains(round, round2))) {
                Path clipPath = getClipPath();
                if (clipPath != null) {
                    if (this.mClipRegionPath != clipPath) {
                        this.mClipRegionPath = clipPath;
                        this.mClipRegion = getRegion(clipPath);
                    }
                    if (!this.mClipRegion.contains(round, round2)) {
                        return -1;
                    }
                }
                return getId();
            }
        }
        return -1;
    }
}
