package com.swmansion.gesturehandler;

import android.os.Handler;
import android.view.MotionEvent;
import androidx.core.app.NotificationCompat;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

public final class FlingGestureHandler extends GestureHandler<FlingGestureHandler> {
    public static final Companion Companion = new Companion(null);
    private static final int DEFAULT_DIRECTION;
    private static final long DEFAULT_MAX_DURATION_MS;
    private static final long DEFAULT_MIN_ACCEPTABLE_DELTA;
    private static final int DEFAULT_NUMBER_OF_TOUCHES_REQUIRED;
    private int direction = 1;
    private final Runnable failDelayed = new FlingGestureHandler$$ExternalSyntheticLambda0(this);
    private Handler handler;
    private final long maxDurationMs = DEFAULT_MAX_DURATION_MS;
    private int maxNumberOfPointersSimultaneously;
    private final long minAcceptableDelta = DEFAULT_MIN_ACCEPTABLE_DELTA;
    private int numberOfPointersRequired = 1;
    private float startX;
    private float startY;

    public final int getNumberOfPointersRequired() {
        return this.numberOfPointersRequired;
    }

    public final void setNumberOfPointersRequired(int i) {
        this.numberOfPointersRequired = i;
    }

    public final int getDirection() {
        return this.direction;
    }

    public final void setDirection(int i) {
        this.direction = i;
    }

    /* renamed from: failDelayed$lambda-0 */
    public static final void m4failDelayed$lambda0(FlingGestureHandler flingGestureHandler) {
        Intrinsics.checkNotNullParameter(flingGestureHandler, "this$0");
        flingGestureHandler.fail();
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void resetConfig() {
        super.resetConfig();
        this.numberOfPointersRequired = 1;
        this.direction = 1;
    }

    private final void startFling(MotionEvent motionEvent) {
        this.startX = motionEvent.getRawX();
        this.startY = motionEvent.getRawY();
        begin();
        this.maxNumberOfPointersSimultaneously = 1;
        Handler handler2 = this.handler;
        if (handler2 == null) {
            this.handler = new Handler();
        } else {
            Intrinsics.checkNotNull(handler2);
            handler2.removeCallbacksAndMessages(null);
        }
        Handler handler3 = this.handler;
        Intrinsics.checkNotNull(handler3);
        handler3.postDelayed(this.failDelayed, this.maxDurationMs);
    }

    private final boolean tryEndFling(MotionEvent motionEvent) {
        if (this.maxNumberOfPointersSimultaneously != this.numberOfPointersRequired || (((this.direction & 1) == 0 || motionEvent.getRawX() - this.startX <= ((float) this.minAcceptableDelta)) && (((this.direction & 2) == 0 || this.startX - motionEvent.getRawX() <= ((float) this.minAcceptableDelta)) && (((this.direction & 4) == 0 || this.startY - motionEvent.getRawY() <= ((float) this.minAcceptableDelta)) && ((this.direction & 8) == 0 || motionEvent.getRawY() - this.startY <= ((float) this.minAcceptableDelta)))))) {
            return false;
        }
        Handler handler2 = this.handler;
        Intrinsics.checkNotNull(handler2);
        handler2.removeCallbacksAndMessages(null);
        activate();
        return true;
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void activate(boolean z) {
        super.activate(z);
        end();
    }

    private final void endFling(MotionEvent motionEvent) {
        if (!tryEndFling(motionEvent)) {
            fail();
        }
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onHandle(MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
        int state = getState();
        if (state == 0) {
            startFling(motionEvent);
        }
        if (state == 2) {
            tryEndFling(motionEvent);
            if (motionEvent.getPointerCount() > this.maxNumberOfPointersSimultaneously) {
                this.maxNumberOfPointersSimultaneously = motionEvent.getPointerCount();
            }
            if (motionEvent.getActionMasked() == 1) {
                endFling(motionEvent);
            }
        }
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onCancel() {
        Handler handler2 = this.handler;
        if (handler2 != null) {
            handler2.removeCallbacksAndMessages(null);
        }
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onReset() {
        Handler handler2 = this.handler;
        if (handler2 != null) {
            handler2.removeCallbacksAndMessages(null);
        }
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }
}
