package com.swmansion.gesturehandler;

import android.os.Handler;
import android.view.MotionEvent;
import androidx.core.app.NotificationCompat;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

public final class TapGestureHandler extends GestureHandler<TapGestureHandler> {
    public static final Companion Companion = new Companion(null);
    private static final long DEFAULT_MAX_DELAY_MS;
    private static final long DEFAULT_MAX_DURATION_MS;
    private static final int DEFAULT_MIN_NUMBER_OF_POINTERS;
    private static final int DEFAULT_NUMBER_OF_TAPS;
    private static final float MAX_VALUE_IGNORE;
    private int currentMaxNumberOfPointers = 1;
    private final Runnable failDelayed = new TapGestureHandler$$ExternalSyntheticLambda0(this);
    private Handler handler;
    private float lastX;
    private float lastY;
    private long maxDelayMs = DEFAULT_MAX_DELAY_MS;
    private float maxDeltaX = Float.MIN_VALUE;
    private float maxDeltaY = Float.MIN_VALUE;
    private float maxDistSq = Float.MIN_VALUE;
    private long maxDurationMs = DEFAULT_MAX_DURATION_MS;
    private int minNumberOfPointers = 1;
    private int numberOfTaps = 1;
    private float offsetX;
    private float offsetY;
    private float startX;
    private float startY;
    private int tapsSoFar;

    public TapGestureHandler() {
        setShouldCancelWhenOutside(true);
    }

    /* renamed from: failDelayed$lambda-0 */
    public static final void m12failDelayed$lambda0(TapGestureHandler tapGestureHandler) {
        Intrinsics.checkNotNullParameter(tapGestureHandler, "this$0");
        tapGestureHandler.fail();
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void resetConfig() {
        super.resetConfig();
        this.maxDeltaX = Float.MIN_VALUE;
        this.maxDeltaY = Float.MIN_VALUE;
        this.maxDistSq = Float.MIN_VALUE;
        this.maxDurationMs = DEFAULT_MAX_DURATION_MS;
        this.maxDelayMs = DEFAULT_MAX_DELAY_MS;
        this.numberOfTaps = 1;
        this.minNumberOfPointers = 1;
    }

    public final TapGestureHandler setNumberOfTaps(int i) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.numberOfTaps = i;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMaxDelayMs(long j) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.maxDelayMs = j;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMaxDurationMs(long j) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.maxDurationMs = j;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMaxDx(float f) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.maxDeltaX = f;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMaxDy(float f) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.maxDeltaY = f;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMaxDist(float f) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.maxDistSq = f * f;
        return tapGestureHandler;
    }

    public final TapGestureHandler setMinNumberOfPointers(int i) {
        TapGestureHandler tapGestureHandler = this;
        tapGestureHandler.minNumberOfPointers = i;
        return tapGestureHandler;
    }

    private final void startTap() {
        Handler handler2 = this.handler;
        if (handler2 == null) {
            this.handler = new Handler();
        } else {
            Intrinsics.checkNotNull(handler2);
            handler2.removeCallbacksAndMessages(null);
        }
        Handler handler3 = this.handler;
        Intrinsics.checkNotNull(handler3);
        handler3.postDelayed(this.failDelayed, this.maxDurationMs);
    }

    private final void endTap() {
        Handler handler2 = this.handler;
        if (handler2 == null) {
            this.handler = new Handler();
        } else {
            Intrinsics.checkNotNull(handler2);
            handler2.removeCallbacksAndMessages(null);
        }
        int i = this.tapsSoFar + 1;
        this.tapsSoFar = i;
        if (i != this.numberOfTaps || this.currentMaxNumberOfPointers < this.minNumberOfPointers) {
            Handler handler3 = this.handler;
            Intrinsics.checkNotNull(handler3);
            handler3.postDelayed(this.failDelayed, this.maxDelayMs);
            return;
        }
        activate();
    }

    private final boolean shouldFail() {
        float f = (this.lastX - this.startX) + this.offsetX;
        if (!(this.maxDeltaX == Float.MIN_VALUE) && Math.abs(f) > this.maxDeltaX) {
            return true;
        }
        float f2 = (this.lastY - this.startY) + this.offsetY;
        if (!(this.maxDeltaY == Float.MIN_VALUE) && Math.abs(f2) > this.maxDeltaY) {
            return true;
        }
        float f3 = (f2 * f2) + (f * f);
        float f4 = this.maxDistSq;
        if ((f4 == Float.MIN_VALUE) || f3 <= f4) {
            return false;
        }
        return true;
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onHandle(MotionEvent motionEvent) {
        Intrinsics.checkNotNullParameter(motionEvent, NotificationCompat.CATEGORY_EVENT);
        int state = getState();
        int actionMasked = motionEvent.getActionMasked();
        if (state == 0) {
            this.offsetX = 0.0f;
            this.offsetY = 0.0f;
            this.startX = motionEvent.getRawX();
            this.startY = motionEvent.getRawY();
        }
        if (actionMasked == 5 || actionMasked == 6) {
            this.offsetX += this.lastX - this.startX;
            this.offsetY += this.lastY - this.startY;
            this.lastX = GestureUtils.INSTANCE.getLastPointerX(motionEvent, true);
            float lastPointerY = GestureUtils.INSTANCE.getLastPointerY(motionEvent, true);
            this.lastY = lastPointerY;
            this.startX = this.lastX;
            this.startY = lastPointerY;
        } else {
            this.lastX = GestureUtils.INSTANCE.getLastPointerX(motionEvent, true);
            this.lastY = GestureUtils.INSTANCE.getLastPointerY(motionEvent, true);
        }
        if (this.currentMaxNumberOfPointers < motionEvent.getPointerCount()) {
            this.currentMaxNumberOfPointers = motionEvent.getPointerCount();
        }
        if (shouldFail()) {
            fail();
        } else if (state == 0) {
            if (actionMasked == 0) {
                begin();
            }
            startTap();
        } else if (state != 2) {
        } else {
            if (actionMasked == 0) {
                startTap();
            } else if (actionMasked == 1) {
                endTap();
            }
        }
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void activate(boolean z) {
        super.activate(z);
        end();
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onCancel() {
        Handler handler2 = this.handler;
        if (handler2 != null) {
            handler2.removeCallbacksAndMessages(null);
        }
    }

    @Override // com.swmansion.gesturehandler.GestureHandler
    public void onReset() {
        this.tapsSoFar = 0;
        this.currentMaxNumberOfPointers = 0;
        Handler handler2 = this.handler;
        if (handler2 != null) {
            handler2.removeCallbacksAndMessages(null);
        }
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }
}
