package expo.modules.adapters.react.apploader;

import android.content.Context;
import android.os.Handler;
import com.facebook.react.ReactApplication;
import com.facebook.react.ReactInstanceManager;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.common.LifecycleState;
import expo.modules.apploader.HeadlessAppLoader;
import expo.modules.core.interfaces.Consumer;
import java.util.Map;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;

public final class RNHeadlessAppLoader implements HeadlessAppLoader {
    private final Context context;

    public RNHeadlessAppLoader(Context context2) {
        Intrinsics.checkNotNullParameter(context2, "context");
        this.context = context2;
    }

    @Override // expo.modules.apploader.HeadlessAppLoader
    public void loadApp(Context context2, HeadlessAppLoader.Params params, Runnable runnable, Consumer<Boolean> consumer) {
        Intrinsics.checkNotNullParameter(context2, "context");
        if (params == null || params.getAppScopeKey() == null) {
            throw new IllegalArgumentException("Params must be set with appScopeKey!");
        } else if (context2.getApplicationContext() instanceof ReactApplication) {
            Context applicationContext = context2.getApplicationContext();
            Objects.requireNonNull(applicationContext, "null cannot be cast to non-null type com.facebook.react.ReactApplication");
            ReactInstanceManager reactInstanceManager = ((ReactApplication) applicationContext).getReactNativeHost().getReactInstanceManager();
            if (!RNHeadlessAppLoaderKt.appRecords.containsKey(params.getAppScopeKey())) {
                reactInstanceManager.addReactInstanceEventListener(new RNHeadlessAppLoader$$ExternalSyntheticLambda0(params, consumer));
                Map map = RNHeadlessAppLoaderKt.appRecords;
                String appScopeKey = params.getAppScopeKey();
                Intrinsics.checkNotNullExpressionValue(appScopeKey, "params.appScopeKey");
                Intrinsics.checkNotNullExpressionValue(reactInstanceManager, "reactInstanceManager");
                map.put(appScopeKey, reactInstanceManager);
                if (reactInstanceManager.hasStartedCreatingInitialContext()) {
                    reactInstanceManager.recreateReactContextInBackground();
                } else {
                    reactInstanceManager.createReactContextInBackground();
                }
            } else if (runnable != null) {
                runnable.run();
            }
        } else {
            throw new IllegalStateException("Your application must implement ReactApplication");
        }
    }

    /* renamed from: loadApp$lambda-0 */
    public static final void m45loadApp$lambda0(HeadlessAppLoader.Params params, Consumer consumer, ReactContext reactContext) {
        HeadlessAppLoaderNotifier.INSTANCE.notifyAppLoaded(params.getAppScopeKey());
        if (consumer != null) {
            consumer.apply(true);
        }
    }

    @Override // expo.modules.apploader.HeadlessAppLoader
    public boolean invalidateApp(String str) {
        if (!RNHeadlessAppLoaderKt.appRecords.containsKey(str) || RNHeadlessAppLoaderKt.appRecords.get(str) == null) {
            return false;
        }
        Object obj = RNHeadlessAppLoaderKt.appRecords.get(str);
        Intrinsics.checkNotNull(obj);
        new Handler(this.context.getMainLooper()).post(new RNHeadlessAppLoader$$ExternalSyntheticLambda1((ReactInstanceManager) obj, str));
        return true;
    }

    /* renamed from: invalidateApp$lambda-1 */
    public static final void m44invalidateApp$lambda1(ReactInstanceManager reactInstanceManager, String str) {
        Intrinsics.checkNotNullParameter(reactInstanceManager, "$appRecord");
        if (reactInstanceManager.getLifecycleState() == LifecycleState.BEFORE_CREATE) {
            reactInstanceManager.destroy();
        }
        HeadlessAppLoaderNotifier.INSTANCE.notifyAppDestroyed(str);
        RNHeadlessAppLoaderKt.appRecords.remove(str);
    }

    @Override // expo.modules.apploader.HeadlessAppLoader
    public boolean isRunning(String str) {
        if (RNHeadlessAppLoaderKt.appRecords.containsKey(str)) {
            Object obj = RNHeadlessAppLoaderKt.appRecords.get(str);
            Intrinsics.checkNotNull(obj);
            if (((ReactInstanceManager) obj).hasStartedCreatingInitialContext()) {
                return true;
            }
        }
        return false;
    }
}
