package expo.modules.filesystem;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.StatFs;
import android.util.Base64;
import android.util.Log;
import androidx.core.app.NotificationCompat;
import androidx.core.content.FileProvider;
import androidx.documentfile.provider.DocumentFile;
import com.facebook.common.util.UriUtil;
import com.facebook.react.bridge.BaseJavaModule;
import com.facebook.react.uimanager.ViewProps;
import com.google.android.gms.common.internal.ImagesContract;
import expo.modules.constants.ExponentInstallationId;
import expo.modules.core.ExportedModule;
import expo.modules.core.ModuleRegistry;
import expo.modules.core.ModuleRegistryDelegate;
import expo.modules.core.Promise;
import expo.modules.core.interfaces.ActivityEventListener;
import expo.modules.core.interfaces.ActivityProvider;
import expo.modules.core.interfaces.services.UIManager;
import expo.modules.filesystem.UploadType;
import expo.modules.interfaces.filesystem.FilePermissionModuleInterface;
import expo.modules.interfaces.filesystem.Permission;
import expo.modules.interfaces.permissions.PermissionsResponse;
import fr.greweb.reactnativeviewshot.ViewShot;
import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.math.BigInteger;
import java.net.CookieHandler;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.EnumSet;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.TuplesKt;
import kotlin.Unit;
import kotlin.collections.MapsKt;
import kotlin.io.CloseableKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.StringCompanionObject;
import kotlin.text.StringsKt;
import okhttp3.Call;
import okhttp3.Headers;
import okhttp3.JavaNetCookieJar;
import okhttp3.MediaType;
import okhttp3.MultipartBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okio.BufferedSink;
import okio.BufferedSource;
import okio.Okio;
import okio.Okio__JvmOkioKt;
import okio.Source;
import org.apache.commons.codec.binary.Hex;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;

public class FileSystemModule extends ExportedModule implements ActivityEventListener {
    private OkHttpClient client;
    private Promise dirPermissionsRequest;
    private final ModuleRegistryDelegate moduleRegistryDelegate;
    private final Map<String, TaskHandler> taskHandlers;
    private final Lazy uIManager$delegate;

    public interface ProgressListener {
        void update(long j, long j2, boolean z);
    }

    /* renamed from: uploadAsync$lambda-42 */
    public static final RequestBody m55uploadAsync$lambda42(RequestBody requestBody) {
        Intrinsics.checkNotNullParameter(requestBody, "requestBody");
        return requestBody;
    }

    @Override // expo.modules.core.ExportedModule
    public String getName() {
        return "ExponentFileSystem";
    }

    @Override // expo.modules.core.interfaces.ActivityEventListener
    public void onNewIntent(Intent intent) {
        Intrinsics.checkNotNullParameter(intent, "intent");
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ FileSystemModule(Context context, ModuleRegistryDelegate moduleRegistryDelegate2, int i, DefaultConstructorMarker defaultConstructorMarker) {
        this(context, (i & 2) != 0 ? new ModuleRegistryDelegate() : moduleRegistryDelegate2);
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public FileSystemModule(Context context, ModuleRegistryDelegate moduleRegistryDelegate2) {
        super(context);
        Intrinsics.checkNotNullParameter(context, "context");
        Intrinsics.checkNotNullParameter(moduleRegistryDelegate2, "moduleRegistryDelegate");
        this.moduleRegistryDelegate = moduleRegistryDelegate2;
        try {
            File filesDir = getContext().getFilesDir();
            Intrinsics.checkNotNullExpressionValue(filesDir, "getContext().filesDir");
            ensureDirExists(filesDir);
            File cacheDir = getContext().getCacheDir();
            Intrinsics.checkNotNullExpressionValue(cacheDir, "getContext().cacheDir");
            ensureDirExists(cacheDir);
        } catch (IOException e) {
            e.printStackTrace();
        }
        this.uIManager$delegate = LazyKt.lazy(new FileSystemModule$special$$inlined$moduleRegistry$1(this.moduleRegistryDelegate));
        this.taskHandlers = new HashMap();
    }

    private final /* synthetic */ <T> Lazy<T> moduleRegistry() {
        ModuleRegistryDelegate moduleRegistryDelegate2 = this.moduleRegistryDelegate;
        Intrinsics.needClassReification();
        return LazyKt.lazy(new FileSystemModule$moduleRegistry$$inlined$getFromModuleRegistry$1(moduleRegistryDelegate2));
    }

    private final UIManager getUIManager() {
        Object value = this.uIManager$delegate.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "<get-uIManager>(...)");
        return (UIManager) value;
    }

    @Override // expo.modules.core.interfaces.RegistryLifecycleListener, expo.modules.core.ExportedModule
    public void onCreate(ModuleRegistry moduleRegistry) {
        Intrinsics.checkNotNullParameter(moduleRegistry, "moduleRegistry");
        this.moduleRegistryDelegate.onCreate(moduleRegistry);
    }

    @Override // expo.modules.core.ExportedModule
    public Map<String, Object> getConstants() {
        String uri = Uri.fromFile(getContext().getFilesDir()).toString();
        String uri2 = Uri.fromFile(getContext().getCacheDir()).toString();
        return MapsKt.mapOf(TuplesKt.to("documentDirectory", uri + "/"), TuplesKt.to("cacheDirectory", uri2 + "/"), TuplesKt.to("bundleDirectory", "asset:///"));
    }

    private final void checkIfFileExists(Uri uri) {
        File file = toFile(uri);
        if (!file.exists()) {
            String path = file.getPath();
            throw new IOException("Directory for '" + path + "' doesn't exist.");
        }
    }

    private final void checkIfFileDirExists(Uri uri) {
        File file = toFile(uri);
        File parentFile = file.getParentFile();
        if (parentFile == null || !parentFile.exists()) {
            String path = file.getPath();
            String parent = file.getParent();
            throw new IOException("Directory for '" + path + "' doesn't exist. Please make sure directory '" + parent + "' exists before calling downloadAsync.");
        }
    }

    /* renamed from: permissionsForPath$lambda-0 */
    private static final FilePermissionModuleInterface m53permissionsForPath$lambda0(Lazy<? extends FilePermissionModuleInterface> lazy) {
        Object value = lazy.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "permissionsForPath$lambda-0(...)");
        return (FilePermissionModuleInterface) value;
    }

    private final EnumSet<Permission> permissionsForUri(Uri uri) {
        if (isSAFUri(uri)) {
            return permissionsForSAFUri(uri);
        }
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_CONTENT_SCHEME)) {
            return EnumSet.of(Permission.READ);
        }
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_ASSET_SCHEME)) {
            return EnumSet.of(Permission.READ);
        }
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
            return permissionsForPath(uri.getPath());
        }
        if (uri.getScheme() == null) {
            return EnumSet.of(Permission.READ);
        }
        return EnumSet.noneOf(Permission.class);
    }

    private final EnumSet<Permission> permissionsForSAFUri(Uri uri) {
        DocumentFile nearestSAFFile = getNearestSAFFile(uri);
        EnumSet<Permission> noneOf = EnumSet.noneOf(Permission.class);
        if (nearestSAFFile != null) {
            if (nearestSAFFile.canRead()) {
                noneOf.add(Permission.READ);
            }
            if (nearestSAFFile.canWrite()) {
                noneOf.add(Permission.WRITE);
            }
        }
        Intrinsics.checkNotNullExpressionValue(noneOf, "noneOf(Permission::class…)\n        }\n      }\n    }");
        return noneOf;
    }

    private final void ensurePermission(Uri uri, Permission permission, String str) {
        EnumSet<Permission> permissionsForUri = permissionsForUri(uri);
        boolean z = true;
        if (permissionsForUri == null || !permissionsForUri.contains(permission)) {
            z = false;
        }
        if (!z) {
            throw new IOException(str);
        }
    }

    private final void ensurePermission(Uri uri, Permission permission) {
        if (permission == Permission.READ) {
            ensurePermission(uri, permission, "Location '" + uri + "' isn't readable.");
        }
        if (permission == Permission.WRITE) {
            ensurePermission(uri, permission, "Location '" + uri + "' isn't writable.");
        }
        String name = permission.name();
        ensurePermission(uri, permission, "Location '" + uri + "' doesn't have permission '" + name + "'.");
    }

    private final InputStream openAssetInputStream(Uri uri) {
        String path = uri.getPath();
        if (path != null) {
            Intrinsics.checkNotNullExpressionValue(path, "requireNotNull(uri.path)");
            String substring = path.substring(1);
            Intrinsics.checkNotNullExpressionValue(substring, "this as java.lang.String).substring(startIndex)");
            InputStream open = getContext().getAssets().open(substring);
            Intrinsics.checkNotNullExpressionValue(open, "context.assets.open(asset)");
            return open;
        }
        throw new IllegalArgumentException("Required value was null.".toString());
    }

    private final InputStream openResourceInputStream(String str) {
        int identifier = getContext().getResources().getIdentifier(str, "raw", getContext().getPackageName());
        if (identifier == 0 && (identifier = getContext().getResources().getIdentifier(str, "drawable", getContext().getPackageName())) == 0) {
            throw new FileNotFoundException("No resource found with the name '" + str + "'");
        }
        InputStream openRawResource = getContext().getResources().openRawResource(identifier);
        Intrinsics.checkNotNullExpressionValue(openRawResource, "context.resources.openRawResource(resourceId)");
        return openRawResource;
    }

    /* JADX WARNING: Removed duplicated region for block: B:46:0x0145 A[Catch:{ FileNotFoundException -> 0x0193 }] */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x018d A[Catch:{ FileNotFoundException -> 0x0193 }] */
    public final void getInfoAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        Uri uri;
        InputStream inputStream;
        Intrinsics.checkNotNullParameter(str, "_uriStr");
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        String str2 = FileSystemModuleKt.slashifyFilePath(str);
        try {
            Uri parse = Uri.parse(str2);
            if (!Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                uri = parse;
            } else if (str2 != null) {
                str2 = parseFileUri(str2);
                uri = Uri.parse(str2);
            } else {
                throw new NullPointerException("null cannot be cast to non-null type kotlin.String");
            }
            Intrinsics.checkNotNullExpressionValue(uri, "absoluteUri");
            ensurePermission(uri, Permission.READ);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                Intrinsics.checkNotNullExpressionValue(uri, "absoluteUri");
                File file = toFile(uri);
                if (file.exists()) {
                    Bundle bundle = new Bundle();
                    bundle.putBoolean("exists", true);
                    bundle.putBoolean("isDirectory", file.isDirectory());
                    bundle.putString("uri", Uri.fromFile(file).toString());
                    bundle.putDouble("size", (double) getFileSize(file));
                    bundle.putDouble("modificationTime", ((double) file.lastModified()) * 0.001d);
                    Object obj = map.get("md5");
                    if (!Intrinsics.areEqual(obj, (Object) true)) {
                        obj = null;
                    }
                    if (obj != null) {
                        bundle.putString("md5", md5(file));
                    }
                    promise.resolve(bundle);
                    return;
                }
                Bundle bundle2 = new Bundle();
                bundle2.putBoolean("exists", false);
                bundle2.putBoolean("isDirectory", false);
                promise.resolve(bundle2);
            } else if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_CONTENT_SCHEME) || Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_ASSET_SCHEME) || parse.getScheme() == null) {
                try {
                    String scheme = parse.getScheme();
                    if (scheme != null) {
                        int hashCode = scheme.hashCode();
                        if (hashCode != 93121264) {
                            if (hashCode == 951530617) {
                                if (scheme.equals(UriUtil.LOCAL_CONTENT_SCHEME)) {
                                    inputStream = getContext().getContentResolver().openInputStream(parse);
                                    if (inputStream != null) {
                                        Bundle bundle3 = new Bundle();
                                        bundle3.putBoolean("exists", true);
                                        bundle3.putBoolean("isDirectory", false);
                                        bundle3.putString("uri", parse.toString());
                                        bundle3.putDouble("size", (double) inputStream.available());
                                        if (map.containsKey("md5") && Intrinsics.areEqual(map.get("md5"), (Object) true)) {
                                            char[] encodeHex = Hex.encodeHex(DigestUtils.md5(inputStream));
                                            Intrinsics.checkNotNullExpressionValue(encodeHex, "encodeHex(md5bytes)");
                                            bundle3.putString("md5", new String(encodeHex));
                                        }
                                        promise.resolve(bundle3);
                                        return;
                                    }
                                    throw new FileNotFoundException();
                                }
                            }
                        } else if (scheme.equals(UriUtil.LOCAL_ASSET_SCHEME)) {
                            Intrinsics.checkNotNullExpressionValue(parse, "uri");
                            inputStream = openAssetInputStream(parse);
                            if (inputStream != null) {
                            }
                        }
                    }
                    inputStream = openResourceInputStream(str2);
                    if (inputStream != null) {
                    }
                } catch (FileNotFoundException unused) {
                    Bundle bundle4 = new Bundle();
                    bundle4.putBoolean("exists", false);
                    bundle4.putBoolean("isDirectory", false);
                    promise.resolve(bundle4);
                }
            } else {
                throw new IOException("Unsupported scheme for location '" + parse + "'.");
            }
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:26:0x008a, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x008b, code lost:
        kotlin.io.CloseableKt.closeFinally(r9, r10);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x008e, code lost:
        throw r0;
     */
    public final void readAsStringAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        String str2;
        String iOUtils;
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.READ);
            if (StringsKt.equals(getEncodingFromOptions(map), ViewShot.Results.BASE_64, true)) {
                InputStream inputStream = getInputStream(parse);
                InputStream inputStream2 = inputStream;
                if (!map.containsKey("length") || !map.containsKey(ViewProps.POSITION)) {
                    str2 = Base64.encodeToString(getInputStreamBytes(inputStream2), 2);
                } else {
                    Object obj = map.get("length");
                    if (obj != null) {
                        int intValue = ((Number) obj).intValue();
                        Object obj2 = map.get(ViewProps.POSITION);
                        if (obj2 != null) {
                            byte[] bArr = new byte[intValue];
                            inputStream2.skip((long) ((Number) obj2).intValue());
                            str2 = Base64.encodeToString(bArr, 0, inputStream2.read(bArr, 0, intValue), 2);
                        } else {
                            throw new NullPointerException("null cannot be cast to non-null type kotlin.Number");
                        }
                    } else {
                        throw new NullPointerException("null cannot be cast to non-null type kotlin.Number");
                    }
                }
                Unit unit = Unit.INSTANCE;
                CloseableKt.closeFinally(inputStream, null);
            } else {
                if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                    iOUtils = IOUtils.toString(new FileInputStream(toFile(parse)));
                } else if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_ASSET_SCHEME)) {
                    iOUtils = IOUtils.toString(openAssetInputStream(parse));
                } else if (parse.getScheme() == null) {
                    iOUtils = IOUtils.toString(openResourceInputStream(str));
                } else if (isSAFUri(parse)) {
                    iOUtils = IOUtils.toString(getContext().getContentResolver().openInputStream(parse));
                } else {
                    throw new IOException("Unsupported scheme for location '" + parse + "'.");
                }
                str2 = iOUtils;
            }
            promise.resolve(str2);
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0058, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0059, code lost:
        kotlin.io.CloseableKt.closeFinally(r5, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x005c, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x005f, code lost:
        r5 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0060, code lost:
        kotlin.io.CloseableKt.closeFinally(r3, r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x0063, code lost:
        throw r5;
     */
    public final void writeAsStringAsync(String str, String str2, Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.WRITE);
            String encodingFromOptions = getEncodingFromOptions(map);
            OutputStream outputStream = getOutputStream(parse);
            OutputStream outputStream2 = outputStream;
            if (Intrinsics.areEqual(encodingFromOptions, ViewShot.Results.BASE_64)) {
                outputStream2.write(Base64.decode(str2, 0));
            } else {
                OutputStreamWriter outputStreamWriter = new OutputStreamWriter(outputStream2);
                outputStreamWriter.write(str2);
                Unit unit = Unit.INSTANCE;
                CloseableKt.closeFinally(outputStreamWriter, null);
            }
            Unit unit2 = Unit.INSTANCE;
            CloseableKt.closeFinally(outputStream, null);
            promise.resolve(null);
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void deleteAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Uri withAppendedPath = Uri.withAppendedPath(parse, "..");
            Intrinsics.checkNotNullExpressionValue(withAppendedPath, "appendedUri");
            Permission permission = Permission.WRITE;
            ensurePermission(withAppendedPath, permission, "Location '" + parse + "' isn't deletable.");
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                Intrinsics.checkNotNullExpressionValue(parse, "uri");
                File file = toFile(parse);
                if (file.exists()) {
                    if (Build.VERSION.SDK_INT >= 26) {
                        FileUtils.forceDelete(file);
                    } else {
                        forceDelete(file);
                    }
                    promise.resolve(null);
                    return;
                }
                if (map.containsKey("idempotent")) {
                    Object obj = map.get("idempotent");
                    if (obj == null) {
                        throw new NullPointerException("null cannot be cast to non-null type kotlin.Boolean");
                    } else if (((Boolean) obj).booleanValue()) {
                        promise.resolve(null);
                        return;
                    }
                }
                promise.reject("ERR_FILESYSTEM_CANNOT_FIND_FILE", "File '" + parse + "' could not be deleted because it could not be found");
                return;
            }
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            if (isSAFUri(parse)) {
                DocumentFile nearestSAFFile = getNearestSAFFile(parse);
                if (nearestSAFFile == null || !nearestSAFFile.exists()) {
                    if (map.containsKey("idempotent")) {
                        Object obj2 = map.get("idempotent");
                        if (obj2 == null) {
                            throw new NullPointerException("null cannot be cast to non-null type kotlin.Boolean");
                        } else if (((Boolean) obj2).booleanValue()) {
                            promise.resolve(null);
                            return;
                        }
                    }
                    promise.reject("ERR_FILESYSTEM_CANNOT_FIND_FILE", "File '" + parse + "' could not be deleted because it could not be found");
                    return;
                }
                nearestSAFFile.delete();
                promise.resolve(null);
                return;
            }
            throw new IOException("Unsupported scheme for location '" + parse + "'.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void moveAsync(Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            if (!map.containsKey("from")) {
                promise.reject("ERR_FILESYSTEM_MISSING_PARAMETER", "`FileSystem.moveAsync` needs a `from` path.");
                return;
            }
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath((String) map.get("from")));
            Uri withAppendedPath = Uri.withAppendedPath(parse, "..");
            Intrinsics.checkNotNullExpressionValue(withAppendedPath, "withAppendedPath(fromUri, \"..\")");
            Permission permission = Permission.WRITE;
            ensurePermission(withAppendedPath, permission, "Location '" + parse + "' isn't movable.");
            if (!map.containsKey("to")) {
                promise.reject("ERR_FILESYSTEM_MISSING_PARAMETER", "`FileSystem.moveAsync` needs a `to` path.");
                return;
            }
            Uri parse2 = Uri.parse(FileSystemModuleKt.slashifyFilePath((String) map.get("to")));
            Intrinsics.checkNotNullExpressionValue(parse2, "toUri");
            ensurePermission(parse2, Permission.WRITE);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                Intrinsics.checkNotNullExpressionValue(parse, "fromUri");
                if (toFile(parse).renameTo(toFile(parse2))) {
                    promise.resolve(null);
                    return;
                }
                promise.reject("ERR_FILESYSTEM_CANNOT_MOVE_FILE", "File '" + parse + "' could not be moved to '" + parse2 + "'");
                return;
            }
            Intrinsics.checkNotNullExpressionValue(parse, "fromUri");
            if (isSAFUri(parse)) {
                DocumentFile nearestSAFFile = getNearestSAFFile(parse);
                if (nearestSAFFile == null || !nearestSAFFile.exists()) {
                    promise.reject("ERR_FILESYSTEM_CANNOT_MOVE_FILE", "File '" + parse + "' could not be moved to '" + parse2 + "'");
                    return;
                }
                transformFilesFromSAF(nearestSAFFile, new File(parse2.getPath()), false);
                promise.resolve(null);
                return;
            }
            throw new IOException("Unsupported scheme for location '" + parse + "'.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void copyAsync(Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            if (!map.containsKey("from")) {
                promise.reject("ERR_FILESYSTEM_MISSING_PARAMETER", "`FileSystem.moveAsync` needs a `from` path.");
                return;
            }
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath((String) map.get("from")));
            Intrinsics.checkNotNullExpressionValue(parse, "fromUri");
            ensurePermission(parse, Permission.READ);
            if (!map.containsKey("to")) {
                promise.reject("ERR_FILESYSTEM_MISSING_PARAMETER", "`FileSystem.moveAsync` needs a `to` path.");
                return;
            }
            Uri parse2 = Uri.parse(FileSystemModuleKt.slashifyFilePath((String) map.get("to")));
            Intrinsics.checkNotNullExpressionValue(parse2, "toUri");
            ensurePermission(parse2, Permission.WRITE);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                File file = toFile(parse);
                File file2 = toFile(parse2);
                if (file.isDirectory()) {
                    FileUtils.copyDirectory(file, file2);
                } else {
                    FileUtils.copyFile(file, file2);
                }
                promise.resolve(null);
            } else if (isSAFUri(parse)) {
                DocumentFile nearestSAFFile = getNearestSAFFile(parse);
                if (nearestSAFFile == null || !nearestSAFFile.exists()) {
                    promise.reject("ERR_FILESYSTEM_CANNOT_FIND_FILE", "File '" + parse + "' could not be copied because it could not be found");
                    return;
                }
                transformFilesFromSAF(nearestSAFFile, new File(parse2.getPath()), true);
                promise.resolve(null);
            } else if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_CONTENT_SCHEME)) {
                IOUtils.copy(getContext().getContentResolver().openInputStream(parse), new FileOutputStream(toFile(parse2)));
                promise.resolve(null);
            } else if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_ASSET_SCHEME)) {
                IOUtils.copy(openAssetInputStream(parse), new FileOutputStream(toFile(parse2)));
                promise.resolve(null);
            } else if (parse.getScheme() == null) {
                IOUtils.copy(openResourceInputStream((String) map.get("from")), new FileOutputStream(toFile(parse2)));
                promise.resolve(null);
            } else {
                throw new IOException("Unsupported scheme for location '" + parse + "'.");
            }
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:33:0x008f, code lost:
        r9 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x0090, code lost:
        kotlin.io.CloseableKt.closeFinally(r2, r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0093, code lost:
        throw r9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x0096, code lost:
        r9 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x0097, code lost:
        kotlin.io.CloseableKt.closeFinally(r8, r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x009a, code lost:
        throw r9;
     */
    private final void transformFilesFromSAF(DocumentFile documentFile, File file, boolean z) {
        if (documentFile.exists()) {
            if (!file.exists() && !file.mkdirs()) {
                throw new IOException("Couldn't create folder in output dir.");
            } else if (documentFile.isDirectory()) {
                DocumentFile[] listFiles = documentFile.listFiles();
                Intrinsics.checkNotNullExpressionValue(listFiles, "documentFile.listFiles()");
                for (DocumentFile documentFile2 : listFiles) {
                    String name = documentFile.getName();
                    if (name != null) {
                        Intrinsics.checkNotNullExpressionValue(documentFile2, UriUtil.LOCAL_FILE_SCHEME);
                        transformFilesFromSAF(documentFile2, new File(file, name), z);
                    }
                }
                if (!z) {
                    documentFile.delete();
                }
            } else {
                String name2 = documentFile.getName();
                if (name2 != null) {
                    File file2 = new File(file.getPath(), name2);
                    InputStream openInputStream = getContext().getContentResolver().openInputStream(documentFile.getUri());
                    InputStream inputStream = openInputStream;
                    FileOutputStream fileOutputStream = new FileOutputStream(file2);
                    IOUtils.copy(inputStream, fileOutputStream);
                    CloseableKt.closeFinally(fileOutputStream, null);
                    CloseableKt.closeFinally(openInputStream, null);
                    if (!z) {
                        documentFile.delete();
                    }
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0053 A[Catch:{ Exception -> 0x00a0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0058 A[Catch:{ Exception -> 0x00a0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x005e A[Catch:{ Exception -> 0x00a0 }] */
    public final void makeDirectoryAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        boolean z;
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.WRITE);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                File file = toFile(parse);
                boolean isDirectory = file.isDirectory();
                if (map.containsKey("intermediates")) {
                    Object obj = map.get("intermediates");
                    if (obj == null) {
                        throw new NullPointerException("null cannot be cast to non-null type kotlin.Boolean");
                    } else if (((Boolean) obj).booleanValue()) {
                        z = true;
                        if (!(!z ? file.mkdirs() : file.mkdir())) {
                            if (!z || !isDirectory) {
                                promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_DIRECTORY", "Directory '" + parse + "' could not be created or already exists.");
                                return;
                            }
                        }
                        promise.resolve(null);
                        return;
                    }
                }
                z = false;
                if (!(!z ? file.mkdirs() : file.mkdir())) {
                }
                promise.resolve(null);
                return;
            }
            throw new IOException("Unsupported scheme for location '" + parse + "'.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void readDirectoryAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.READ);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                File[] listFiles = toFile(parse).listFiles();
                if (listFiles != null) {
                    ArrayList arrayList = new ArrayList(listFiles.length);
                    int i = 0;
                    int length = listFiles.length;
                    while (i < length) {
                        File file = listFiles[i];
                        i++;
                        arrayList.add(file.getName());
                    }
                    promise.resolve(arrayList);
                    return;
                }
                promise.reject("ERR_FILESYSTEM_CANNOT_READ_DIRECTORY", "Directory '" + parse + "' could not be read.");
            } else if (isSAFUri(parse)) {
                promise.reject("ERR_FILESYSTEM_UNSUPPORTED_SCHEME", "Can't read Storage Access Framework directory, use StorageAccessFramework.readDirectoryAsync() instead.");
            } else {
                throw new IOException("Unsupported scheme for location '" + parse + "'.");
            }
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void getTotalDiskCapacityAsync(Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            StatFs statFs = new StatFs(Environment.getDataDirectory().getAbsolutePath());
            promise.resolve(Double.valueOf(Math.min(BigInteger.valueOf(statFs.getBlockCountLong()).multiply(BigInteger.valueOf(statFs.getBlockSizeLong())).doubleValue(), Math.pow(2.0d, 53.0d) - ((double) 1))));
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject("ERR_FILESYSTEM_CANNOT_DETERMINE_DISK_CAPACITY", "Unable to access total disk capacity", e);
        }
    }

    public final void getFreeDiskStorageAsync(Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            StatFs statFs = new StatFs(Environment.getDataDirectory().getAbsolutePath());
            promise.resolve(Double.valueOf(Math.min(BigInteger.valueOf(statFs.getAvailableBlocksLong()).multiply(BigInteger.valueOf(statFs.getBlockSizeLong())).doubleValue(), Math.pow(2.0d, 53.0d) - ((double) 1))));
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject("ERR_FILESYSTEM_CANNOT_DETERMINE_DISK_CAPACITY", "Unable to determine free disk storage capacity", e);
        }
    }

    public final void getContentUriAsync(String str, Promise promise) {
        Intrinsics.checkNotNullParameter(str, "uri");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "fileUri");
            ensurePermission(parse, Permission.WRITE);
            ensurePermission(parse, Permission.READ);
            checkIfFileDirExists(parse);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                promise.resolve(contentUriFromFile(toFile(parse)).toString());
                return;
            }
            promise.reject("ERR_FILESYSTEM_CANNOT_READ_DIRECTORY", "No readable files with the uri '" + str + "'. Please use other uri.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    /* renamed from: contentUriFromFile$lambda-27 */
    private static final ActivityProvider m52contentUriFromFile$lambda27(Lazy<? extends ActivityProvider> lazy) {
        Object value = lazy.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "contentUriFromFile$lambda-27(...)");
        return (ActivityProvider) value;
    }

    public final void readSAFDirectoryAsync(String str, Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.READ);
            if (isSAFUri(parse)) {
                DocumentFile fromTreeUri = DocumentFile.fromTreeUri(getContext(), parse);
                if (fromTreeUri != null && fromTreeUri.exists()) {
                    if (fromTreeUri.isDirectory()) {
                        DocumentFile[] listFiles = fromTreeUri.listFiles();
                        Intrinsics.checkNotNullExpressionValue(listFiles, "file.listFiles()");
                        ArrayList arrayList = new ArrayList(listFiles.length);
                        int i = 0;
                        int length = listFiles.length;
                        while (i < length) {
                            DocumentFile documentFile = listFiles[i];
                            i++;
                            arrayList.add(documentFile.getUri().toString());
                        }
                        promise.resolve(arrayList);
                        return;
                    }
                }
                promise.reject("ERR_FILESYSTEM_CANNOT_READ_DIRECTORY", "Uri '" + parse + "' doesn't exist or isn't a directory.");
                return;
            }
            throw new IOException("The URI '" + parse + "' is not a Storage Access Framework URI. Try using FileSystem.readDirectoryAsync instead.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void makeSAFDirectoryAsync(String str, String str2, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.WRITE);
            if (isSAFUri(parse)) {
                DocumentFile nearestSAFFile = getNearestSAFFile(parse);
                if (nearestSAFFile == null || nearestSAFFile.isDirectory()) {
                    DocumentFile documentFile = null;
                    if (!(str2 == null || nearestSAFFile == null)) {
                        documentFile = nearestSAFFile.createDirectory(str2);
                    }
                    if (documentFile == null) {
                        promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_DIRECTORY", "Unknown error.");
                    } else {
                        promise.resolve(documentFile.getUri().toString());
                    }
                } else {
                    promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_DIRECTORY", "Provided uri '" + parse + "' is not pointing to a directory.");
                }
            } else {
                throw new IOException("The URI '" + parse + "' is not a Storage Access Framework URI. Try using FileSystem.makeDirectoryAsync instead.");
            }
        } catch (Exception e) {
            promise.reject(e);
        }
    }

    public final void createSAFFileAsync(String str, String str2, String str3, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.WRITE);
            if (isSAFUri(parse)) {
                DocumentFile nearestSAFFile = getNearestSAFFile(parse);
                if (nearestSAFFile == null || !nearestSAFFile.isDirectory()) {
                    promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_FILE", "Provided uri '" + parse + "' is not pointing to a directory.");
                } else if (str3 == null || str2 == null) {
                    promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_FILE", "Parameters fileName and mimeType can not be null.");
                } else {
                    DocumentFile createFile = nearestSAFFile.createFile(str3, str2);
                    if (createFile == null) {
                        promise.reject("ERR_FILESYSTEM_CANNOT_CREATE_FILE", "Unknown error.");
                    } else {
                        promise.resolve(createFile.getUri().toString());
                    }
                }
            } else {
                throw new IOException("The URI '" + parse + "' is not a Storage Access Framework URI.");
            }
        } catch (Exception e) {
            promise.reject(e);
        }
    }

    public final void requestDirectoryPermissionsAsync(String str, Promise promise) {
        Uri parse;
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        if (this.dirPermissionsRequest != null) {
            promise.reject("ERR_FILESYSTEM_CANNOT_ASK_FOR_PERMISSIONS", "You have an unfinished permission request.");
            return;
        }
        try {
            Intent intent = new Intent("android.intent.action.OPEN_DOCUMENT_TREE");
            if (!(Build.VERSION.SDK_INT < 26 || str == null || (parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str))) == null)) {
                intent.putExtra("android.provider.extra.INITIAL_URI", parse);
            }
            Activity currentActivity = m54requestDirectoryPermissionsAsync$lambda33(LazyKt.lazy(new FileSystemModule$requestDirectoryPermissionsAsync$$inlined$moduleRegistry$1(this.moduleRegistryDelegate))).getCurrentActivity();
            if (currentActivity == null) {
                promise.reject("ERR_FILESYSTEM_CANNOT_ASK_FOR_PERMISSIONS", "Can't find activity.");
                return;
            }
            getUIManager().registerActivityEventListener(this);
            this.dirPermissionsRequest = promise;
            currentActivity.startActivityForResult(intent, 5394);
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject("ERR_FILESYSTEM_CANNOT_ASK_FOR_PERMISSIONS", "Can't ask for permissions.", e);
        }
    }

    /* renamed from: requestDirectoryPermissionsAsync$lambda-33 */
    private static final ActivityProvider m54requestDirectoryPermissionsAsync$lambda33(Lazy<? extends ActivityProvider> lazy) {
        Object value = lazy.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "requestDirectoryPermissionsAsync$lambda-33(...)");
        return (ActivityProvider) value;
    }

    private final Request createUploadRequest(String str, String str2, Map<String, ? extends Object> map, Promise promise, RequestBodyDecorator requestBodyDecorator) {
        Map map2;
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str2));
            Intrinsics.checkNotNullExpressionValue(parse, "fileUri");
            ensurePermission(parse, Permission.READ);
            checkIfFileExists(parse);
            if (!map.containsKey("httpMethod")) {
                promise.reject("ERR_FILESYSTEM_MISSING_HTTP_METHOD", "Missing HTTP method.", null);
                return null;
            }
            String str3 = (String) map.get("httpMethod");
            if (!map.containsKey("uploadType")) {
                promise.reject("ERR_FILESYSTEM_MISSING_UPLOAD_TYPE", "Missing upload type.", null);
                return null;
            }
            Request.Builder url = new Request.Builder().url(str);
            if (map.containsKey("headers") && (map2 = (Map) map.get("headers")) != null) {
                for (Map.Entry entry : map2.entrySet()) {
                    url.addHeader((String) entry.getKey(), entry.getValue().toString());
                }
            }
            RequestBody createRequestBody = createRequestBody(map, requestBodyDecorator, toFile(parse));
            if (str3 != null) {
                return url.method(str3, createRequestBody).build();
            }
            return null;
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
            return null;
        }
    }

    private final RequestBody createRequestBody(Map<String, ? extends Object> map, RequestBodyDecorator requestBodyDecorator, File file) {
        String str;
        UploadType.Companion companion = UploadType.Companion;
        Object obj = map.get("uploadType");
        Objects.requireNonNull(obj, "null cannot be cast to non-null type kotlin.Double");
        UploadType fromInt = companion.fromInt((int) ((Double) obj).doubleValue());
        if (fromInt == UploadType.BINARY_CONTENT) {
            return requestBodyDecorator.decorate(RequestBody.Companion.create((MediaType) null, file));
        }
        if (fromInt == UploadType.MULTIPART) {
            MultipartBody.Builder type = new MultipartBody.Builder(null, 1, null).setType(MultipartBody.FORM);
            Object obj2 = map.get("parameters");
            if (obj2 != null) {
                for (Map.Entry entry : ((Map) obj2).entrySet()) {
                    type.addFormDataPart((String) entry.getKey(), entry.getValue().toString());
                }
            }
            Object obj3 = map.get("mimeType");
            if (obj3 != null) {
                str = (String) obj3;
            } else {
                str = URLConnection.guessContentTypeFromName(file.getName());
                Intrinsics.checkNotNullExpressionValue(str, "guessContentTypeFromName(file.name)");
            }
            Object obj4 = map.get("fieldName");
            String name = obj4 != null ? (String) obj4 : file.getName();
            Intrinsics.checkNotNullExpressionValue(name, "fieldName");
            type.addFormDataPart(name, file.getName(), requestBodyDecorator.decorate(RequestBody.Companion.create(file, MediaType.Companion.parse(str))));
            return type.build();
        }
        StringCompanionObject stringCompanionObject = StringCompanionObject.INSTANCE;
        String format = String.format("Invalid upload type: %s.", Arrays.copyOf(new Object[]{map.get("uploadType")}, 1));
        Intrinsics.checkNotNullExpressionValue(format, "format(format, *args)");
        throw new IllegalArgumentException("ERR_FILESYSTEM_INVALID_UPLOAD_TYPE. " + format);
    }

    public final void uploadAsync(String str, String str2, Map<String, ? extends Object> map, Promise promise) {
        Unit unit;
        Intrinsics.checkNotNullParameter(str, ImagesContract.URL);
        Intrinsics.checkNotNullParameter(str2, "fileUriString");
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        Request createUploadRequest = createUploadRequest(str, str2, map, promise, FileSystemModule$$ExternalSyntheticLambda0.INSTANCE);
        if (createUploadRequest != null) {
            OkHttpClient okHttpClient = getOkHttpClient();
            if (okHttpClient != null) {
                okHttpClient.newCall(createUploadRequest).enqueue(new FileSystemModule$uploadAsync$1$1(promise, this));
                unit = Unit.INSTANCE;
            } else {
                unit = null;
            }
            if (unit == null) {
                promise.reject(new NullPointerException("okHttpClient is null"));
            }
        }
    }

    public final void uploadTaskStartAsync(String str, String str2, String str3, Map<String, ? extends Object> map, Promise promise) {
        Intrinsics.checkNotNullParameter(str, ImagesContract.URL);
        Intrinsics.checkNotNullParameter(str2, "fileUriString");
        Intrinsics.checkNotNullParameter(str3, ExponentInstallationId.LEGACY_UUID_KEY);
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        Request createUploadRequest = createUploadRequest(str, str2, map, promise, new FileSystemModule$uploadTaskStartAsync$request$1(new FileSystemModule$uploadTaskStartAsync$progressListener$1(this, str3)));
        if (createUploadRequest != null) {
            OkHttpClient okHttpClient = getOkHttpClient();
            Intrinsics.checkNotNull(okHttpClient);
            Call newCall = okHttpClient.newCall(createUploadRequest);
            this.taskHandlers.put(str3, new TaskHandler(newCall));
            newCall.enqueue(new FileSystemModule$uploadTaskStartAsync$1(promise, this));
        }
    }

    public final void downloadAsync(String str, String str2, Map<String, ? extends Object> map, Promise promise) {
        Call newCall;
        Intrinsics.checkNotNullParameter(str, ImagesContract.URL);
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str2));
            Intrinsics.checkNotNullExpressionValue(parse, "uri");
            ensurePermission(parse, Permission.WRITE);
            checkIfFileDirExists(parse);
            Object obj = null;
            if (!StringsKt.contains$default((CharSequence) str, (CharSequence) ":", false, 2, (Object) null)) {
                Context context = getContext();
                InputStream openRawResource = context.getResources().openRawResource(context.getResources().getIdentifier(str, "raw", context.getPackageName()));
                Intrinsics.checkNotNullExpressionValue(openRawResource, "context.resources.openRawResource(resourceId)");
                BufferedSource buffer = Okio.buffer(Okio.source(openRawResource));
                File file = toFile(parse);
                file.delete();
                BufferedSink buffer2 = Okio.buffer(Okio__JvmOkioKt.sink$default(file, false, 1, null));
                buffer2.writeAll(buffer);
                buffer2.close();
                Bundle bundle = new Bundle();
                bundle.putString("uri", Uri.fromFile(file).toString());
                Object obj2 = map != null ? map.get("md5") : null;
                if (Intrinsics.areEqual(obj2, (Object) true)) {
                    obj = obj2;
                }
                if (obj != null) {
                    bundle.putString("md5", md5(file));
                }
                promise.resolve(bundle);
            } else if (Intrinsics.areEqual(UriUtil.LOCAL_FILE_SCHEME, parse.getScheme())) {
                Request.Builder url = new Request.Builder().url(str);
                if (map != null && map.containsKey("headers")) {
                    try {
                        Map map2 = (Map) map.get("headers");
                        if (map2 != null) {
                            for (Map.Entry entry : map2.entrySet()) {
                                url.addHeader((String) entry.getKey(), entry.getValue().toString());
                            }
                        }
                    } catch (ClassCastException e) {
                        promise.reject("ERR_FILESYSTEM_INVALID_HEADERS", "Invalid headers dictionary. Keys and values should be strings.", e);
                        return;
                    }
                }
                OkHttpClient okHttpClient = getOkHttpClient();
                if (!(okHttpClient == null || (newCall = okHttpClient.newCall(url.build())) == null)) {
                    newCall.enqueue(new FileSystemModule$downloadAsync$4(promise, this, parse, map));
                    obj = Unit.INSTANCE;
                }
                if (obj == null) {
                    promise.reject(new NullPointerException("okHttpClient is null"));
                }
            } else {
                throw new IOException("Unsupported scheme for location '" + parse + "'.");
            }
        } catch (Exception e2) {
            String message = e2.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e2);
        }
    }

    public final void networkTaskCancelAsync(String str, Promise promise) {
        Call call;
        Intrinsics.checkNotNullParameter(str, ExponentInstallationId.LEGACY_UUID_KEY);
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        TaskHandler taskHandler = this.taskHandlers.get(str);
        if (!(taskHandler == null || (call = taskHandler.getCall()) == null)) {
            call.cancel();
        }
        promise.resolve(null);
    }

    public final void downloadResumableStartAsync(String str, String str2, String str3, Map<String, ? extends Object> map, String str4, Promise promise) {
        Map map2;
        OkHttpClient.Builder newBuilder;
        OkHttpClient.Builder addNetworkInterceptor;
        Intrinsics.checkNotNullParameter(str, ImagesContract.URL);
        Intrinsics.checkNotNullParameter(str2, "fileUriStr");
        Intrinsics.checkNotNullParameter(str3, ExponentInstallationId.LEGACY_UUID_KEY);
        Intrinsics.checkNotNullParameter(map, "options");
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        try {
            Uri parse = Uri.parse(FileSystemModuleKt.slashifyFilePath(str2));
            Intrinsics.checkNotNullExpressionValue(parse, "fileUri");
            checkIfFileDirExists(parse);
            if (Intrinsics.areEqual(parse.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
                FileSystemModule$downloadResumableStartAsync$progressListener$1 fileSystemModule$downloadResumableStartAsync$progressListener$1 = new FileSystemModule$downloadResumableStartAsync$progressListener$1(this, str4, str3);
                OkHttpClient okHttpClient = getOkHttpClient();
                OkHttpClient build = (okHttpClient == null || (newBuilder = okHttpClient.newBuilder()) == null || (addNetworkInterceptor = newBuilder.addNetworkInterceptor(new FileSystemModule$downloadResumableStartAsync$$inlined$addNetworkInterceptor$1(fileSystemModule$downloadResumableStartAsync$progressListener$1))) == null) ? null : addNetworkInterceptor.build();
                if (build == null) {
                    promise.reject(new NullPointerException("okHttpClient is null"));
                    return;
                }
                Request.Builder builder = new Request.Builder();
                if (str4 != null) {
                    builder.addHeader("Range", "bytes=" + str4 + "-");
                }
                if (map.containsKey("headers") && (map2 = (Map) map.get("headers")) != null) {
                    for (Map.Entry entry : map2.entrySet()) {
                        builder.addHeader((String) entry.getKey(), entry.getValue().toString());
                    }
                }
                DownloadResumableTask downloadResumableTask = new DownloadResumableTask();
                Call newCall = build.newCall(builder.url(str).build());
                this.taskHandlers.put(str3, new DownloadTaskHandler(parse, newCall));
                downloadResumableTask.execute(new DownloadResumableTaskParams(map, newCall, toFile(parse), str4 != null, promise));
                return;
            }
            throw new IOException("Unsupported scheme for location '" + parse + "'.");
        } catch (Exception e) {
            String message = e.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(e);
        }
    }

    public final void downloadResumablePauseAsync(String str, Promise promise) {
        Intrinsics.checkNotNullParameter(str, ExponentInstallationId.LEGACY_UUID_KEY);
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        TaskHandler taskHandler = this.taskHandlers.get(str);
        if (taskHandler == null) {
            IOException iOException = new IOException("No download object available");
            String message = iOException.getMessage();
            if (message != null) {
                Log.e(FileSystemModuleKt.TAG, message);
            }
            promise.reject(iOException);
        } else if (!(taskHandler instanceof DownloadTaskHandler)) {
            promise.reject("ERR_FILESYSTEM_CANNOT_FIND_TASK", "Cannot find task.");
        } else {
            ((DownloadTaskHandler) taskHandler).getCall().cancel();
            this.taskHandlers.remove(str);
            try {
                File file = toFile(((DownloadTaskHandler) taskHandler).getFileUri());
                Bundle bundle = new Bundle();
                bundle.putString("resumeData", String.valueOf(file.length()));
                promise.resolve(bundle);
            } catch (Exception e) {
                String message2 = e.getMessage();
                if (message2 != null) {
                    Log.e(FileSystemModuleKt.TAG, message2);
                }
                promise.reject(e);
            }
        }
    }

    @Override // expo.modules.core.interfaces.ActivityEventListener
    public void onActivityResult(Activity activity, int i, int i2, Intent intent) {
        Intrinsics.checkNotNullParameter(activity, "activity");
        if (i == 5394 && this.dirPermissionsRequest != null) {
            Bundle bundle = new Bundle();
            if (i2 != -1 || intent == null) {
                bundle.putBoolean(PermissionsResponse.GRANTED_KEY, false);
            } else {
                Uri data = intent.getData();
                int flags = intent.getFlags() & 3;
                if (data != null) {
                    activity.getContentResolver().takePersistableUriPermission(data, flags);
                }
                bundle.putBoolean(PermissionsResponse.GRANTED_KEY, true);
                bundle.putString("directoryUri", String.valueOf(data));
            }
            Promise promise = this.dirPermissionsRequest;
            if (promise != null) {
                promise.resolve(bundle);
            }
            getUIManager().unregisterActivityEventListener(this);
            this.dirPermissionsRequest = null;
        }
    }

    public static final class DownloadResumableTaskParams {
        private Call call;
        private File file;
        private boolean isResume;
        private Map<String, ? extends Object> options;
        private Promise promise;

        public DownloadResumableTaskParams(Map<String, ? extends Object> map, Call call2, File file2, boolean z, Promise promise2) {
            Intrinsics.checkNotNullParameter(call2, NotificationCompat.CATEGORY_CALL);
            Intrinsics.checkNotNullParameter(file2, UriUtil.LOCAL_FILE_SCHEME);
            Intrinsics.checkNotNullParameter(promise2, BaseJavaModule.METHOD_TYPE_PROMISE);
            this.options = map;
            this.call = call2;
            this.file = file2;
            this.isResume = z;
            this.promise = promise2;
        }

        public final Call getCall() {
            return this.call;
        }

        public final File getFile() {
            return this.file;
        }

        public final Map<String, Object> getOptions() {
            return this.options;
        }

        public final Promise getPromise() {
            return this.promise;
        }

        public final boolean isResume() {
            return this.isResume;
        }

        public final void setCall(Call call2) {
            Intrinsics.checkNotNullParameter(call2, "<set-?>");
            this.call = call2;
        }

        public final void setFile(File file2) {
            Intrinsics.checkNotNullParameter(file2, "<set-?>");
            this.file = file2;
        }

        public final void setOptions(Map<String, ? extends Object> map) {
            this.options = map;
        }

        public final void setPromise(Promise promise2) {
            Intrinsics.checkNotNullParameter(promise2, "<set-?>");
            this.promise = promise2;
        }

        public final void setResume(boolean z) {
            this.isResume = z;
        }
    }

    private final class DownloadResumableTask extends AsyncTask<DownloadResumableTaskParams, Void, Void> {
        public DownloadResumableTask() {
            FileSystemModule.this = r1;
        }

        public Void doInBackground(DownloadResumableTaskParams... downloadResumableTaskParamsArr) {
            Intrinsics.checkNotNullParameter(downloadResumableTaskParamsArr, "params");
            boolean z = false;
            DownloadResumableTaskParams downloadResumableTaskParams = downloadResumableTaskParamsArr[0];
            Call call = downloadResumableTaskParams != null ? downloadResumableTaskParams.getCall() : null;
            DownloadResumableTaskParams downloadResumableTaskParams2 = downloadResumableTaskParamsArr[0];
            Promise promise = downloadResumableTaskParams2 != null ? downloadResumableTaskParams2.getPromise() : null;
            DownloadResumableTaskParams downloadResumableTaskParams3 = downloadResumableTaskParamsArr[0];
            File file = downloadResumableTaskParams3 != null ? downloadResumableTaskParams3.getFile() : null;
            DownloadResumableTaskParams downloadResumableTaskParams4 = downloadResumableTaskParamsArr[0];
            Boolean valueOf = downloadResumableTaskParams4 != null ? Boolean.valueOf(downloadResumableTaskParams4.isResume()) : null;
            DownloadResumableTaskParams downloadResumableTaskParams5 = downloadResumableTaskParamsArr[0];
            Map<String, Object> options = downloadResumableTaskParams5 != null ? downloadResumableTaskParams5.getOptions() : null;
            try {
                Intrinsics.checkNotNull(call);
                Response execute = call.execute();
                ResponseBody body = execute.body();
                Intrinsics.checkNotNull(body);
                BufferedInputStream bufferedInputStream = new BufferedInputStream(body.byteStream());
                FileOutputStream fileOutputStream = new FileOutputStream(file, Intrinsics.areEqual((Object) valueOf, (Object) true));
                byte[] bArr = new byte[1024];
                while (true) {
                    int read = bufferedInputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    fileOutputStream.write(bArr, 0, read);
                }
                Bundle bundle = new Bundle();
                FileSystemModule fileSystemModule = FileSystemModule.this;
                bundle.putString("uri", Uri.fromFile(file).toString());
                bundle.putInt("status", execute.code());
                bundle.putBundle("headers", fileSystemModule.translateHeaders(execute.headers()));
                Object obj = options != null ? options.get("md5") : null;
                if (!Intrinsics.areEqual(obj, (Object) true)) {
                    obj = null;
                }
                if (obj != null) {
                    bundle.putString("md5", file != null ? fileSystemModule.md5(file) : null);
                }
                execute.close();
                if (promise != null) {
                    promise.resolve(bundle);
                }
                return null;
            } catch (Exception e) {
                if (call != null && call.isCanceled()) {
                    z = true;
                }
                if (z) {
                    if (promise != null) {
                        promise.resolve(null);
                    }
                    return null;
                }
                String message = e.getMessage();
                if (message != null) {
                    Log.e(FileSystemModuleKt.TAG, message);
                }
                if (promise != null) {
                    promise.reject(e);
                }
                return null;
            }
        }
    }

    /* access modifiers changed from: private */
    public static class TaskHandler {
        private final Call call;

        public TaskHandler(Call call2) {
            Intrinsics.checkNotNullParameter(call2, NotificationCompat.CATEGORY_CALL);
            this.call = call2;
        }

        public final Call getCall() {
            return this.call;
        }
    }

    private static final class DownloadTaskHandler extends TaskHandler {
        private final Uri fileUri;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public DownloadTaskHandler(Uri uri, Call call) {
            super(call);
            Intrinsics.checkNotNullParameter(uri, "fileUri");
            Intrinsics.checkNotNullParameter(call, NotificationCompat.CATEGORY_CALL);
            this.fileUri = uri;
        }

        public final Uri getFileUri() {
            return this.fileUri;
        }
    }

    public static final class ProgressResponseBody extends ResponseBody {
        private BufferedSource bufferedSource;
        private final ProgressListener progressListener;
        private final ResponseBody responseBody;

        public ProgressResponseBody(ResponseBody responseBody2, ProgressListener progressListener2) {
            Intrinsics.checkNotNullParameter(progressListener2, "progressListener");
            this.responseBody = responseBody2;
            this.progressListener = progressListener2;
        }

        @Override // okhttp3.ResponseBody
        public MediaType contentType() {
            ResponseBody responseBody2 = this.responseBody;
            if (responseBody2 != null) {
                return responseBody2.contentType();
            }
            return null;
        }

        @Override // okhttp3.ResponseBody
        public long contentLength() {
            ResponseBody responseBody2 = this.responseBody;
            if (responseBody2 != null) {
                return responseBody2.contentLength();
            }
            return -1;
        }

        @Override // okhttp3.ResponseBody
        public BufferedSource source() {
            BufferedSource bufferedSource2 = this.bufferedSource;
            if (bufferedSource2 != null) {
                return bufferedSource2;
            }
            ResponseBody responseBody2 = this.responseBody;
            Intrinsics.checkNotNull(responseBody2);
            return Okio.buffer(source(responseBody2.source()));
        }

        private final Source source(Source source) {
            return new FileSystemModule$ProgressResponseBody$source$1(source, this);
        }
    }

    private final synchronized OkHttpClient getOkHttpClient() {
        if (this.client == null) {
            OkHttpClient.Builder writeTimeout = new OkHttpClient.Builder().connectTimeout(60, TimeUnit.SECONDS).readTimeout(60, TimeUnit.SECONDS).writeTimeout(60, TimeUnit.SECONDS);
            writeTimeout.cookieJar(new JavaNetCookieJar(m51_get_okHttpClient_$lambda59(LazyKt.lazy(new FileSystemModule$special$$inlined$moduleRegistry$2(this.moduleRegistryDelegate)))));
            this.client = writeTimeout.build();
        }
        return this.client;
    }

    /* renamed from: _get_okHttpClient_$lambda-59 */
    private static final CookieHandler m51_get_okHttpClient_$lambda59(Lazy<? extends CookieHandler> lazy) {
        Object value = lazy.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "_get_okHttpClient_$lambda-59(...)");
        return (CookieHandler) value;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0029, code lost:
        throw r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x0025, code lost:
        r1 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0026, code lost:
        kotlin.io.CloseableKt.closeFinally(r0, r3);
     */
    private final String md5(File file) {
        FileInputStream fileInputStream = new FileInputStream(file);
        char[] encodeHex = Hex.encodeHex(DigestUtils.md5(fileInputStream));
        Intrinsics.checkNotNullExpressionValue(encodeHex, "encodeHex(md5bytes)");
        String str = new String(encodeHex);
        CloseableKt.closeFinally(fileInputStream, null);
        return str;
    }

    private final void ensureDirExists(File file) {
        if (!file.isDirectory() && !file.mkdirs()) {
            throw new IOException("Couldn't create directory '" + file + "'");
        }
    }

    private final void forceDelete(File file) {
        if (file.isDirectory()) {
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                IOException e = null;
                for (File file2 : listFiles) {
                    try {
                        Intrinsics.checkNotNullExpressionValue(file2, "f");
                        forceDelete(file2);
                    } catch (IOException e2) {
                        e = e2;
                    }
                }
                if (e != null) {
                    throw e;
                } else if (!file.delete()) {
                    throw new IOException("Unable to delete directory " + file + ".");
                }
            } else {
                throw new IOException("Failed to list contents of " + file);
            }
        } else if (!file.delete()) {
            throw new IOException("Unable to delete file: " + file);
        }
    }

    private final long getFileSize(File file) {
        Object obj;
        if (!file.isDirectory()) {
            return file.length();
        }
        File[] listFiles = file.listFiles();
        if (listFiles == null) {
            return 0;
        }
        ArrayList arrayList = new ArrayList(listFiles.length);
        int i = 0;
        int length = listFiles.length;
        while (i < length) {
            File file2 = listFiles[i];
            i++;
            Intrinsics.checkNotNullExpressionValue(file2, "it");
            arrayList.add(Long.valueOf(getFileSize(file2)));
        }
        Iterator it = arrayList.iterator();
        if (!it.hasNext()) {
            obj = null;
        } else {
            Object next = it.next();
            while (it.hasNext()) {
                next = Long.valueOf(((Number) next).longValue() + ((Number) it.next()).longValue());
            }
            obj = next;
        }
        Long l = (Long) obj;
        if (l != null) {
            return l.longValue();
        }
        return 0;
    }

    private final String getEncodingFromOptions(Map<String, ? extends Object> map) {
        if (!map.containsKey("encoding") || !(map.get("encoding") instanceof String)) {
            return "utf8";
        }
        Object obj = map.get("encoding");
        Objects.requireNonNull(obj, "null cannot be cast to non-null type kotlin.String");
        Locale locale = Locale.ROOT;
        Intrinsics.checkNotNullExpressionValue(locale, "ROOT");
        String lowerCase = ((String) obj).toLowerCase(locale);
        Intrinsics.checkNotNullExpressionValue(lowerCase, "this as java.lang.String).toLowerCase(locale)");
        return lowerCase;
    }

    private final InputStream getInputStream(Uri uri) {
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
            return new FileInputStream(toFile(uri));
        }
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_ASSET_SCHEME)) {
            return openAssetInputStream(uri);
        }
        if (isSAFUri(uri)) {
            InputStream openInputStream = getContext().getContentResolver().openInputStream(uri);
            Intrinsics.checkNotNull(openInputStream);
            return openInputStream;
        }
        throw new IOException("Unsupported scheme for location '" + uri + "'.");
    }

    private final OutputStream getOutputStream(Uri uri) {
        FileOutputStream fileOutputStream;
        if (Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_FILE_SCHEME)) {
            fileOutputStream = new FileOutputStream(toFile(uri));
        } else if (isSAFUri(uri)) {
            fileOutputStream = getContext().getContentResolver().openOutputStream(uri);
            Intrinsics.checkNotNull(fileOutputStream);
        } else {
            throw new IOException("Unsupported scheme for location '" + uri + "'.");
        }
        Intrinsics.checkNotNullExpressionValue(fileOutputStream, "when {\n    uri.scheme ==…or location '$uri'.\")\n  }");
        return fileOutputStream;
    }

    private final DocumentFile getNearestSAFFile(Uri uri) {
        DocumentFile fromSingleUri = DocumentFile.fromSingleUri(getContext(), uri);
        return (fromSingleUri == null || !fromSingleUri.isFile()) ? DocumentFile.fromTreeUri(getContext(), uri) : fromSingleUri;
    }

    private final File toFile(Uri uri) {
        return new File(uri.getPath());
    }

    private final boolean isSAFUri(Uri uri) {
        if (!Intrinsics.areEqual(uri.getScheme(), UriUtil.LOCAL_CONTENT_SCHEME)) {
            return false;
        }
        String host = uri.getHost();
        return host != null ? StringsKt.startsWith$default(host, "com.android.externalstorage", false, 2, null) : false;
    }

    private final String parseFileUri(String str) {
        String substring = str.substring(StringsKt.indexOf$default((CharSequence) str, ':', 0, false, 6, (Object) null) + 3);
        Intrinsics.checkNotNullExpressionValue(substring, "this as java.lang.String).substring(startIndex)");
        return substring;
    }

    private final byte[] getInputStreamBytes(InputStream inputStream) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byte[] bArr = new byte[1024];
        while (true) {
            try {
                int read = inputStream.read(bArr);
                if (read == -1) {
                    break;
                }
                byteArrayOutputStream.write(bArr, 0, read);
            } finally {
                try {
                    byteArrayOutputStream.close();
                } catch (IOException unused) {
                }
            }
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        Intrinsics.checkNotNullExpressionValue(byteArray, "byteBuffer.toByteArray()");
        return byteArray;
    }

    private final Bundle translateHeaders(Headers headers) {
        Bundle bundle = new Bundle();
        int size = headers.size();
        for (int i = 0; i < size; i++) {
            String name = headers.name(i);
            if (bundle.get(name) != null) {
                String string = bundle.getString(name);
                String value = headers.value(i);
                bundle.putString(name, string + ", " + value);
            } else {
                bundle.putString(name, headers.value(i));
            }
        }
        return bundle;
    }

    private final EnumSet<Permission> permissionsForPath(String str) {
        return m53permissionsForPath$lambda0(LazyKt.lazy(new FileSystemModule$permissionsForPath$$inlined$moduleRegistry$1(this.moduleRegistryDelegate))).getPathPermissions(getContext(), str);
    }

    private final Uri contentUriFromFile(File file) {
        Application application = m52contentUriFromFile$lambda27(LazyKt.lazy(new FileSystemModule$contentUriFromFile$$inlined$moduleRegistry$1(this.moduleRegistryDelegate))).getCurrentActivity().getApplication();
        Application application2 = application;
        String packageName = application.getPackageName();
        Uri uriForFile = FileProvider.getUriForFile(application2, packageName + ".FileSystemFileProvider", file);
        Intrinsics.checkNotNullExpressionValue(uriForFile, "getUriForFile(applicatio…ystemFileProvider\", file)");
        return uriForFile;
    }
}
