package expo.modules.keepawake;

import android.app.Activity;
import expo.modules.core.ModuleRegistry;
import expo.modules.core.ModuleRegistryDelegate;
import expo.modules.core.errors.CurrentActivityNotFoundException;
import expo.modules.core.interfaces.ActivityProvider;
import expo.modules.core.interfaces.InternalModule;
import expo.modules.core.interfaces.RegistryLifecycleListener;
import expo.modules.core.interfaces.services.KeepAwakeManager;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

public final class ExpoKeepAwakeManager implements KeepAwakeManager, InternalModule {
    private final ModuleRegistryDelegate moduleRegistryDelegate;
    private final Set<String> tags;

    public ExpoKeepAwakeManager() {
        this(null, 1, null);
    }

    @Override // expo.modules.core.interfaces.RegistryLifecycleListener
    public /* synthetic */ void onDestroy() {
        RegistryLifecycleListener.CC.$default$onDestroy(this);
    }

    public ExpoKeepAwakeManager(ModuleRegistryDelegate moduleRegistryDelegate2) {
        Intrinsics.checkNotNullParameter(moduleRegistryDelegate2, "moduleRegistryDelegate");
        this.moduleRegistryDelegate = moduleRegistryDelegate2;
        this.tags = new HashSet();
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public /* synthetic */ ExpoKeepAwakeManager(ModuleRegistryDelegate moduleRegistryDelegate2, int i, DefaultConstructorMarker defaultConstructorMarker) {
        this((i & 1) != 0 ? new ModuleRegistryDelegate() : moduleRegistryDelegate2);
    }

    private final /* synthetic */ <T> Lazy<T> moduleRegistry() {
        ModuleRegistryDelegate moduleRegistryDelegate2 = this.moduleRegistryDelegate;
        Intrinsics.needClassReification();
        return LazyKt.lazy(new ExpoKeepAwakeManager$moduleRegistry$$inlined$getFromModuleRegistry$1(moduleRegistryDelegate2));
    }

    @Override // expo.modules.core.interfaces.RegistryLifecycleListener
    public void onCreate(ModuleRegistry moduleRegistry) {
        Intrinsics.checkNotNullParameter(moduleRegistry, "moduleRegistry");
        this.moduleRegistryDelegate.onCreate(moduleRegistry);
    }

    /* renamed from: _get_currentActivity_$lambda-0 */
    private static final ActivityProvider m61_get_currentActivity_$lambda0(Lazy<? extends ActivityProvider> lazy) {
        Object value = lazy.getValue();
        Intrinsics.checkNotNullExpressionValue(value, "_get_currentActivity_$lambda-0(...)");
        return (ActivityProvider) value;
    }

    @Override // expo.modules.core.interfaces.services.KeepAwakeManager
    public void activate(String str, Runnable runnable) {
        Intrinsics.checkNotNullParameter(str, "tag");
        Intrinsics.checkNotNullParameter(runnable, "done");
        Activity currentActivity = getCurrentActivity();
        if (!isActivated()) {
            currentActivity.runOnUiThread(new ExpoKeepAwakeManager$$ExternalSyntheticLambda0(currentActivity));
        }
        this.tags.add(str);
        runnable.run();
    }

    /* renamed from: activate$lambda-1 */
    public static final void m62activate$lambda1(Activity activity) {
        Intrinsics.checkNotNullParameter(activity, "$activity");
        activity.getWindow().addFlags(128);
    }

    @Override // expo.modules.core.interfaces.services.KeepAwakeManager
    public void deactivate(String str, Runnable runnable) {
        Intrinsics.checkNotNullParameter(str, "tag");
        Intrinsics.checkNotNullParameter(runnable, "done");
        Activity currentActivity = getCurrentActivity();
        if (this.tags.size() == 1 && this.tags.contains(str)) {
            currentActivity.runOnUiThread(new ExpoKeepAwakeManager$$ExternalSyntheticLambda1(currentActivity));
        }
        this.tags.remove(str);
        runnable.run();
    }

    /* renamed from: deactivate$lambda-2 */
    public static final void m63deactivate$lambda2(Activity activity) {
        Intrinsics.checkNotNullParameter(activity, "$activity");
        activity.getWindow().clearFlags(128);
    }

    @Override // expo.modules.core.interfaces.services.KeepAwakeManager
    public boolean isActivated() {
        return !this.tags.isEmpty();
    }

    @Override // expo.modules.core.interfaces.InternalModule
    public List<Class<?>> getExportedInterfaces() {
        return CollectionsKt.listOf(KeepAwakeManager.class);
    }

    private final Activity getCurrentActivity() {
        Lazy lazy = LazyKt.lazy(new ExpoKeepAwakeManager$special$$inlined$moduleRegistry$1(this.moduleRegistryDelegate));
        if (m61_get_currentActivity_$lambda0(lazy).getCurrentActivity() != null) {
            Activity currentActivity = m61_get_currentActivity_$lambda0(lazy).getCurrentActivity();
            Intrinsics.checkNotNullExpressionValue(currentActivity, "{\n        activityProvider.currentActivity\n      }");
            return currentActivity;
        }
        throw new CurrentActivityNotFoundException();
    }
}
