package org.matrix.olm;

import android.text.TextUtils;
import android.util.Log;
import java.security.SecureRandom;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import kotlin.jvm.internal.ByteCompanionObject;
import org.json.JSONObject;

public class OlmUtility {
    private static final String LOG_TAG = "OlmUtility";
    public static final int RANDOM_KEY_SIZE = 32;
    private long mNativeId;

    private native long createUtilityJni();

    private native void releaseUtilityJni();

    private native byte[] sha256Jni(byte[] bArr);

    private native String verifyEd25519SignatureJni(byte[] bArr, byte[] bArr2, byte[] bArr3);

    public OlmUtility() throws OlmException {
        initUtility();
    }

    private void initUtility() throws OlmException {
        try {
            this.mNativeId = createUtilityJni();
        } catch (Exception e) {
            throw new OlmException(OlmException.EXCEPTION_CODE_UTILITY_CREATION, e.getMessage());
        }
    }

    public void releaseUtility() {
        if (0 != this.mNativeId) {
            releaseUtilityJni();
        }
        this.mNativeId = 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0033  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0061 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x0062  */
    public void verifyEd25519Signature(String str, String str2, String str3) throws OlmException {
        String str4;
        byte[] bArr = null;
        try {
            if (!TextUtils.isEmpty(str) && !TextUtils.isEmpty(str2)) {
                if (!TextUtils.isEmpty(str3)) {
                    bArr = str3.getBytes("UTF-8");
                    str4 = verifyEd25519SignatureJni(str.getBytes("UTF-8"), str2.getBytes("UTF-8"), bArr);
                    if (bArr != null) {
                        Arrays.fill(bArr, (byte) 0);
                    }
                    if (TextUtils.isEmpty(str4)) {
                        throw new OlmException(OlmException.EXCEPTION_CODE_UTILITY_VERIFY_SIGNATURE, str4);
                    }
                    return;
                }
            }
            Log.e(LOG_TAG, "## verifyEd25519Signature(): invalid input parameters");
            str4 = "JAVA sanity check failure - invalid input parameters";
            if (bArr != null) {
            }
        } catch (Exception e) {
            Log.e(LOG_TAG, "## verifyEd25519Signature(): failed " + e.getMessage());
            str4 = e.getMessage();
            if (0 != 0) {
                Arrays.fill((byte[]) null, (byte) 0);
            }
        } catch (Throwable th) {
            if (0 != 0) {
                Arrays.fill((byte[]) null, (byte) 0);
            }
            throw th;
        }
        if (TextUtils.isEmpty(str4)) {
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x003c  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x0044  */
    /* JADX WARNING: Removed duplicated region for block: B:26:? A[RETURN, SYNTHETIC] */
    public String sha256(String str) {
        Throwable th;
        byte[] bArr;
        Exception e;
        byte[] bArr2 = null;
        if (str == null) {
            return null;
        }
        try {
            bArr = str.getBytes("UTF-8");
            try {
                String str2 = new String(sha256Jni(bArr), "UTF-8");
                if (bArr != null) {
                    Arrays.fill(bArr, (byte) 0);
                }
                return str2;
            } catch (Exception e2) {
                e = e2;
                try {
                    Log.e(LOG_TAG, "## sha256(): failed " + e.getMessage());
                    if (bArr != null) {
                        return null;
                    }
                    Arrays.fill(bArr, (byte) 0);
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    bArr2 = bArr;
                    if (bArr2 != null) {
                        Arrays.fill(bArr2, (byte) 0);
                    }
                    throw th;
                }
            }
        } catch (Exception e3) {
            e = e3;
            bArr = null;
            Log.e(LOG_TAG, "## sha256(): failed " + e.getMessage());
            if (bArr != null) {
            }
        } catch (Throwable th3) {
            th = th3;
            if (bArr2 != null) {
            }
            throw th;
        }
    }

    public static byte[] getRandomKey() {
        byte[] bArr = new byte[32];
        new SecureRandom().nextBytes(bArr);
        for (int i = 0; i < 32; i++) {
            bArr[i] = (byte) (bArr[i] & ByteCompanionObject.MAX_VALUE);
        }
        return bArr;
    }

    public boolean isReleased() {
        return 0 == this.mNativeId;
    }

    public static Map<String, String> toStringMap(JSONObject jSONObject) {
        if (jSONObject == null) {
            return null;
        }
        HashMap hashMap = new HashMap();
        Iterator<String> keys = jSONObject.keys();
        while (keys.hasNext()) {
            String next = keys.next();
            try {
                Object obj = jSONObject.get(next);
                if (obj instanceof String) {
                    hashMap.put(next, (String) obj);
                } else {
                    Log.e(LOG_TAG, "## toStringMap(): unexpected type " + obj.getClass());
                }
            } catch (Exception e) {
                Log.e(LOG_TAG, "## toStringMap(): failed " + e.getMessage());
            }
        }
        return hashMap;
    }

    public static Map<String, Map<String, String>> toStringMapMap(JSONObject jSONObject) {
        if (jSONObject == null) {
            return null;
        }
        HashMap hashMap = new HashMap();
        Iterator<String> keys = jSONObject.keys();
        while (keys.hasNext()) {
            String next = keys.next();
            try {
                Object obj = jSONObject.get(next);
                if (obj instanceof JSONObject) {
                    hashMap.put(next, toStringMap((JSONObject) obj));
                } else {
                    Log.e(LOG_TAG, "## toStringMapMap(): unexpected type " + obj.getClass());
                }
            } catch (Exception e) {
                Log.e(LOG_TAG, "## toStringMapMap(): failed " + e.getMessage());
            }
        }
        return hashMap;
    }
}
